/**
 * SCSS Variables.
 *
 * Please use variables from this sheet to ensure consistency across the UI.
 * Don't add to this sheet unless you're pretty sure the value will be reused in many places.
 * For example, don't add rules to this sheet that affect block visuals. It's purely for UI.
 */
/**
 * Colors
 */
/**
 * Fonts & basic variables.
 */
/**
 * Typography
 */
/**
 * Grid System.
 * https://make.wordpress.org/design/2019/10/31/proposal-a-consistent-spacing-system-for-wordpress/
 */
/**
 * Radius scale.
 */
/**
 * Elevation scale.
 */
/**
 * Dimensions.
 */
/**
 * Mobile specific styles
 */
/**
 * Editor styles.
 */
/**
 * Block & Editor UI.
 */
/**
 * Block paddings.
 */
/**
 * React Native specific.
 * These variables do not appear to be used anywhere else.
 */
.wp-block-social-links div.block-editor-url-input {
  display: inline-block;
  margin-right: 8px;
}

.wp-social-link:hover {
  transform: none;
}

:root :where(.wp-block-social-links) {
  padding: 0;
}

.wp-block[data-align=center] > .wp-block-social-links,
.wp-block.wp-block-social-links.aligncenter {
  justify-content: center;
}

.block-editor-block-preview__content .components-button:disabled {
  opacity: 1;
}

.wp-social-link.wp-social-link__is-incomplete {
  opacity: 0.5;
}

.wp-block-social-links .is-selected .wp-social-link__is-incomplete,
.wp-social-link.wp-social-link__is-incomplete:hover,
.wp-social-link.wp-social-link__is-incomplete:focus {
  opacity: 1;
}

.wp-block-social-links .block-list-appender {
  position: static;
}
.wp-block-social-links .block-list-appender .block-editor-inserter {
  font-size: inherit;
}
.wp-block-social-links .block-list-appender .block-editor-button-block-appender {
  height: 1.5em;
  width: 1.5em;
  font-size: inherit;
  padding: 0;
}