"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["7213"],{26476(e){e.exports=JSON.parse('{"copyClipboard":"Skopiuj do schowka","copyClipboardSuccess":"Skopiowano!","noDataToDisplay":"Brak danych do wy\u015Bwietlenia","search":"Szukaj","sort":"Sortuj","pagination":{"rowsPerPage":"Wiersze na stron\u0119:","displayedRows":"{from}\u2013{to} z {count}"},"phoneInput":{"countryCode":"Kod kraju","phoneNumber":"Numer telefonu","countryCodeRequired":"Kod kraju jest wymagany","phoneNumberRequired":"Numer telefonu jest wymagany"}}')}}]);