{% import 'elementor/macros' as m %}
{%- set classes = settings.classes | merge( [ base_styles.base ] ) | join(' ') -%}
<{{ settings.tag | e('html_tag') }} data-interaction-id="{{ interaction_id }}" class="{{ classes }}"
	{{- m.render_custom_attributes(settings) }}>
{%- set allowed_tags = '<b><strong><sup><sub><s><em><i><u><a><del><span><br>' -%}
{%- if settings.link is defined and settings.link.href is defined and settings.link.href is not empty -%}
	<{{ settings.link.tag | default('a') | e('html_tag') }}
		{{- m.render_link_attributes(settings.link) }} class="{{ base_styles['link-base'] }}">
		{{ settings.title | striptags(allowed_tags) | raw }}
	</{{ settings.link.tag | default('a') | e('html_tag') }}>
{%- else -%}
	{{ settings.title | striptags(allowed_tags) | raw }}
{%- endif %}
</{{ settings.tag | e('html_tag') }}>
