@keyframes elementor-animation-wobble-bottom {
	16.65% {
		transform: skew(-12deg);
	}
	33.3% {
		transform: skew(10deg);
	}
	49.95% {
		transform: skew(-6deg);
	}
	66.6% {
		transform: skew(4deg);
	}
	83.25% {
		transform: skew(-2deg);
	}
	100% {
		transform: skew(0);
	}
}
.elementor-animation-wobble-bottom {
	transform-origin: 100% 0;
}
.elementor-animation-wobble-bottom:active,
.elementor-animation-wobble-bottom:focus,
.elementor-animation-wobble-bottom:hover {
	animation-name: elementor-animation-wobble-bottom;
	animation-duration: 1s;
	animation-timing-function: ease-in-out;
	animation-iteration-count: 1;
}
