{% set classes = ['e-con', 'e-atomic-element', base_styles.base] | merge(settings.classes | default([])) | join(' ') %}
<div class="{{ classes }} {{ editor_classes | default('') }}{{ is_active ? ' e--selected' : '' }}"
    data-id="{{ id }}"
    data-element_type="{{ type }}"
    data-e-type="{{ type }}"
    data-interaction-id="{{ interaction_id }}"
    data-interactions="{{ interactions | json_encode | e('html_attr') }}"
    role="tabpanel"
    x-bind="tabContent"
    id="{{ tab_content_id }}"
    aria-labelledby="{{ tab_id }}"
    {% if not is_active %} hidden="true" style="display: none;"{% endif %}
    {% if settings.attributes is defined and settings.attributes is not empty %}
        {{ settings.attributes | raw }}
    {% endif %}
    {{ editor_attributes | default('') | raw }}><!-- elementor-children-placeholder --></div>
