"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9258"],{14369(e){e.exports=JSON.parse('{"title":"Toolbeheerder","subtitle":"Beheer al uw tools op \xc9\xc9N plek.","filters":{"all":"Alle","active":"Actief","disabled":"Uitgeschakeld","notInstalled":"Niet ge\xefnstalleerd"},"back":"Terug naar tooloverzicht","breadcrumb":{"home":"Startpagina","toolManager":"Toolbeheerder"},"tools":{"build":{"title":"Bouwen","items":{"core":{"title":"Editor kern"},"pro":{"title":"Editor pro","features":{"themeBuilder":"Themabouwer","popups":"Pop-ups","commerce":"Commerce","savedTemplates":"Opgeslagen sjablonen","templateCategories":"Sjablooncategorie\xebn","starterTemplates":"Startersjablonen (websitesjablonen)","customFonts":"Aangepaste lettertypen","customIcons":"Aangepaste pictogrammen","customCode":"Aangepaste code","customCss":"Aangepaste CSS"}},"ai":{"title":"Agentic AI"}}},"optimize":{"title":"Optimaliseren","items":{"accessibility":{"title":"Toegankelijkheid"},"io":{"title":"Afbeeldingsoptimalisatie"}}},"manage":{"title":"Beheren","items":{"email":{"title":"E-mailbezorgbaarheid"},"manage":{"title":"Beheer van de site"}}},"create":{"title":"Cre\xebren","items":{"core":{"title":"Redacteur Kern","withAI":"met AI-mogelijkheden"},"pro":{"title":"Redacteur Pro","features":{"themeBuilder":"Thema bouwer","popups":"Pop-ups","commerce":"Handel","savedTemplates":"Opgeslagen sjablonen","templateCategories":"Sjablooncategorie\xebn","starterTemplates":"Starterssjablonen (websitesjablonen)","customFonts":"Aangepaste lettertypen","customIcons":"Aangepaste pictogrammen","customCode":"Aangepaste code","customCss":"Aangepaste CSS"}},"ai":{"title":"Angie - Native AI voor WordPress"}}}},"actions":{"add":"Toevoegen","update":"Bijwerken","activate":"Activeren","deactivate":"Deactiveren","migrateToOne":"Migreren naar One","updateRequired":"Update vereist","confirmAdd":{"title":"Tool toevoegen","msg":"Weet u zeker dat u deze tool wilt toevoegen? Dit voegt de tool toe aan uw account en u kunt deze in uw projecten gebruiken.","ok":"Toevoegen","cancel":"Annuleren"},"confirmActivate":{"title":"Weet u zeker dat u {name} wilt activeren? ","msg":"Door te activeren ...","ok":"Activeren","cancel":"Annuleren"},"confirmDeactivate":{"title":"Weet u zeker dat u {name} wilt deactiveren? ","msg":"Door te deactiveren ...","ok":"Deactiveren","cancel":"Niet nu"},"detachAi":"Koppel Editor AI los van Elementor One","activateCore":"Schakel Editor Core in om Editor Pro in te schakelen","confirmDetach":{"title":"Detach {name} ","msg":"{isEditorCore, select, true {Remove Elementor One from Editor AI. This lets you use it with another plan.} other {Remove the One plan from this plugin. This lets you use it with another plan.}}","ok":"Losmaken","cancel":"Niet nu"},"confirmDeactivateOrDetach":{"title":"Wat zou je graag willen doen?","deactivateMsg":"Schakel deze mogelijkheid en de bijbehorende WordPress-plug-in uit. Je kunt het op elk gewenst moment weer inschakelen en blijven gebruiken met je One-abonnement.","deactivate":"Deactiveren","msg":"{isEditorCore, select, true {Remove Elementor One from Editor AI. This lets you use it with another plan.} other {Remove the One plan from this plugin. This lets you use it with another plan.}}","detach":"Losmaken","cancel":"Niet nu"},"confirmMigration":{"title":"Move {name} to Elementor One? ","msg":"{name} is currently active with its own subscription. You also have an Elementor One subscription for this site.<br/><br/>If you switch to Elementor One:<ul><li>Your current {name} subscription will be deactivated</li><li>{name} will use your shared Elementor One credits</li></ul>","ok":"Beweging","cancel":"Niet nu"},"failedAction":{"install":"Installatie mislukt. Probeer het later opnieuw.","activate":"Activering mislukt. Probeer het later opnieuw.","deactivate":"Deactivering is mislukt. Probeer het later opnieuw.","migrate":"De migratie is mislukt. Probeer het later opnieuw.","detach":"Detachering is mislukt. Probeer het later opnieuw."}},"showMoreFeatures":"Meer functies tonen","hideMoreFeatures":"Meer functies verbergen","noToolsFound":"Geen tools gevonden die overeenkomen met de zoekopdracht","noToolsFoundDescription":"Probeer uw filters aan te passen.","updateRequiredTooltip":"Up-to-date plug-ins hebben nieuwe functies en fixes, zodat uw site veilig en soepel werkt."}')}}]);