.wp-block[data-align=center] > .wp-block-comments-pagination {
  justify-content: center;
}

:where(.editor-styles-wrapper) .wp-block-comments-pagination {
  max-width: 100%;
}

.wp-block-comments-pagination > .wp-block-comments-pagination-next,
.wp-block-comments-pagination > .wp-block-comments-pagination-previous,
.wp-block-comments-pagination > .wp-block-comments-pagination-numbers {
  font-size: inherit;
}