"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["1228"],{61047(e){e.exports=JSON.parse('{"downloadInvoice404":{"title":"Your invoice is being processed","message":"We\u2019ll email it to you once it\u2019s ready."},"supportedLanguages":{"en":"English","de":"Deutsch","es":"Espa\xf1ol","it":"Italiano","nl":"Nederlands","pt-PT":"Portugu\xeas","pt-BR":"Portugu\xeas (Brasil)","fr":"Fran\xe7ais","he-IL":"\u05E2\u05D1\u05E8\u05D9\u05EA"}}')}}]);