"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9288"],{2843(e){e.exports=JSON.parse('{"hi":"Merhaba. Ana bilgisayar \xe7evirisi","alerts":{"connect":{"description":"Elementor One plan\u0131n\u0131z m\u0131 var?","action":"Buradan etkinle\u015Ftirin"},"installing":"Y\xfckleniyor\u2026 l\xfctfen bu sayfada kal\u0131n ({total} \xfczerinden {current})","urlMismatch":{"title":"Lisans\u0131n\u0131z bu alana ba\u011Fl\u0131 de\u011Fil","description":"Bu genellikle HTTPS\'ye ge\xe7i\u015F veya URL de\u011Fi\u015Ftirme gibi bir alan ad\u0131 de\u011Fi\u015Fikli\u011Finden sonra olur.","action":"E\u015Fle\u015Fmeyen URL\'yi d\xfczeltin"}}}')}}]);