"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9726"],{57421(e){e.exports=JSON.parse('{"wPLoginAttempts":"Tentativas de login WP.","wPLoginAttemptsResetSuccess":"As tentativas de login WP foram redefinidas com sucesso.","errorTryAgain":"Algo deu errado, por favor, tente novamente.","backupCreation":"Cria\xe7\xe3o de backup.","backupCreated":"O backup do site foi criado com sucesso.","backupUpdate":"O backup do site foi atualizado com sucesso.","backupUpdated":"O backup do site foi atualizado com sucesso.","backupRestore":"Restaurar backup.","backupDelete":"Exclus\xe3o de backup.","backupDeleted":"O backup foi exclu\xeddo.","backupExport":"Exportar backup.","backupExportSuccessToast":"Em breve, voc\xea receber\xe1 um e-mail com o link para download.","debugMode":"Modo de depura\xe7\xe3o.","debugModeSwithFailed":"{value, select, true {Desativar} other {Ativar}} o modo de depura\xe7\xe3o falhou, por favor, tente novamente.","siteDeletion":"Remo\xe7\xe3o do site.","siteDeleted":"O site foi removido.","setFavoriteSuccess":"{domain} foi adicionado aos seus sites favoritos.","removeFavoriteSuccess":"{domain} foi removido dos seus sites favoritos.","maxReachedFavorites":"Voc\xea atingiu o n\xfamero m\xe1ximo de favoritos.","generalErrorToast":"Ops, isso n\xe3o funcionou. Tente novamente mais tarde.","websiteDeactivation":"Desativa\xe7\xe3o do site.","setDefaultPaymentFailed":"Falha ao definir o m\xe9todo de pagamento padr\xe3o.","actionFailedMessage":"Desculpe, isso n\xe3o funcionou.","retryErrorMessage":"Desculpe, isso n\xe3o funcionou. Tente novamente.","addingDomainFailed":"A adi\xe7\xe3o de um dom\xednio n\xe3o foi bem-sucedida, por favor, tente novamente.","removingDomainFailed":"A remo\xe7\xe3o de um dom\xednio n\xe3o foi bem-sucedida, por favor, tente novamente.","settingDomainPrimaryFailed":"A defini\xe7\xe3o do dom\xednio como principal n\xe3o foi bem-sucedida, por favor, tente novamente.","emailVerification":"Verifica\xe7\xe3o de e-mail.","emailAlreadyVerified":"O e-mail j\xe1 est\xe1 verificado.","emailVerificationSent":"Enviado! Verifique sua caixa de entrada para um e-mail de verifica\xe7\xe3o.","emailVerificationResendDelay":"J\xe1 enviamos um e-mail de verifica\xe7\xe3o para sua caixa de entrada. Se voc\xea ainda n\xe3o conseguir encontrar o e-mail, poder\xe1 solicitar o reenvio em 5 minutos.","teamMemberRemoved":"{email} foi removido da sua equipe.","inviteSentTo":"Um convite foi enviado para {email}.","inviteResendDelay":"Por favor, aguarde {cooldown} segundos antes de reenviar o convite.","billingInfoUpdated":"Suas informa\xe7\xf5es de faturamento foram atualizadas.","subCanceledConfirmation":"Sua assinatura foi cancelada e seu reembolso est\xe1 sendo processado. Verifique seu e-mail para obter detalhes.","siteDomainRemoved":"O site {domain} foi removido.","siteLockPassReset":"Redefini\xe7\xe3o de senha de bloqueio do site.","updatedSiteLockCode":"Seu novo c\xf3digo de bloqueio do site \xe9: {pass}.","contactSupport":"Entrar em contato com o suporte.","srySomethingWrong":"Desculpe, algo deu errado.","subRefundFailed":"Sua assinatura ainda est\xe1 ativa porque o reembolso n\xe3o p\xf4de ser processado. Estamos aqui para ajudar.","partialRefundMessage":"Seu reembolso n\xe3o p\xf4de ser totalmente processado, mas sua assinatura n\xe3o est\xe1 mais ativa. Estamos aqui para ajudar.","exitMaintenanceModeToastTitle":"Sair do modo de manuten\xe7\xe3o.","exitMaintenanceModeToastText":"O site {slug} saiu do modo de manuten\xe7\xe3o com sucesso."}')}}]);