__( 'Activate Atomic Editor features', 'elementor' );
__( 'The Atomic Editor presents a new generation of high-performance, flexible building blocks designed for less bloat and precise styling with a unified interface.', 'elementor' );
__( 'Combine legacy widgets & new elements', 'elementor' );
__( 'Your current and new workflows work together on the same page.', 'elementor' );
__( 'Build reusable design systems', 'elementor' );
__( 'Classes, Variables and Components give you a clear path for scale.', 'elementor' );
__( 'Consistent styling experience', 'elementor' );
__( 'A unified Style tab for all Atomic Elements with full control over responsive design.', 'elementor' );
__( 'Unparalleled performance', 'elementor' );
__( 'Cleaner code and a lighter CSS footprint with single-div wrappers.', 'elementor' );
__( 'And much more!', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'We’d love your feedback!', 'elementor' );
__( 'Head over to Github', 'elementor' );
__( 'Tell us why', 'elementor' );
__( 'Editor V4', 'elementor' );
__( 'Try out the new experience', 'elementor' );
__( 'Activate the new experience', 'elementor' );
__( 'Deactivate', 'elementor' );
__( 'Welcome! You’ve got the newest version of the editor.', 'elementor' );
__( 'You’ve deactivated the new Editor. Have feedback?', 'elementor' );
__( 'Ouch, there was a glitch. Try activating again soon.', 'elementor' );
__( 'Atomic Editor', 'elementor' );
__( 'I’ve read and understood.', 'elementor' );
__( 'You are about to enable Atomic Editor features!', 'elementor' );
__( 'By activating, you’ll get access to the next generation of Elementor’s Editor. This is your chance to explore new capabilities and help shape the future of Elementor! ', 'elementor' );
__( 'When you activate, you’ll also be activating Containers and Nested Elements. You can turn them back off by going to: WP Admin > Elementor > Settings > Features.', 'elementor' );
__( 'Activate', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'You\'re about to lose all content created with Atomic features', 'elementor' );
__( 'By deactivating, you’ll lose all Atomic Elements, Classes and Variables. Any content you created with these features will no longer be available or appear on your site.', 'elementor' );
__( 'Containers and Nested Elements will stay in their current status.', 'elementor' );
__( 'Deactivate', 'elementor' );
__( 'Cancel', 'elementor' );