"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9886"],{42381(e){e.exports=JSON.parse('{"wPLoginAttempts":"WP login attempts.","wPLoginAttemptsResetSuccess":"WP login attempts have been successfully reset.","errorTryAgain":"Something went wrong, please try again.","backupCreation":"Backup creation.","backupCreated":"Site backup has been successfully created.","backupUpdate":"Site backup has been successfully updated.","backupUpdated":"Site backup has been successfully updated.","backupRestore":"Backup restore.","backupDelete":"Backup deletion.","backupDeleted":"Backup has been deleted.","backupExport":"Backup Export.","backupExportSuccessToast":"Soon you will receive an email with the download link.","debugMode":"Debug mode.","debugModeSwithFailed":"{value, select, true {Disabling} other {Enabling}} debug mode failed, please try again.","siteDeletion":"Site removal.","siteDeleted":"Site has been removed.","setFavoriteSuccess":"{domain} was added to your favorite sites.","removeFavoriteSuccess":"{domain} was removed from your favorite sites.","maxReachedFavorites":"You have reached the maximum number of favorites.","generalErrorToast":"Woops, that didn\'t work, Try again later.","websiteDeactivation":"Website deactivation.","setDefaultPaymentFailed":"Failed to set default payment method.","actionFailedMessage":"Sorry, that didn\'t work.","retryErrorMessage":"Sorry, that didn\'t work. Try again.","addingDomainFailed":"Adding a domain was unsuccessful, please try again.","removingDomainFailed":"Removing a domain was unsuccessful, please try again.","settingDomainPrimaryFailed":"Setting domain as primary was unsuccessful please try again.","emailVerification":"Email verification.","emailAlreadyVerified":"The email is already verified.","emailVerificationSent":"Sent! Check your inbox for a verification email.","emailVerificationResendDelay":"We already sent a verification email to your inbox. If you still can\'t find the email, you can ask to resend it in 5 minutes.","teamMemberRemoved":"{email} was removed from your team.","inviteSentTo":"An invite was sent to {email}.","inviteResendDelay":"We already sent an invite to {email}. You can try again later.","billingInfoUpdated":"Your billing information was updated.","subCanceledConfirmation":"Your subscription has been cancelled and your refund is being processed. Check your email for details.","siteDomainRemoved":"Website {domain} has been removed.","siteLockPassReset":"Site lock password reset.","updatedSiteLockCode":"Your new Site-Lock code is: {pass}.","contactSupport":"Contact support.","srySomethingWrong":"Sorry, something went wrong.","subRefundFailed":"Your subscription is still active because the refund couldn\'t be processed. We\'re here to help.","partialRefundMessage":"Your refund couldn\'t be fully processed, but your subscription is no longer active. We\'re here to help.","exitMaintenanceModeToastTitle":"Exit maintenance mode.","exitMaintenanceModeToastText":"Site {slug} has been successfully exited from maintenance mode."}')}}]);