"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["1605"],{54708(e){e.exports=JSON.parse('{"dialog":{"title":"Deel uw feedback","fieldTitlePlaceholder":"Titel","fieldDescriptionPlaceholder":"Vertel ons wat u in gedachten had","fieldSubjectPlaceholder":"Selecteer het onderwerp van uw feedback","fieldProductPlaceholder":"Selecteer het product","note":"We waarderen uw feedback! Hoewel we alle inzendingen beoordelen, kunnen we niet garanderen dat elke suggestie zal leiden tot een wijziging of update.","subjects":{"leaveFeedback":"Geef feedback","reportBug":"Meld een bug","requestFeature":"Vraag een functie aan","shareThoughts":"Deel andere gedachten"},"products":{"general":"Algemeen","editor":"Editor","accessibility":"Toegankelijkheid","imageOptimization":"Afbeeldingsoptimalisatie","emailDeliverability":"E-mailbezorgbaarheid","siteManagement":"Site Management"},"cancel":"Annuleren","submit":"Verzenden","titleLengthError":"Titel moet minder dan 90 tekens bevatten","descriptionLengthError":"Beschrijving moet minder dan 1024 tekens bevatten","alert":{"title":"Hulp nodig of een probleem tegengekomen?","button":"Dien een supportticket in"}},"tooltipSuccess":"Feedback verzonden. Bedankt voor uw hulp.","tooltipError":"Er is iets misgegaan. Probeer uw feedback opnieuw te verzenden."}')}}]);