__( 'Here\'s where you can fine-tune Elementor to your workflow. Disable elements you don\'t use for a cleaner interface, more focused creative experience, and improved performance.', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'We saved your changes.', 'elementor' );
__( 'No elements found.', 'elementor' );
__( 'Element', 'elementor' );
__( 'Status', 'elementor' );
__( 'Usage', 'elementor' );
__( 'Plugin', 'elementor' );
__( 'Permission', 'elementor' );
__( 'Choose which users will have access to each widget.', 'elementor' );
__( 'times', 'elementor' );
__( 'Show', 'elementor' );
__( 'Search', 'elementor' );
__( 'Plugin', 'elementor' );
__( 'All Plugins', 'elementor' );
__( 'All Plugins', 'elementor' );
__( 'Status', 'elementor' );
__( 'All Statuses', 'elementor' );
__( 'Active', 'elementor' );
__( 'Inactive', 'elementor' );
__( 'Scan Element Usage', 'elementor' );
__( 'Deactivate Unused Elements', 'elementor' );
__( 'Enable All', 'elementor' );
__( 'Save Changes', 'elementor' );
__( 'Admin', 'elementor' );
__( 'All Roles', 'elementor' );
__( 'Edit', 'elementor' );
__( 'All', 'elementor' );
__( 'Edit', 'elementor' );
__( 'Elementor Pro Elements', 'elementor' );
__( 'Unleash the full power of Elementor\'s features and web creation tools.', 'elementor' );
__( 'Element', 'elementor' );
__( 'Status', 'elementor' );
__( 'Usage', 'elementor' );
__( 'Plugin', 'elementor' );
__( 'Permission', 'elementor' );
__( 'Choose which role will have access to a specific widget.', 'elementor' );
__( 'Elementor Pro', 'elementor' );
__( 'Before you continue:', 'elementor' );
__( 'Deactivating widgets here will remove them from both the Elementor Editor and your website, which can cause changes to your overall layout, design and what visitors see.', 'elementor' );
__( 'Sure you want to save these changes?', 'elementor' );
__( 'Turning widgets off will hide them from the editor panel, and can potentially affect your layout or front-end.', 'elementor' );
__( 'If you\'re adding widgets back in, enjoy them!', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Save', 'elementor' );