<?php

namespace ElementorOne\Admin\Exceptions;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Migration MigrationException
 */
class MigrationException extends \Exception {}
