"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["4708"],{80031(a){a.exports=JSON.parse('{"hi":"Ol\xe1. Tradu\xe7\xe3o do anfitri\xe3o","alerts":{"connect":{"description":"Tem um plano Elementor One?","action":"Ative-o aqui"},"installing":"A instalar\u2026 por favor, permane\xe7a nesta p\xe1gina ({current} de {total})","urlMismatch":{"title":"A sua licen\xe7a n\xe3o est\xe1 ligada a este dom\xednio","description":"Isto geralmente acontece ap\xf3s uma altera\xe7\xe3o de dom\xednio, como a mudan\xe7a para HTTPS ou a altera\xe7\xe3o de URLs.","action":"Corrigir URL incompat\xedvel"}}}')}}]);