<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
/**
 * This file is generated by Webpack, do not edit it directly.
 */
return [
	'handle' => 'elementor-v2-editor-elements-panel',
	'deps' => [
		'elementor-v2-editor',
		'elementor-v2-editor-v1-adapters',
		'elementor-v2-ui',
		'elementor-v2-utils',
		'react',
	],
];
