"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["3125"],{87316(e){e.exports=JSON.parse('{"onBoardingInstall":{"title":"Bienvenido a\\nelementor one!","description":"Instalaremos todas las capacidades de Elementor.\\nSi no desea instalarlas, deselecci\xf3nelas ahora.","skip":"Omitir","continue":"Continuar","installAndContinue":"Instalar y continuar","duringInstallation":"Durante la instalaci\xf3n, actualizaremos todas las herramientas que lo requieran.","tools":{"additionalBetaTools":"Herramientas beta adicionales","editorCore":{"title":"N\xfacleo del editor","description":"Cree sitios web perfectos con una interfaz de arrastrar y soltar"},"editorPro":{"title":"Editor Pro","description":"Cree su sitio completo con herramientas profesionales"},"imageOptimizer":{"title":"Optimizaci\xf3n de im\xe1genes","description":"Comprima y optimice im\xe1genes para mejorar el rendimiento"},"accessibility":{"title":"Accesibilidad","description":"Encuentre y corrija problemas de accesibilidad en todo su sitio"},"siteMailer":{"title":"Site Mailer","description":"Aseg\xfarese de que los correos electr\xf3nicos de su sitio lleguen a la bandeja de entrada, no al spam"},"ai":{"title":"IA nativa para WordPress","description":"Convierta ideas en p\xe1ginas, bloques y funciones con IA nativa "},"installed":"Ya instalado","singleSub":"Suscripci\xf3n \xfanica","updateRequired":"Actualizaci\xf3n necesaria","updateRequiredTooltip":"Se actualizar\xe1 autom\xe1ticamente a la \xfaltima versi\xf3n","beta":"Beta","manage":{"title":"Gesti\xf3n del sitio","description":"Supervisa, optimiza y mant\xe9n todos tus sitios en un solo lugar"},"installedTooltip":"Puedes desinstalar las herramientas instaladas desde el administrador de herramientas."},"installedToolTip":"Puedes desinstalar las herramientas instaladas desde el administrador de herramientas.","conflictsDialog":{"update":{"title":"Actualizaciones disponibles","description":"Estas herramientas usan versiones anteriores. Actualiza para obtener el mejor rendimiento y seguridad.","selectTools":"Selecciona las herramientas a actualizar","action":"{nothingIsSelected, select, true {Continuar} other {Actualizar y continuar}}"},"migrate":{"title":"Migraci\xf3n necesaria","description":"Estas herramientas no est\xe1n migradas a Elementor One. Migra para obtener el mejor rendimiento y seguridad.","selectTools":"Selecciona las herramientas a migrar","action":"{nothingIsSelected, select, true {Continuar} other {Mover y continuar}}"},"manageLater":"Puedes gestionar estas actualizaciones m\xe1s tarde en el administrador de herramientas","step":"Paso {step} de {total}"}},"siteIdentity":{"activeTheme":"Tema activo:","getHelloElementor":"Obtener hello elementor","goToDashboard":"Ir al panel de control","editSite":"Editar sitio","editSiteMenu":{"addPage":"A\xf1adir una p\xe1gina","addBlogPost":"A\xf1adir una entrada de blog","createHeader":"Crear un encabezado","createFooter":"Crear un pie de p\xe1gina"},"helloThemeInstalled":"Tema Hello Elementor instalado correctamente","helloThemeInstallationFailed":"Error al instalar el tema Hello Elementor","helloThemeActivationFailed":"Error al activar el tema Hello Elementor","helloThemeActivated":"Tema Hello Elementor activado correctamente","goToSiteSetup":"Ir a la configuraci\xf3n del sitio"},"capabilities":{"greeting":"Empecemos a construir.","filters":{"all":"Todo","discover":"Descubrir","build":"Construir","optimize":"Optimizar","manage":"Gestionar","featured":"Destacados","create":"Crear"},"toolManager":"Administrador de herramientas","addForFreeButton":"A\xf1adir gratis","openButton":"Abrir","goProButton":"Hacerse Pro","inProgressButton":"En curso","learnMore":{"upgrade":"Actualizar","install":"Instalar","open":"Abrir"},"isNew":"Nuevo"},"toolManager":{"title":"Controle todas sus herramientas en UN solo lugar."},"welcomeModal":{"letsStart":{"title":"\xa1Te damos la bienvenida al <br />nuevo Elementor!","description":"Crea, optimiza y gestiona tu sitio web <br />desde un \xfanico espacio de trabajo potente.","button":"Empecemos"}}}')}}]);