"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_pl-PL_send-feedback_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/pl-PL/send-feedback.json":
/*!****************************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/pl-PL/send-feedback.json ***!
  \****************************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"dialog":{"title":"Prześlij swoją opinię","fieldTitlePlaceholder":"Tytuł","fieldDescriptionPlaceholder":"Opowiedz nam, co masz na myśli","fieldSubjectPlaceholder":"Wybierz temat swojej opinii","fieldProductPlaceholder":"Wybierz produkt","note":"Dziękujemy za Twoją opinię! Chociaż przeglądamy wszystkie zgłoszenia, nie możemy zagwarantować, że każda sugestia zaowocuje zmianą lub aktualizacją.","subjects":{"leaveFeedback":"Zostaw opinię","reportBug":"Zgłoś błąd","requestFeature":"Zaproponuj funkcję","shareThoughts":"Podziel się innymi przemyśleniami"},"products":{"general":"Ogólne","editor":"Edytor","accessibility":"Dostępność","imageOptimization":"Optymalizacja obrazu","emailDeliverability":"Dostarczalność wiadomości e-mail","siteManagement":"Site Management"},"cancel":"Anuluj","submit":"Wyślij","titleLengthError":"Tytuł musi zawierać mniej niż 90 znaków","descriptionLengthError":"Opis musi zawierać mniej niż 1024 znaki","alert":{"title":"Potrzebujesz pomocy lub napotkałeś problem?","button":"Wyślij zgłoszenie do pomocy technicznej"}},"tooltipSuccess":"Opinia wysłana. Dziękujemy za pomoc.","tooltipError":"Coś poszło nie tak. Spróbuj ponownie wysłać swoją opinię."}');

/***/ })

}]);