__( 'Please note that you are switching to WordPress default editor. Your current layout, design and content might break.', 'elementor' );
__( 'Back to WordPress Editor', 'elementor' );
__( 'Continue', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Please note that you are switching to WordPress default editor. Your current layout, design and content might break.', 'elementor' );
__( 'Back to WordPress Editor', 'elementor' );
__( 'Continue', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'I understand that by upgrading to Font Awesome 5,', 'elementor' );
__( 'I acknowledge that some changes may affect my website and that this action cannot be undone.', 'elementor' );
__( 'Font Awesome 5 Migration', 'elementor' );
__( 'Continue', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Rollback to Previous Version', 'elementor' );
__( 'Are you sure you want to reinstall previous version?', 'elementor' );
__( 'Continue', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Migrate to v3.0', 'elementor' );
__( 'Please note that this process will revert all changes made to Global Colors and Fonts since upgrading to v3.x.', 'elementor' );
__( 'Continue', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Importing...', 'elementor' );
__( 'Submit & Deactivate', 'elementor' );
__( 'Skip & Deactivate', 'elementor' );
__( 'New Template', 'elementor' );
__( 'New Floating Elements', 'elementor' );
__( 'Sign Up', 'elementor' );
__( 'Don\'t Show Again', 'elementor' );