#adminmenu .toplevel_page_elementor-home .wp-menu-image:before{background-color:currentColor;content:"";-webkit-mask-image:url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyNCAyNCI+PHBhdGggZD0iTTEyLjEyIDBDNS40MjUgMCAwIDUuMzcgMCAxMnM1LjQyNCAxMiAxMi4xMiAxMmM2LjY5NyAwIDEyLjEyMS01LjM3IDEyLjEyMS0xMlMxOC44MTcgMCAxMi4xMjEgME04LjQ4NSAxOEg2LjA2VjZoMi40MjR6bTkuNjk3IDBoLTcuMjcydi0yLjRoNy4yNzJ6bTAtNC44aC03LjI3MnYtMi40aDcuMjcyem0wLTQuOGgtNy4yNzJWNmg3LjI3MnoiLz48L3N2Zz4=);mask-image:url(data:image/svg+xml;base64,PHN2ZyB4bWxucz0iaHR0cDovL3d3dy53My5vcmcvMjAwMC9zdmciIHZpZXdCb3g9IjAgMCAyNCAyNCI+PHBhdGggZD0iTTEyLjEyIDBDNS40MjUgMCAwIDUuMzcgMCAxMnM1LjQyNCAxMiAxMi4xMiAxMmM2LjY5NyAwIDEyLjEyMS01LjM3IDEyLjEyMS0xMlMxOC44MTcgMCAxMi4xMjEgME04LjQ4NSAxOEg2LjA2VjZoMi40MjR6bTkuNjk3IDBoLTcuMjcydi0yLjRoNy4yNzJ6bTAtNC44aC03LjI3MnYtMi40aDcuMjcyem0wLTQuOGgtNy4yNzJWNmg3LjI3MnoiLz48L3N2Zz4=);-webkit-mask-position:center;mask-position:center;-webkit-mask-repeat:no-repeat;mask-repeat:no-repeat;-webkit-mask-size:20px;mask-size:20px}#adminmenu a[href="admin.php?page=elementor-one-upgrade"]{background-color:#93003f;border-radius:4px;color:#fff;display:block;font-weight:500;letter-spacing:.46px;line-height:22px;margin:8px 12px;text-align:center}#adminmenu a[href="admin.php?page=elementor-one-upgrade"]:focus,#adminmenu a[href="admin.php?page=elementor-one-upgrade"]:hover{background-color:#c60055;box-shadow:none;color:#fff}#elementor-home-app-top-bar~#wpbody #wpbody-content{margin-block-start:0}
