"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["2591"],{48402(e){e.exports=JSON.parse('{"header":"URL mismatch","title":"How would you like to continue?","description":"Your license key does not match your current domain, causing a mismatch.{br}This is most likely due to a change in the domain URL of your site.","actions":{"updateCurrentSite":{"title":"Update the connected URL","description":"For URL changes on the same site, like staging to production or HTTP to HTTPS.","action":"Update connected URL"},"connectNewSite":{"title":"Connect the URL as a new site","description":"For connecting a completely different site. Previous history will be removed.","action":"Connect as a new site"}}}')}}]);