"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["7646"],{68669(i){i.exports=JSON.parse('{"hi":"Ciao. Traduzione host","alerts":{"connect":{"description":"Hai un piano Elementor One?","action":"Attivalo qui"},"installing":"Installazione in corso\u2026 resta su questa pagina ({current} di {total})","urlMismatch":{"title":"La tua licenza non \xe8 connessa a questo dominio","description":"Questo di solito accade dopo un cambio di dominio, come il passaggio a HTTPS o la modifica degli URL.","action":"Correggi l\'URL non corrispondente"}}}')}}]);