"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9828"],{38719(e){e.exports=JSON.parse('{"hi":"Cze\u015B\u0107. T\u0142umaczenie hosta","alerts":{"connect":{"description":"Masz plan Elementor One?","action":"Aktywuj go tutaj"},"installing":"Instalowanie\u2026 prosz\u0119 pozosta\u0107 na tej stronie ({current} z {total})","urlMismatch":{"title":"Twoja licencja nie jest po\u0142\u0105czona z t\u0105 domen\u0105","description":"Zazwyczaj dzieje si\u0119 tak po zmianie domeny, na przyk\u0142ad po przej\u015Bciu na HTTPS lub zmianie adres\xf3w URL.","action":"Napraw niezgodny adres URL"}}}')}}]);