"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["1744"],{71907(e){e.exports=JSON.parse('{"hi":"Ol\xe1. Tradu\xe7\xe3o do host","alerts":{"connect":{"description":"Tem um plano Elementor One?","action":"Ative-o aqui"},"installing":"Instalando\u2026 permane\xe7a nesta p\xe1gina ({current} de {total})","urlMismatch":{"title":"Sua licen\xe7a n\xe3o est\xe1 conectada a este dom\xednio","description":"Isso geralmente acontece ap\xf3s uma altera\xe7\xe3o de dom\xednio, como mudar para HTTPS ou trocar de URL.","action":"Corrigir URL incompat\xedvel"}}}')}}]);