"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["1081"],{27984(e){e.exports=JSON.parse('{"header":{"title":"website builder","userInfo":"My account","userProfileMenu":{"connectPreText":"Have an Elementor One plan?","connect":"Connect","goToMyAccount":"Go to My account","disconnect":"Disconnect","elementorOneActive":"Elementor One","active":"Active","urlMismatch":"URL mismatch detected","fixUrlMismatch":"Fix now"},"whatsNew":"What\'s new","whatsNewError":"Something went wrong while fetching the notifications. Please try again later."}}')}}]);