/*! For license information please see env.js.LICENSE.txt */
!function(){"use strict";var n={d:function(e,t){for(var r in t)n.o(t,r)&&!n.o(e,r)&&Object.defineProperty(e,r,{enumerable:!0,get:t[r]})},o:function(n,e){return Object.prototype.hasOwnProperty.call(n,e)},r:function(n){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(n,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(n,"__esModule",{value:!0})}},e={};n.r(e),n.d(e,{InvalidEnvError:function(){return InvalidEnvError},__resetEnv:function(){return __resetEnv},initEnv:function(){return initEnv},parseEnv:function(){return parseEnv}});let t=null;function initEnv(n){t=n}function __resetEnv(){t=null}function parseEnv(n,e=n=>n){let r={},o=!1;const i=new Proxy(r,{get(n,e){return o||parse(),r[e]},ownKeys(){return o||parse(),Reflect.ownKeys(r)},getOwnPropertyDescriptor(){return{configurable:!0,enumerable:!0}}}),parse=()=>{try{const o=t?.[n];if(!o)throw new InvalidEnvError("Settings object not found");if("object"!=typeof o)throw new InvalidEnvError(`Expected settings to be \`object\`, but got \`${typeof o}\``);r=e(o)}catch(e){if(!(e instanceof InvalidEnvError))throw e;console.warn(`${n} - ${e.message}`),r={}}finally{o=!0}};return{validateEnv:parse,env:i}}class InvalidEnvError extends Error{}(window.elementorV2=window.elementorV2||{}).env=e}(),window.elementorV2.env?.init?.();
//# sourceMappingURL=env.js.map