"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["3840"],{73635(e){e.exports=JSON.parse('{"header":"Incoh\xe9rence d\u2019URL","title":"Comment souhaitez-vous continuer ?","description":"Votre cl\xe9 de licence ne correspond pas \xe0 votre domaine actuel, ce qui provoque une incoh\xe9rence.{br}Cela est tr\xe8s probablement d\xfb \xe0 un changement d\u2019URL de domaine de votre site.","actions":{"updateCurrentSite":{"title":"Mettre \xe0 jour l\u2019URL connect\xe9e","description":"Pour les changements d\u2019URL sur le m\xeame site, comme de la pr\xe9-production \xe0 la production ou de HTTP \xe0 HTTPS.","action":"Mettre \xe0 jour l\u2019URL connect\xe9e"},"connectNewSite":{"title":"Connecter l\u2019URL comme un nouveau site","description":"Pour connecter un site compl\xe8tement diff\xe9rent. L\u2019historique pr\xe9c\xe9dent sera supprim\xe9.","action":"Connecter comme un nouveau site"}}}')}}]);