.e-has-sidebar-navigation {
  --editor-one-sidebar-admin-top-bar-height: 50px;
  --editor-one-wordpress-admin-bar-height: 32px;
  --editor-one-sidebar-navigation-width: 240px;
  --editor-one-sidebar-navigation-width-collapsed: 72px;
  --editor-one-sidebar-left-offset: 160px;
  --editor-one-sidebar-left-offset-collapsed: 36px;
  --editor-one-sidebar-z-index: 99;
  --editor-one-sidebar-bg: #fff;
  --editor-one-sidebar-content-padding: 20px;
  --editor-one-sidebar-transition: width 0.3s ease-in-out, padding-inline-start 0.3s ease-in-out, margin-inline-start 0.3s ease-in-out;
}
.e-has-sidebar-navigation.folded {
  --editor-one-sidebar-left-offset: var(--editor-one-sidebar-left-offset-collapsed);
}

#editor-one-sidebar-navigation {
  position: fixed;
  top: calc(var(--editor-one-sidebar-admin-top-bar-height) + var(--editor-one-wordpress-admin-bar-height));
  bottom: 0;
  inset-inline-start: var(--editor-one-sidebar-left-offset);
  inset-inline-end: auto;
  z-index: var(--editor-one-sidebar-z-index);
  background-color: var(--editor-one-sidebar-bg);
  overflow: visible;
}
#editor-one-sidebar-navigation nav {
  width: var(--editor-one-sidebar-navigation-width);
  max-width: var(--editor-one-sidebar-navigation-width);
}

.e-sidebar-transitioning #editor-one-sidebar-navigation > nav {
  transition: var(--editor-one-sidebar-transition);
  overflow: hidden;
}
.e-sidebar-transitioning #wpcontent,
.e-sidebar-transitioning #wpbody-content,
.e-sidebar-transitioning #wpfooter {
  transition: var(--editor-one-sidebar-transition);
}

.e-has-sidebar-navigation {
  -ms-overflow-style: none; /* IE and Edge */
  scrollbar-width: none; /* Firefox */
}
.e-has-sidebar-navigation::-webkit-scrollbar {
  display: none; /* Hide scrollbar for Chrome, Safari and Opera */
}
.e-has-sidebar-navigation:has(.e-sidebar-collapsed) {
  --editor-one-sidebar-navigation-width: var(--editor-one-sidebar-navigation-width-collapsed);
}
.e-has-sidebar-navigation #wpcontent {
  padding-inline-start: var(--editor-one-sidebar-navigation-width);
}
.e-has-sidebar-navigation #wpwrap > #wpfooter {
  display: none;
}
.e-has-sidebar-navigation #wpcontent #wpfooter {
  background-color: transparent;
  position: relative;
  margin-inline: 0;
  margin-block-start: auto;
  padding-block-start: 18px;
}
.e-has-sidebar-navigation #wpcontent #wpfooter #footer-left {
  float: none;
  text-align: center;
  margin: 0 auto;
}
.e-has-sidebar-navigation #adminmenu li.wp-has-current-submenu a.wp-has-current-submenu::after, .e-has-sidebar-navigation #adminmenu li.wp-has-submenu.wp-not-current-submenu:hover > a::after {
  display: none;
}
.e-has-sidebar-navigation #adminmenu li.wp-has-current-submenu, .e-has-sidebar-navigation #adminmenu li.wp-has-submenu:hover {
  background: transparent;
}
.e-has-sidebar-navigation #adminmenu li.menu-top:hover, .e-has-sidebar-navigation #adminmenu li.opensub > a.menu-top,
.e-has-sidebar-navigation #adminmenu li > a.menu-top:focus {
  background: transparent;
}
.e-has-sidebar-navigation #adminmenu li.elementor-has-flyout .elementor-submenu-flyout {
  display: none;
}
.e-has-sidebar-navigation #adminmenu .wp-submenu-head {
  display: none;
}

/*# sourceMappingURL=sidebar-navigation.css.map */