"use strict";
(self["webpackChunkelementorFrontend"] = self["webpackChunkelementorFrontend"] || []).push([["wp-audio"],{

/***/ "../assets/dev/js/frontend/handlers/wp-audio.js":
/*!******************************************************!*\
  !*** ../assets/dev/js/frontend/handlers/wp-audio.js ***!
  \******************************************************/
/***/ ((__unused_webpack_module, exports) => {



Object.defineProperty(exports, "__esModule", ({
  value: true
}));
exports["default"] = void 0;
class WpAudio extends elementorModules.frontend.handlers.Base {
  onInit() {
    super.onInit();
    window.wp.mediaelement.initialize();
  }
}
exports["default"] = WpAudio;

/***/ })

}]);
//# sourceMappingURL=wp-audio.0ba9114964acf4c37ca2.bundle.js.map