__( 'You can enable the Atomic editor anytime from Editor Settings.', 'elementor' );
__( 'Failed to activate Atomic elements', 'elementor' );
__( 'Atomic Elements', 'elementor' );
__( 'New', 'elementor' );
__(
							'Build with modern, flexible elements designed for reusable styles and cleaner layouts. Your existing site and content stay exactly the same.',
							'elementor'
						);
__( 'Learn more', 'elementor' );
__( 'Activate now', 'elementor' );