__( 'Container', 'elementor' );
__( 'Direction Column', 'elementor' );
__( 'Direction Row', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Elementor\'s New Icon Library', 'elementor' );
__( 'Elementor v2.6 includes an upgrade from Font Awesome 4 to 5. In order to continue using icons, be sure to click "Update".', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Update', 'elementor' );
__( 'Take Over', 'elementor' );
__( 'Take Over', 'elementor' );
__( 'Go Back', 'elementor' );
__( '%s has taken over and is currently editing. Do you want to take over this page editing?', 'elementor' );
__( 'Sorry, you can\'t upload that file yet', 'elementor' );
__( 'This is because JSON files may pose a security risk.', 'elementor' );
__( 'To upload them anyway, ask the site administrator to enable unfiltered file uploads.', 'elementor' );
__( 'Got it', 'elementor' );
__( 'Enable Unfiltered File Uploads', 'elementor' );
__( 'Before you enable unfiltered files upload, note that such files include a security risk. Elementor does run a process to remove possible malicious code, but there is still risk involved when using such files.', 'elementor' );
__( 'Enable', 'elementor' );
__( 'Enable Unfiltered File Uploads', 'elementor' );
__( 'Before you enable unfiltered files upload, note that such files include a security risk. Elementor does run a process to remove possible malicious code, but there is still risk involved when using such files.', 'elementor' );
__( 'If you do not enable uploading unfiltered files, any SVG or JSON (including lottie) files used in the uploaded template will not be imported.', 'elementor' );
__( 'Enable and Import', 'elementor' );
__( 'Import Without Enabling', 'elementor' );
__( 'Container', 'elementor' );
__( 'Clear', 'elementor' );
__( 'Color Picker', 'elementor' );
__( 'Create New Global Color', 'elementor' );