"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_tr-TR_send-feedback_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/tr-TR/send-feedback.json":
/*!****************************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/tr-TR/send-feedback.json ***!
  \****************************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"dialog":{"title":"Geri bildiriminizi paylaşın","fieldTitlePlaceholder":"Başlık","fieldDescriptionPlaceholder":"Aklınızdakileri bize anlatın","fieldSubjectPlaceholder":"Geri bildiriminizin konusunu seçin","fieldProductPlaceholder":"Ürünü seçin","note":"Geri bildiriminiz için teşekkür ederiz! Tüm gönderimleri incelesek de her önerinin bir değişiklikle veya güncellemeyle sonuçlanacağını garanti edemeyiz.","subjects":{"leaveFeedback":"Geri bildirim bırakın","reportBug":"Hata bildirin","requestFeature":"Özellik isteyin","shareThoughts":"Diğer düşüncelerinizi paylaşın"},"products":{"general":"Genel","editor":"Düzenleyici","accessibility":"Erişilebilirlik","imageOptimization":"Görsel optimizasyonu","emailDeliverability":"E-posta teslim edilebilirliği","siteManagement":"Site Management"},"cancel":"İptal","submit":"Gönder","titleLengthError":"Başlık 90 karakterden az olmalı","descriptionLengthError":"Açıklama 1024 karakterden az olmalı","alert":{"title":"Yardıma mı ihtiyacınız var veya bir sorunla mı karşılaştınız?","button":"Destek talebi gönderin"}},"tooltipSuccess":"Geri bildirim gönderildi. Bize yardım ettiğiniz için teşekkürler.","tooltipError":"Bir şeyler ters gitti. Lütfen geri bildiriminizi tekrar göndermeyi deneyin."}');

/***/ })

}]);