"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9321"],{6736(a){a.exports=JSON.parse('{"alertError":{"defaultTitle":"Qualcosa \xe8 andato storto!","defaultMessage":"Si prega di aggiornare questa pagina.","refreshBtn":"Aggiorna","okBtn":"Ok"},"errorBoundary":{"default":{"title":"Qualcosa \xe8 andato storto!","message":"Si prega di aggiornare questa pagina.","btn":"Aggiorna"},"newVersion":{"title":"Nuova versione disponibile!","message":"Si prega di aggiornare questa pagina.","btn":"Aggiorna"}}}')}}]);