<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInit69a127256f0c26284ac31a679a58264b
{
    public static $files = array (
        '9db71c6726821ac61284818089584d23' => __DIR__ . '/..' . '/elementor/wp-one-package/runner.php',
    );

    public static $prefixLengthsPsr4 = array (
        'E' =>
        array (
            'Elementor\\WPNotificationsPackage\\' => 33,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'Elementor\\WPNotificationsPackage\\' =>
        array (
            0 => __DIR__ . '/..' . '/elementor/wp-notifications-package/src',
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
        'ElementorDeps\\Attribute' => __DIR__ . '/../..' . '/vendor_prefixed/twig/symfony/polyfill-php80/Resources/stubs/Attribute.php',
        'ElementorDeps\\CURLStringFile' => __DIR__ . '/../..' . '/vendor_prefixed/twig/symfony/polyfill-php81/Resources/stubs/CURLStringFile.php',
        'ElementorDeps\\PhpToken' => __DIR__ . '/../..' . '/vendor_prefixed/twig/symfony/polyfill-php80/Resources/stubs/PhpToken.php',
        'ElementorDeps\\ReturnTypeWillChange' => __DIR__ . '/../..' . '/vendor_prefixed/twig/symfony/polyfill-php81/Resources/stubs/ReturnTypeWillChange.php',
        'ElementorDeps\\Stringable' => __DIR__ . '/../..' . '/vendor_prefixed/twig/symfony/polyfill-php80/Resources/stubs/Stringable.php',
        'ElementorDeps\\Symfony\\Polyfill\\Ctype\\Ctype' => __DIR__ . '/../..' . '/vendor_prefixed/twig/symfony/polyfill-ctype/Ctype.php',
        'ElementorDeps\\Symfony\\Polyfill\\Mbstring\\Mbstring' => __DIR__ . '/../..' . '/vendor_prefixed/twig/symfony/polyfill-mbstring/Mbstring.php',
        'ElementorDeps\\Symfony\\Polyfill\\Php80\\Php80' => __DIR__ . '/../..' . '/vendor_prefixed/twig/symfony/polyfill-php80/Php80.php',
        'ElementorDeps\\Symfony\\Polyfill\\Php80\\PhpToken' => __DIR__ . '/../..' . '/vendor_prefixed/twig/symfony/polyfill-php80/PhpToken.php',
        'ElementorDeps\\Symfony\\Polyfill\\Php81\\Php81' => __DIR__ . '/../..' . '/vendor_prefixed/twig/symfony/polyfill-php81/Php81.php',
        'ElementorDeps\\Twig\\Attribute\\YieldReady' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Attribute/YieldReady.php',
        'ElementorDeps\\Twig\\Cache\\CacheInterface' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Cache/CacheInterface.php',
        'ElementorDeps\\Twig\\Cache\\ChainCache' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Cache/ChainCache.php',
        'ElementorDeps\\Twig\\Cache\\FilesystemCache' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Cache/FilesystemCache.php',
        'ElementorDeps\\Twig\\Cache\\NullCache' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Cache/NullCache.php',
        'ElementorDeps\\Twig\\Cache\\ReadOnlyFilesystemCache' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Cache/ReadOnlyFilesystemCache.php',
        'ElementorDeps\\Twig\\Compiler' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Compiler.php',
        'ElementorDeps\\Twig\\Environment' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Environment.php',
        'ElementorDeps\\Twig\\Error\\Error' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Error/Error.php',
        'ElementorDeps\\Twig\\Error\\LoaderError' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Error/LoaderError.php',
        'ElementorDeps\\Twig\\Error\\RuntimeError' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Error/RuntimeError.php',
        'ElementorDeps\\Twig\\Error\\SyntaxError' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Error/SyntaxError.php',
        'ElementorDeps\\Twig\\ExpressionParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/ExpressionParser.php',
        'ElementorDeps\\Twig\\ExtensionSet' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/ExtensionSet.php',
        'ElementorDeps\\Twig\\Extension\\AbstractExtension' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/AbstractExtension.php',
        'ElementorDeps\\Twig\\Extension\\CoreExtension' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/CoreExtension.php',
        'ElementorDeps\\Twig\\Extension\\DebugExtension' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/DebugExtension.php',
        'ElementorDeps\\Twig\\Extension\\EscaperExtension' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/EscaperExtension.php',
        'ElementorDeps\\Twig\\Extension\\ExtensionInterface' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/ExtensionInterface.php',
        'ElementorDeps\\Twig\\Extension\\GlobalsInterface' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/GlobalsInterface.php',
        'ElementorDeps\\Twig\\Extension\\OptimizerExtension' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/OptimizerExtension.php',
        'ElementorDeps\\Twig\\Extension\\ProfilerExtension' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/ProfilerExtension.php',
        'ElementorDeps\\Twig\\Extension\\RuntimeExtensionInterface' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/RuntimeExtensionInterface.php',
        'ElementorDeps\\Twig\\Extension\\SandboxExtension' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/SandboxExtension.php',
        'ElementorDeps\\Twig\\Extension\\StagingExtension' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/StagingExtension.php',
        'ElementorDeps\\Twig\\Extension\\StringLoaderExtension' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/StringLoaderExtension.php',
        'ElementorDeps\\Twig\\Extension\\YieldNotReadyExtension' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Extension/YieldNotReadyExtension.php',
        'ElementorDeps\\Twig\\FileExtensionEscapingStrategy' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/FileExtensionEscapingStrategy.php',
        'ElementorDeps\\Twig\\Lexer' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Lexer.php',
        'ElementorDeps\\Twig\\Loader\\ArrayLoader' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Loader/ArrayLoader.php',
        'ElementorDeps\\Twig\\Loader\\ChainLoader' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Loader/ChainLoader.php',
        'ElementorDeps\\Twig\\Loader\\FilesystemLoader' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Loader/FilesystemLoader.php',
        'ElementorDeps\\Twig\\Loader\\LoaderInterface' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Loader/LoaderInterface.php',
        'ElementorDeps\\Twig\\Markup' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Markup.php',
        'ElementorDeps\\Twig\\NodeTraverser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/NodeTraverser.php',
        'ElementorDeps\\Twig\\NodeVisitor\\AbstractNodeVisitor' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/NodeVisitor/AbstractNodeVisitor.php',
        'ElementorDeps\\Twig\\NodeVisitor\\EscaperNodeVisitor' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/NodeVisitor/EscaperNodeVisitor.php',
        'ElementorDeps\\Twig\\NodeVisitor\\MacroAutoImportNodeVisitor' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/NodeVisitor/MacroAutoImportNodeVisitor.php',
        'ElementorDeps\\Twig\\NodeVisitor\\NodeVisitorInterface' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/NodeVisitor/NodeVisitorInterface.php',
        'ElementorDeps\\Twig\\NodeVisitor\\OptimizerNodeVisitor' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/NodeVisitor/OptimizerNodeVisitor.php',
        'ElementorDeps\\Twig\\NodeVisitor\\SafeAnalysisNodeVisitor' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/NodeVisitor/SafeAnalysisNodeVisitor.php',
        'ElementorDeps\\Twig\\NodeVisitor\\SandboxNodeVisitor' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/NodeVisitor/SandboxNodeVisitor.php',
        'ElementorDeps\\Twig\\NodeVisitor\\YieldNotReadyNodeVisitor' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/NodeVisitor/YieldNotReadyNodeVisitor.php',
        'ElementorDeps\\Twig\\Node\\AutoEscapeNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/AutoEscapeNode.php',
        'ElementorDeps\\Twig\\Node\\BlockNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/BlockNode.php',
        'ElementorDeps\\Twig\\Node\\BlockReferenceNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/BlockReferenceNode.php',
        'ElementorDeps\\Twig\\Node\\BodyNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/BodyNode.php',
        'ElementorDeps\\Twig\\Node\\CaptureNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/CaptureNode.php',
        'ElementorDeps\\Twig\\Node\\CheckSecurityCallNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/CheckSecurityCallNode.php',
        'ElementorDeps\\Twig\\Node\\CheckSecurityNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/CheckSecurityNode.php',
        'ElementorDeps\\Twig\\Node\\CheckToStringNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/CheckToStringNode.php',
        'ElementorDeps\\Twig\\Node\\DeprecatedNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/DeprecatedNode.php',
        'ElementorDeps\\Twig\\Node\\DoNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/DoNode.php',
        'ElementorDeps\\Twig\\Node\\EmbedNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/EmbedNode.php',
        'ElementorDeps\\Twig\\Node\\Expression\\AbstractExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/AbstractExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\ArrayExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/ArrayExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\ArrowFunctionExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/ArrowFunctionExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\AssignNameExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/AssignNameExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\AbstractBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/AbstractBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\AddBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/AddBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\AndBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/AndBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\BitwiseAndBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/BitwiseAndBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\BitwiseOrBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/BitwiseOrBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\BitwiseXorBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/BitwiseXorBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\ConcatBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/ConcatBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\DivBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/DivBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\EndsWithBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/EndsWithBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\EqualBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/EqualBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\FloorDivBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/FloorDivBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\GreaterBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/GreaterBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\GreaterEqualBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/GreaterEqualBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\HasEveryBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/HasEveryBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\HasSomeBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/HasSomeBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\InBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/InBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\LessBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/LessBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\LessEqualBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/LessEqualBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\MatchesBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/MatchesBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\ModBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/ModBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\MulBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/MulBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\NotEqualBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/NotEqualBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\NotInBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/NotInBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\OrBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/OrBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\PowerBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/PowerBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\RangeBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/RangeBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\SpaceshipBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/SpaceshipBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\StartsWithBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/StartsWithBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Binary\\SubBinary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Binary/SubBinary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\BlockReferenceExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/BlockReferenceExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\CallExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/CallExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\ConditionalExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/ConditionalExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\ConstantExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/ConstantExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\FilterExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/FilterExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Filter\\DefaultFilter' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Filter/DefaultFilter.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Filter\\RawFilter' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Filter/RawFilter.php',
        'ElementorDeps\\Twig\\Node\\Expression\\FunctionExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/FunctionExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\GetAttrExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/GetAttrExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\InlinePrint' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/InlinePrint.php',
        'ElementorDeps\\Twig\\Node\\Expression\\MethodCallExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/MethodCallExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\NameExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/NameExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\NullCoalesceExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/NullCoalesceExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\ParentExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/ParentExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\TempNameExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/TempNameExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\TestExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/TestExpression.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Test\\ConstantTest' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Test/ConstantTest.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Test\\DefinedTest' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Test/DefinedTest.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Test\\DivisiblebyTest' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Test/DivisiblebyTest.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Test\\EvenTest' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Test/EvenTest.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Test\\NullTest' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Test/NullTest.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Test\\OddTest' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Test/OddTest.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Test\\SameasTest' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Test/SameasTest.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Unary\\AbstractUnary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Unary/AbstractUnary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Unary\\NegUnary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Unary/NegUnary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Unary\\NotUnary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Unary/NotUnary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\Unary\\PosUnary' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/Unary/PosUnary.php',
        'ElementorDeps\\Twig\\Node\\Expression\\VariadicExpression' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Expression/VariadicExpression.php',
        'ElementorDeps\\Twig\\Node\\FlushNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/FlushNode.php',
        'ElementorDeps\\Twig\\Node\\ForLoopNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/ForLoopNode.php',
        'ElementorDeps\\Twig\\Node\\ForNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/ForNode.php',
        'ElementorDeps\\Twig\\Node\\IfNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/IfNode.php',
        'ElementorDeps\\Twig\\Node\\ImportNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/ImportNode.php',
        'ElementorDeps\\Twig\\Node\\IncludeNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/IncludeNode.php',
        'ElementorDeps\\Twig\\Node\\MacroNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/MacroNode.php',
        'ElementorDeps\\Twig\\Node\\ModuleNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/ModuleNode.php',
        'ElementorDeps\\Twig\\Node\\NameDeprecation' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/NameDeprecation.php',
        'ElementorDeps\\Twig\\Node\\Node' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/Node.php',
        'ElementorDeps\\Twig\\Node\\NodeCaptureInterface' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/NodeCaptureInterface.php',
        'ElementorDeps\\Twig\\Node\\NodeOutputInterface' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/NodeOutputInterface.php',
        'ElementorDeps\\Twig\\Node\\PrintNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/PrintNode.php',
        'ElementorDeps\\Twig\\Node\\SandboxNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/SandboxNode.php',
        'ElementorDeps\\Twig\\Node\\SetNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/SetNode.php',
        'ElementorDeps\\Twig\\Node\\TextNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/TextNode.php',
        'ElementorDeps\\Twig\\Node\\WithNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Node/WithNode.php',
        'ElementorDeps\\Twig\\Parser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Parser.php',
        'ElementorDeps\\Twig\\Profiler\\Dumper\\BaseDumper' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Profiler/Dumper/BaseDumper.php',
        'ElementorDeps\\Twig\\Profiler\\Dumper\\BlackfireDumper' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Profiler/Dumper/BlackfireDumper.php',
        'ElementorDeps\\Twig\\Profiler\\Dumper\\HtmlDumper' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Profiler/Dumper/HtmlDumper.php',
        'ElementorDeps\\Twig\\Profiler\\Dumper\\TextDumper' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Profiler/Dumper/TextDumper.php',
        'ElementorDeps\\Twig\\Profiler\\NodeVisitor\\ProfilerNodeVisitor' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Profiler/NodeVisitor/ProfilerNodeVisitor.php',
        'ElementorDeps\\Twig\\Profiler\\Node\\EnterProfileNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Profiler/Node/EnterProfileNode.php',
        'ElementorDeps\\Twig\\Profiler\\Node\\LeaveProfileNode' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Profiler/Node/LeaveProfileNode.php',
        'ElementorDeps\\Twig\\Profiler\\Profile' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Profiler/Profile.php',
        'ElementorDeps\\Twig\\RuntimeLoader\\ContainerRuntimeLoader' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/RuntimeLoader/ContainerRuntimeLoader.php',
        'ElementorDeps\\Twig\\RuntimeLoader\\FactoryRuntimeLoader' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/RuntimeLoader/FactoryRuntimeLoader.php',
        'ElementorDeps\\Twig\\RuntimeLoader\\RuntimeLoaderInterface' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/RuntimeLoader/RuntimeLoaderInterface.php',
        'ElementorDeps\\Twig\\Runtime\\EscaperRuntime' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Runtime/EscaperRuntime.php',
        'ElementorDeps\\Twig\\Sandbox\\SecurityError' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Sandbox/SecurityError.php',
        'ElementorDeps\\Twig\\Sandbox\\SecurityNotAllowedFilterError' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Sandbox/SecurityNotAllowedFilterError.php',
        'ElementorDeps\\Twig\\Sandbox\\SecurityNotAllowedFunctionError' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Sandbox/SecurityNotAllowedFunctionError.php',
        'ElementorDeps\\Twig\\Sandbox\\SecurityNotAllowedMethodError' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Sandbox/SecurityNotAllowedMethodError.php',
        'ElementorDeps\\Twig\\Sandbox\\SecurityNotAllowedPropertyError' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Sandbox/SecurityNotAllowedPropertyError.php',
        'ElementorDeps\\Twig\\Sandbox\\SecurityNotAllowedTagError' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Sandbox/SecurityNotAllowedTagError.php',
        'ElementorDeps\\Twig\\Sandbox\\SecurityPolicy' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Sandbox/SecurityPolicy.php',
        'ElementorDeps\\Twig\\Sandbox\\SecurityPolicyInterface' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Sandbox/SecurityPolicyInterface.php',
        'ElementorDeps\\Twig\\Sandbox\\SourcePolicyInterface' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Sandbox/SourcePolicyInterface.php',
        'ElementorDeps\\Twig\\Source' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Source.php',
        'ElementorDeps\\Twig\\Template' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Template.php',
        'ElementorDeps\\Twig\\TemplateWrapper' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TemplateWrapper.php',
        'ElementorDeps\\Twig\\Test\\IntegrationTestCase' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Test/IntegrationTestCase.php',
        'ElementorDeps\\Twig\\Test\\NodeTestCase' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Test/NodeTestCase.php',
        'ElementorDeps\\Twig\\Token' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Token.php',
        'ElementorDeps\\Twig\\TokenParser\\AbstractTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/AbstractTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\ApplyTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/ApplyTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\AutoEscapeTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/AutoEscapeTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\BlockTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/BlockTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\DeprecatedTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/DeprecatedTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\DoTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/DoTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\EmbedTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/EmbedTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\ExtendsTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/ExtendsTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\FlushTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/FlushTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\ForTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/ForTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\FromTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/FromTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\IfTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/IfTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\ImportTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/ImportTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\IncludeTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/IncludeTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\MacroTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/MacroTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\SandboxTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/SandboxTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\SetTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/SetTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\TokenParserInterface' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/TokenParserInterface.php',
        'ElementorDeps\\Twig\\TokenParser\\UseTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/UseTokenParser.php',
        'ElementorDeps\\Twig\\TokenParser\\WithTokenParser' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenParser/WithTokenParser.php',
        'ElementorDeps\\Twig\\TokenStream' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TokenStream.php',
        'ElementorDeps\\Twig\\TwigFilter' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TwigFilter.php',
        'ElementorDeps\\Twig\\TwigFunction' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TwigFunction.php',
        'ElementorDeps\\Twig\\TwigTest' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/TwigTest.php',
        'ElementorDeps\\Twig\\Util\\DeprecationCollector' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Util/DeprecationCollector.php',
        'ElementorDeps\\Twig\\Util\\ReflectionCallable' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Util/ReflectionCallable.php',
        'ElementorDeps\\Twig\\Util\\TemplateDirIterator' => __DIR__ . '/../..' . '/vendor_prefixed/twig/twig/twig/src/Util/TemplateDirIterator.php',
        'ElementorDeps\\UnhandledMatchError' => __DIR__ . '/../..' . '/vendor_prefixed/twig/symfony/polyfill-php80/Resources/stubs/UnhandledMatchError.php',
        'ElementorDeps\\ValueError' => __DIR__ . '/../..' . '/vendor_prefixed/twig/symfony/polyfill-php80/Resources/stubs/ValueError.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInit69a127256f0c26284ac31a679a58264b::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInit69a127256f0c26284ac31a679a58264b::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInit69a127256f0c26284ac31a679a58264b::$classMap;

        }, null, ClassLoader::class);
    }
}
