"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["8718"],{99661(e){e.exports=JSON.parse('{"dialog":{"title":"Share your feedback","fieldTitlePlaceholder":"Title","fieldDescriptionPlaceholder":"Tell us what you had in mind","fieldSubjectPlaceholder":"Select the subject of your feedback","fieldProductPlaceholder":"Select the product","note":"We appreciate your feedback! While we review all submissions, we can\'t guarantee that every suggestion will result in a change or update.","subjects":{"leaveFeedback":"Leave a feedback","reportBug":"Report a bug","requestFeature":"Request a feature","shareThoughts":"Share any other thoughts"},"products":{"general":"General","editor":"Editor","accessibility":"Accessibility","imageOptimization":"Image optimization","emailDeliverability":"Email deliverability","siteManagement":"Site Management","cookieConsent":"Cookie consent"},"cancel":"Cancel","submit":"Submit","titleLengthError":"Title must be less than 90 characters","descriptionLengthError":"Description must be less than 1024 characters","alert":{"title":"Need help or ran into an issue?","button":"Submit a support ticket"}},"tooltipSuccess":"Feedback sent. Thanks for helping us out.","tooltipError":"Something went wrong. Please try sending your feedback again."}')}}]);