.e-has-sidebar-navigation {
  --editor-one-sidebar-admin-top-bar-height: 50px;
  --editor-one-wordpress-admin-bar-height: 32px;
  --editor-one-sidebar-navigation-width: 240px;
  --editor-one-sidebar-navigation-width-collapsed: 72px;
  --editor-one-sidebar-left-offset: 160px;
  --editor-one-sidebar-left-offset-collapsed: 36px;
  --editor-one-sidebar-z-index: 99;
  --editor-one-sidebar-bg: #fff;
  --editor-one-sidebar-content-padding: 20px;
  --editor-one-sidebar-transition: width 0.3s ease-in-out, padding-inline-start 0.3s ease-in-out, margin-inline-start 0.3s ease-in-out;
}
.e-has-sidebar-navigation.folded {
  --editor-one-sidebar-left-offset: var(--editor-one-sidebar-left-offset-collapsed);
}

#editor-one-top-bar {
  --editor-one-sidebar-admin-top-bar-height: 48px;
}
#editor-one-top-bar:not(:has(header)) {
  height: var(--editor-one-sidebar-admin-top-bar-height);
}
#editor-one-top-bar > * {
  inset-block-start: var(--editor-one-wordpress-admin-bar-height, 32px);
  inset-inline-start: var(--editor-one-sidebar-left-offset, 160px);
  inset-inline-end: 0;
  width: calc(100% - var(--editor-one-sidebar-left-offset, 160px));
  position: fixed;
}
@media screen and (max-width: 960px) {
  #editor-one-top-bar > * {
    inset-inline-start: var(--editor-one-wordpress-admin-bar-height, 32px);
    width: calc(100% - var(--editor-one-wordpress-admin-bar-height, 32px));
  }
}
@media screen and (max-width: 782px) {
  #editor-one-top-bar {
    --editor-one-sidebar-admin-top-bar-height: 46px;
  }
  #editor-one-top-bar > * {
    inset-inline-start: 0;
    inset-block-start: var(--editor-one-sidebar-admin-top-bar-height, 46px);
    width: 100%;
  }
}

@media screen and (max-width: 600px) {
  body:has(#editor-one-top-bar) #wpadminbar {
    position: fixed;
  }
}

/*# sourceMappingURL=top-bar.css.map */