__( "Can't add this component - components that contain each other can't be nested.", 'elementor' );
__( 'Components', 'elementor' );
__( 'Editing components requires an active Pro subscription.', 'elementor' );
__( 'Upgrade Now', 'elementor' );
__( 'To edit components, update Elementor Pro to the latest version.', 'elementor' );
__( 'Update Now', 'elementor' );
__( 'Edit Component', 'elementor' );
__( 'Detach from Component', 'elementor' );
__( 'Failed to detach component instance.', 'elementor' );
__(
			'You have unpublished component on this page. You need a pro version to publish it.',
			'elementor'
		);
__( 'Upgrade Now', 'elementor' );
/* translators: %s is the name of the user who is currently editing the document */
__( '%s is currently editing this document', 'elementor' );
__(
							'You can wait for them to finish or reach out to coordinate your changes together.',
							'elementor'
						);
__( 'Close', 'elementor' );
__( 'Detach from Component?', 'elementor' );
__(
						'Detaching this instance will break its link to the Component. Changes to the Component will no longer apply. Continue?',
						'elementor'
					);
__( 'Detach', 'elementor' );
__( 'Upgrade now', 'elementor' );
__( 'Upgrade Now', 'elementor' );
__( 'Detach from Component', 'elementor' );
__( 'Instance detached', 'elementor' );
/* translators: %s: component name. */
__( 'Edit %s', 'elementor' );
__( 'Edit Component', 'elementor' );
__(
							'To edit components, update Elementor Pro to the latest version.',
							'elementor'
						);
__( 'Edit components', 'elementor' );
__( 'Editing components requires an active Pro subscription.', 'elementor' );
__(
				'Edit the component to add properties, manage them or update the design across all instances.',
				'elementor'
		  );
__(
				'With your current role, you cannot edit this component. Contact an administrator to add properties.',
				'elementor'
		  );
__( 'No properties yet', 'elementor' );
__( 'Edit component', 'elementor' );
__( 'Failed to detach component instance.', 'elementor' );
__( 'Detach from Component', 'elementor' );
__( 'Create new Components', 'elementor' );
__( 'To create new components, update Elementor Pro to the latest version.', 'elementor' );
__( 'Create new components', 'elementor' );
__( 'Creating new components requires an active Pro subscription.', 'elementor' );
__( 'Create Reusable Components', 'elementor' );
__( 'Create design elements that sync across your entire site.', 'elementor' );
__( 'Upgrade now', 'elementor' );
__( 'Create Reusable Components', 'elementor' );
__( 'Create design elements that sync across your entire site.', 'elementor' );
__( 'To create components, update Elementor Pro to the latest version.', 'elementor' );
__( 'Update Elementor Pro', 'elementor' );
__( 'No components yet', 'elementor' );
__( 'Components are reusable blocks that sync across your site.', 'elementor' );
__( 'Create once, use everywhere.', 'elementor' );
__(
								'With your current role, you cannot create components. Contact an administrator to create one.',
								'elementor'
						  );
__( 'Learn more about components', 'elementor' );
__( 'Create your first one:', 'elementor' );
__(
								'Right-click any div-block or flexbox on your canvas or structure and select "Create component"',
								'elementor'
							);
__( 'Sorry, nothing matched', 'elementor' );
__( 'Try something else.', 'elementor' );
__( 'Clear & try again', 'elementor' );
__( 'Search', 'elementor' );