"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["5818"],{22593(e){e.exports=JSON.parse('{"onBoardingInstall":{"title":"Bem-vindo ao\\nElementor One!","description":"Instalaremos todos os recursos do Elementor.\\nSe n\xe3o quiser instal\xe1-los, desmarque-os agora.","skip":"Pular","continue":"Continuar","installAndContinue":"Instalar e continuar","duringInstallation":"Durante a instala\xe7\xe3o, atualizaremos todas as ferramentas que exigirem.","tools":{"additionalBetaTools":"Ferramentas beta adicionais","editorCore":{"title":"N\xfacleo do Editor","description":"Crie sites pixel-perfect com uma interface de arrastar e soltar"},"editorPro":{"title":"Editor Pro","description":"Crie seu site inteiro com ferramentas profissionais"},"imageOptimizer":{"title":"Otimiza\xe7\xe3o de imagem","description":"Comprima e otimize imagens para aumentar o desempenho"},"accessibility":{"title":"Acessibilidade","description":"Encontre e corrija problemas de acessibilidade em seu site"},"siteMailer":{"title":"Remetente do site","description":"Garanta que os e-mails do seu site cheguem \xe0 caixa de entrada - n\xe3o ao spam"},"ai":{"title":"IA nativa para WordPress","description":"Transforme ideias em p\xe1ginas, blocos e recursos com IA nativa "},"installed":"J\xe1 instalado","singleSub":"Assinatura \xfanica","updateRequired":"Atualiza\xe7\xe3o necess\xe1ria","updateRequiredTooltip":"Ser\xe1 atualizado automaticamente para a vers\xe3o mais recente","beta":"Beta","manage":{"title":"Gerenciamento do site","description":"Monitore, otimize e gerencie todos os seus sites em um s\xf3 lugar"},"installedTooltip":"Voc\xea pode desinstalar as ferramentas instaladas no gerenciador de ferramentas."},"installedToolTip":"Voc\xea pode desinstalar as ferramentas instaladas no gerenciador de ferramentas.","conflictsDialog":{"update":{"title":"Atualiza\xe7\xf5es dispon\xedveis","description":"Estas ferramentas est\xe3o em vers\xf5es antigas. Atualize para obter o melhor desempenho e seguran\xe7a.","selectTools":"Selecione as ferramentas a atualizar","action":"{nothingIsSelected, select, true {Continuar} other {Atualizar e continuar}}"},"migrate":{"title":"Migra\xe7\xe3o necess\xe1ria","description":"Estas ferramentas n\xe3o est\xe3o migradas para o Elementor One. Migre para obter o melhor desempenho e seguran\xe7a.","selectTools":"Selecione as ferramentas a migrar","action":"{nothingIsSelected, select, true {Continuar} other {Mover e continuar}}"},"manageLater":"Voc\xea pode gerenciar essas atualiza\xe7\xf5es depois no gerenciador de ferramentas","step":"Passo {step} de {total}"}},"siteIdentity":{"activeTheme":"Tema ativo:","getHelloElementor":"Obter hello elementor","goToDashboard":"Ir para o painel","editSite":"Editar site","editSiteMenu":{"addPage":"Adicionar uma p\xe1gina","addBlogPost":"Adicionar uma postagem de blog","createHeader":"Criar um cabe\xe7alho","createFooter":"Criar um rodap\xe9"},"helloThemeInstalled":"Tema Hello Elementor instalado com sucesso","helloThemeInstallationFailed":"Falha na instala\xe7\xe3o do tema Hello Elementor","helloThemeActivationFailed":"Falha na ativa\xe7\xe3o do tema Hello Elementor","helloThemeActivated":"Tema Hello Elementor ativado com sucesso","goToSiteSetup":"Ir \xe0 configura\xe7\xe3o do site"},"capabilities":{"greeting":"Vamos come\xe7ar a construir.","filters":{"all":"Todos","discover":"Descobrir","build":"Construir","optimize":"Otimizar","manage":"Gerenciar","featured":"Destaques","create":"Criar"},"toolManager":"Gerenciador de ferramentas","addForFreeButton":"Adicionar gratuitamente","openButton":"Abrir","goProButton":"Tornar-se Pro","inProgressButton":"Em andamento","learnMore":{"upgrade":"Atualizar","install":"Instalar","open":"Abrir"},"isNew":"Novo"},"toolManager":{"title":"Controle todas as suas ferramentas em UM s\xf3 lugar."},"welcomeModal":{"letsStart":{"title":"Bem-vindo ao <br />novo Elementor!","description":"Crie, otimize e gerencie seu site <br />a partir de um \xfanico ambiente de trabalho poderoso.","button":"Vamos come\xe7ar"}}}')}}]);