"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_he-IL_send-feedback_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/he-IL/send-feedback.json":
/*!****************************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/he-IL/send-feedback.json ***!
  \****************************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"dialog":{"title":"שתף את המשוב שלך","fieldTitlePlaceholder":"כותרת","fieldDescriptionPlaceholder":"ספר לנו מה חשבת","fieldSubjectPlaceholder":"בחר את נושא המשוב שלך","fieldProductPlaceholder":"בחר את המוצר","note":"אנו מעריכים את המשוב שלך! אנו בודקים את כל ההגשות, אך איננו יכולים להבטיח שכל הצעה תוביל לשינוי או עדכון.","subjects":{"leaveFeedback":"השאר משוב","reportBug":"דווח על באג","requestFeature":"בקש תכונה","shareThoughts":"שתף כל מחשבה אחרת"},"products":{"general":"כללי","editor":"עורך","accessibility":"נגישות","imageOptimization":"אופטימיזציית תמונה","emailDeliverability":"יכולת מסירת email","siteManagement":"Site Management"},"cancel":"ביטול","submit":"שלח","titleLengthError":"הכותרת חייבת להיות פחות מ-90 תווים","descriptionLengthError":"התיאור חייב להיות פחות מ-1024 תווים","alert":{"title":"זקוק לעזרה או נתקלת בבעיה?","button":"שלח בקשת תמיכה"}},"tooltipSuccess":"המשוב נשלח. תודה שעזרת לנו.","tooltipError":"משהו השתבש. אנא נסה לשלוח את המשוב שלך שוב."}');

/***/ })

}]);