"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["1095"],{96266(e){e.exports=JSON.parse('{"hi":"Hola. Traducci\xf3n de host","alerts":{"connect":{"description":"\xbfTiene un plan Elementor One?","action":"Act\xedvelo aqu\xed"},"installing":"Instalando\u2026 permanezca en esta p\xe1gina ({current} de {total})","urlMismatch":{"title":"Su licencia no est\xe1 conectada a este dominio","description":"Esto suele ocurrir despu\xe9s de un cambio de dominio, como al pasar a HTTPS o cambiar de URL.","action":"Corregir URL no coincidente"}}}')}}]);