<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
/**
 * This file is generated by Webpack, do not edit it directly.
 */
return [
	'handle' => 'elementor-v2-editor-ui',
	'deps' => [
		'elementor-v2-editor-v1-adapters',
		'elementor-v2-icons',
		'elementor-v2-ui',
		'react',
		'react-dom',
		'wp-i18n',
	],
];
