@keyframes elementor-animation-buzz {
	50% {
		transform: translateX(3px) rotate(2deg);
	}
	100% {
		transform: translateX(-3px) rotate(-2deg);
	}
}
.elementor-animation-buzz:active,
.elementor-animation-buzz:focus,
.elementor-animation-buzz:hover {
	animation-name: elementor-animation-buzz;
	animation-duration: 0.15s;
	animation-timing-function: linear;
	animation-iteration-count: infinite;
}
