"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["5468"],{79799(e){e.exports=JSON.parse('{"downloadInvoice404":{"title":"Sua fatura est\xe1 sendo processada","message":"Enviaremos por e-mail assim que estiver pronta."},"supportedLanguages":{"en":"Ingl\xeas","de":"Alem\xe3o","es":"Espanhol","it":"Italiano","nl":"Holand\xeas","pt-PT":"Portugu\xeas","pt-BR":"Portugu\xeas (Brasil)","fr":"Franc\xeas","he-IL":"Hebraico"}}')}}]);