"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["6978"],{11753(a){a.exports=JSON.parse('{"wPLoginAttempts":"Pr\xf3by logowania do WP.","wPLoginAttemptsResetSuccess":"Pr\xf3by logowania do WP zosta\u0142y pomy\u015Blnie zresetowane.","errorTryAgain":"Co\u015B posz\u0142o nie tak, spr\xf3buj ponownie.","backupCreation":"Tworzenie kopii zapasowej.","backupCreated":"Kopia zapasowa witryny zosta\u0142a pomy\u015Blnie utworzona.","backupUpdate":"Kopia zapasowa witryny zosta\u0142a pomy\u015Blnie zaktualizowana.","backupUpdated":"Kopia zapasowa witryny zosta\u0142a pomy\u015Blnie zaktualizowana.","backupRestore":"Przywracanie kopii zapasowej.","backupDelete":"Usuwanie kopii zapasowej.","backupDeleted":"Kopia zapasowa zosta\u0142a usuni\u0119ta.","backupExport":"Eksport kopii zapasowej.","backupExportSuccessToast":"Wkr\xf3tce otrzymasz e-mail z linkiem do pobrania.","debugMode":"Tryb debugowania.","debugModeSwithFailed":"{value, select, true {Wy\u0142\u0105czenie} other {W\u0142\u0105czenie}} trybu debugowania nie powiod\u0142o si\u0119, spr\xf3buj ponownie.","siteDeletion":"Usuni\u0119cie witryny.","siteDeleted":"Witryna zosta\u0142a usuni\u0119ta.","setFavoriteSuccess":"{domain} zosta\u0142 dodany do Twoich ulubionych witryn.","removeFavoriteSuccess":"{domain} zosta\u0142 usuni\u0119ty z Twoich ulubionych witryn.","maxReachedFavorites":"Osi\u0105gni\u0119to maksymaln\u0105 liczb\u0119 ulubionych.","generalErrorToast":"Ups, co\u015B posz\u0142o nie tak. Spr\xf3buj ponownie p\xf3\u017Aniej.","websiteDeactivation":"Dezaktywacja witryny.","setDefaultPaymentFailed":"Nie uda\u0142o si\u0119 ustawi\u0107 domy\u015Blnej metody p\u0142atno\u015Bci.","actionFailedMessage":"Przepraszamy, to nie zadzia\u0142a\u0142o.","retryErrorMessage":"Przepraszamy, to nie zadzia\u0142a\u0142o. Spr\xf3buj ponownie.","addingDomainFailed":"Dodanie domeny nie powiod\u0142o si\u0119, spr\xf3buj ponownie.","removingDomainFailed":"Usuni\u0119cie domeny nie powiod\u0142o si\u0119, spr\xf3buj ponownie.","settingDomainPrimaryFailed":"Ustawienie domeny jako g\u0142\xf3wnej nie powiod\u0142o si\u0119, spr\xf3buj ponownie.","emailVerification":"Weryfikacja adresu e-mail.","emailAlreadyVerified":"Ten adres e-mail jest ju\u017C zweryfikowany.","emailVerificationSent":"Wys\u0142ano! Sprawd\u017A swoj\u0105 skrzynk\u0119 odbiorcz\u0105, aby znale\u017A\u0107 e-mail weryfikacyjny.","emailVerificationResendDelay":"Ju\u017C wys\u0142ali\u015Bmy e-mail weryfikacyjny do Twojej skrzynki odbiorczej. Je\u015Bli nadal nie mo\u017Cesz znale\u017A\u0107 wiadomo\u015Bci, mo\u017Cesz poprosi\u0107 o ponowne wys\u0142anie za 5 minut.","teamMemberRemoved":"{email} zosta\u0142 usuni\u0119ty z Twojego zespo\u0142u.","inviteSentTo":"Zaproszenie zosta\u0142o wys\u0142ane do {email}.","billingInfoUpdated":"Twoje informacje rozliczeniowe zosta\u0142y zaktualizowane.","subCanceledConfirmation":"Twoja subskrypcja zosta\u0142a anulowana, a zwrot jest przetwarzany. Sprawd\u017A swoj\u0105 skrzynk\u0119 e-mail, aby uzyska\u0107 szczeg\xf3\u0142owe informacje.","siteDomainRemoved":"Witryna {domain} zosta\u0142a usuni\u0119ta.","siteLockPassReset":"Resetowanie has\u0142a blokady witryny.","updatedSiteLockCode":"Tw\xf3j nowy kod blokady witryny to: {pass}.","contactSupport":"Skontaktuj si\u0119 z pomoc\u0105 techniczn\u0105.","srySomethingWrong":"Przepraszamy, co\u015B posz\u0142o nie tak.","subRefundFailed":"Twoja subskrypcja jest nadal aktywna, poniewa\u017C zwrot nie m\xf3g\u0142 zosta\u0107 przetworzony. Jeste\u015Bmy tutaj, aby pom\xf3c.","partialRefundMessage":"Tw\xf3j zwrot nie m\xf3g\u0142 zosta\u0107 w pe\u0142ni przetworzony, ale Twoja subskrypcja nie jest ju\u017C aktywna. Jeste\u015Bmy tutaj, aby pom\xf3c.","exitMaintenanceModeToastTitle":"Wyj\u015Bcie z trybu konserwacji.","exitMaintenanceModeToastText":"Witryna {slug} pomy\u015Blnie wysz\u0142a z trybu konserwacji."}')}}]);