.elementor-animation-skew-forward {
	transition-duration: 0.3s;
	transition-property: transform;
	transform-origin: 0 100%;
}
.elementor-animation-skew-forward:active,
.elementor-animation-skew-forward:focus,
.elementor-animation-skew-forward:hover {
	transform: skew(-10deg);
}
