"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_es_send-feedback_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/es/send-feedback.json":
/*!*************************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/es/send-feedback.json ***!
  \*************************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"dialog":{"title":"Comparta sus comentarios","fieldTitlePlaceholder":"Título","fieldDescriptionPlaceholder":"Díganos qué tenía en mente","fieldSubjectPlaceholder":"Seleccione el asunto de sus comentarios","fieldProductPlaceholder":"Seleccionar el producto","note":"¡Agradecemos sus comentarios! Aunque revisamos todas las sugerencias, no podemos garantizar que cada una de ellas resulte en un cambio o actualización.","subjects":{"leaveFeedback":"Enviar comentarios","reportBug":"Informar de un error","requestFeature":"Solicitar una función","shareThoughts":"Compartir cualquier otra idea"},"products":{"general":"General","editor":"Editor","accessibility":"Accesibilidad","imageOptimization":"Optimización de imágenes","emailDeliverability":"Capacidad de entrega de correo electrónico","siteManagement":"Site Management"},"cancel":"Cancelar","submit":"Enviar","titleLengthError":"El título debe tener menos de 90 caracteres","descriptionLengthError":"La descripción debe tener menos de 1024 caracteres","alert":{"title":"¿Necesita ayuda o ha tenido algún problema?","button":"Enviar un ticket de soporte"}},"tooltipSuccess":"Comentarios enviados. Gracias por su ayuda.","tooltipError":"Algo salió mal. Intente enviar sus comentarios de nuevo."}');

/***/ })

}]);