__( 'The default cache status for this element:', 'elementor' );
__( 'Inactive', 'elementor' );
__( 'Active', 'elementor' );
__( 'Activating cache improves loading times by storing a static version of this element.', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Inner Section', 'elementor' );
__( 'Preview', 'elementor' );
__( 'Delete All Content', 'elementor' );
__( 'Attention: We are going to DELETE ALL CONTENT from this page. Are you sure you want to do that?', 'elementor' );
__( 'Delete', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Server Error', 'elementor' );
__( 'Connection Lost', 'elementor' );
__( 'Unknown Error', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Go Back', 'elementor' );
__( 'Note: Flexbox Changes', 'elementor' );
__( 'Elementor 2.5 introduces key changes to the layout using CSS Flexbox. Your existing pages might have been affected, please review your page before publishing.', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Got It', 'elementor' );
__( 'This is just a draft. Play around and when you\'re done - click update.', 'elementor' );
__( 'View All Revisions', 'elementor' );
__( 'Your browser isn\'t compatible', 'elementor' );
__( 'Your browser isn\'t compatible with all of Elementor\'s editing features. We recommend you switch to another browser like Chrome or Firefox.', 'elementor' );
__( 'Proceed Anyway', 'elementor' );
__( 'Your site doesn\'t have a default kit', 'elementor' );
__( 'Seems like your kit was deleted, please create new one or try restore it from trash.', 'elementor' );
__( 'Recreate Kit', 'elementor' );
__( 'Go Back', 'elementor' );
__( 'Click here for preview debug', 'elementor' );
__( 'Sorry, the content area was not found in your page.', 'elementor' );
__( 'You must call \'the_content\' function in the current template, in order for Elementor to work on this page.', 'elementor' );
__( 'Paste', 'elementor' );
__( 'Copy All Content', 'elementor' );
__( 'Delete All Content', 'elementor' );
__( 'Typography', 'elementor' );
__( 'Create New Global Font', 'elementor' );
__( 'Container', 'elementor' );
__( 'Direction Column', 'elementor' );
__( 'Direction Row', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Elementor\'s New Icon Library', 'elementor' );
__( 'Elementor v2.6 includes an upgrade from Font Awesome 4 to 5. In order to continue using icons, be sure to click "Update".', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Update', 'elementor' );
__( 'Take Over', 'elementor' );
__( 'Take Over', 'elementor' );
__( 'Go Back', 'elementor' );
__( '%s has taken over and is currently editing. Do you want to take over this page editing?', 'elementor' );
__( 'Sorry, you can\'t upload that file yet', 'elementor' );
__( 'This is because JSON files may pose a security risk.', 'elementor' );
__( 'To upload them anyway, ask the site administrator to enable unfiltered file uploads.', 'elementor' );
__( 'Got it', 'elementor' );
__( 'Enable Unfiltered File Uploads', 'elementor' );
__( 'Before you enable unfiltered files upload, note that such files include a security risk. Elementor does run a process to remove possible malicious code, but there is still risk involved when using such files.', 'elementor' );
__( 'Enable', 'elementor' );
__( 'Enable Unfiltered File Uploads', 'elementor' );
__( 'Before you enable unfiltered files upload, note that such files include a security risk. Elementor does run a process to remove possible malicious code, but there is still risk involved when using such files.', 'elementor' );
__( 'If you do not enable uploading unfiltered files, any SVG or JSON (including lottie) files used in the uploaded template will not be imported.', 'elementor' );
__( 'Enable and Import', 'elementor' );
__( 'Import Without Enabling', 'elementor' );
__( 'Container', 'elementor' );
__( 'Clear', 'elementor' );
__( 'Color Picker', 'elementor' );
__( 'Create New Global Color', 'elementor' );
__( 'Item', 'elementor' );
__( 'Item #%s', 'elementor' );
__( 'New Typography Setting', 'elementor' );
__( 'Are you sure you want to create a new Global Font setting?', 'elementor' );
__( 'Atomic Classes', 'elementor' );
__( 'Global Fonts', 'elementor' );
__( 'Insert Media', 'elementor' );
__( 'Insert Media', 'elementor' );
__( 'Elementor\'s New Icon Library', 'elementor' );
__( 'Elementor v2.6 includes an upgrade from Font Awesome 4 to 5. In order to continue using icons, be sure to click "Update".', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Update', 'elementor' );
__( 'Insert Media', 'elementor' );
__( 'Insert Media', 'elementor' );
__( '%s Images Selected', 'elementor' );
__( 'No Images Selected', 'elementor' );
__( 'Insert Media', 'elementor' );
__( 'Are you sure you want to clear this gallery?', 'elementor' );
__( 'Clear gallery', 'elementor' );
__( 'Clear', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Invalid Global Color', 'elementor' );
__( 'Color Sampler', 'elementor' );
__( 'Please note that the same exact color already exists in your Global Colors list. Are you sure you want to create it?', 'elementor' );
__( 'Are you sure you want to create a new Global Color?', 'elementor' );
__( 'New Global Color', 'elementor' );
__( 'Are you sure you want to create a new Global Color?', 'elementor' );
__( 'Atomic Variables', 'elementor' );
__( 'Global Colors', 'elementor' );
__( 'Add new layout element', 'elementor' );
__( 'Paste', 'elementor' );
__( 'Paste from other site', 'elementor' );
__( 'Copy All Content', 'elementor' );
__( 'Delete All Content', 'elementor' );
__( 'Grid', 'elementor' );
__( 'Check out Global Fonts', 'elementor' );
__( 'Save time by applying Global Fonts to change the style of multiple elements at once. Click %s to see what Global Fonts you already have.', 'elementor' );
__( 'Got it!', 'elementor' );
__( 'Check out Global Colors', 'elementor' );
__( 'Save time by applying Global Colors to change the style of multiple elements at once. Click %s to see what Global Colors you already have.', 'elementor' );
__( 'Got it!', 'elementor' );
__( 'The value inserted isn\'t in the breakpoint boundaries', 'elementor' );
__( 'Show Panel', 'elementor' );
__( 'Hide Panel', 'elementor' );
__( 'Custom Positioning', 'elementor' );
__( 'Collapse all elements', 'elementor' );
__( 'Expand all elements', 'elementor' );
__( 'Save as a global', 'elementor' );
__( 'Add %s', 'elementor' );
__( 'Edit %s', 'elementor' );
__( 'Duplicate %s', 'elementor' );
__( 'Save as a template', 'elementor' );
__( 'New', 'elementor' );
__( 'Save as a template', 'elementor' );
__( 'New', 'elementor' );
__( 'Add New Container', 'elementor' );
__( 'Add %s', 'elementor' );
__( 'Edit %s', 'elementor' );
__( 'Duplicate %s', 'elementor' );
__( 'Delete %s', 'elementor' );
__( 'Edit %s', 'elementor' );
__( 'Container', 'elementor' );
__( 'Grid', 'elementor' );
__( 'Edit %s', 'elementor' );
__( 'Duplicate %s', 'elementor' );
__( 'Add %s', 'elementor' );
__( 'Add New Column', 'elementor' );
__( 'Paste', 'elementor' );
__( 'Edit %s', 'elementor' );
__( 'Duplicate', 'elementor' );
__( 'Copy', 'elementor' );
__( 'Paste', 'elementor' );
__( 'Paste style', 'elementor' );
__( 'Paste interactions', 'elementor' );
__( 'Paste from other site', 'elementor' );
__( 'Reset style', 'elementor' );
__( 'Delete %d items', 'elementor' );
__( 'Delete', 'elementor' );
__( 'Delete %s', 'elementor' );
__( 'Edit %s', 'elementor' );
__( 'Duplicate %s', 'elementor' );
__( 'Please note: All unsaved changes will be lost.', 'elementor' );
__( 'Elements', 'elementor' );
__( 'Save', 'elementor' );
__( "You can save it to %1$sCloud Templates%2$s to reuse across any of your Elementor sites at any time%3$sor to %4$sSite Templates%5$s so it's always ready when editing this website.", 'elementor' );
__( 'Save page', 'elementor' );
__( 'Store your design in %1$sCloud Templates%2$s for future Elementor projects. Or save it to %3$sSite Templates%4$s, to reuse anywhere on this site.', 'elementor' );
__( 'Page', 'elementor' );
__( 'Section', 'elementor' );
__( 'Container', 'elementor' );
__( 'Alternatively, you can copy the template.', 'elementor' );
__( 'Move', 'elementor' );
__( 'Alternatively, you can move the template.', 'elementor' );
__( 'Copy', 'elementor' );
__( 'Alternatively, you can copy the templates.', 'elementor' );
__( 'Move templates to a different location', 'elementor' );
__( 'Move', 'elementor' );
__( 'Alternatively, you can move the templates.', 'elementor' );
__( 'Copy templates to a different location', 'elementor' );
__( 'Copy', 'elementor' );
__( '%s name', 'elementor' );
__( 'Type the page name here', 'elementor' );
__( 'Give your template a name', 'elementor' );
__( 'Save this %s to your library', 'elementor' );
__( 'Where would you like to save this %s?', 'elementor' );
__( 'Move your %s to a different location', 'elementor' );
__( 'Where would you like to move this %s?', 'elementor' );
__( 'Copy your %s to a different location', 'elementor' );
__( 'Where would you like to cppy this %s?', 'elementor' );
__( 'Where would you like to move selected templates?', 'elementor' );
__( 'Where would you like to copy selected templates?', 'elementor' );
__( 'Undo', 'elementor' );
__( 'Rename "%1$s"', 'elementor' );
__( 'Rename', 'elementor' );
__( 'You can not create a folder inside another folder.', 'elementor' );
__( 'Save assets to reuse on any site in your account.', 'elementor' );
__( 'Folder name', 'elementor' );
__( 'Create a new folder', 'elementor' );
__( 'Create', 'elementor' );
__( 'Delete this folder?', 'elementor' );
__( 'This will permanently delete "%1$s" that contains %2$d templates.', 'elementor' );
__( 'Delete', 'elementor' );
__( 'Delete items?', 'elementor' );
__( 'This will permanently remove %1$s selected items.', 'elementor' );
__( 'Delete', 'elementor' );
__( 'Delete this template?', 'elementor' );
__( 'This will permanently remove "%1$s".', 'elementor' );
__( 'Delete', 'elementor' );
__( 'An error occurred.', 'elementor' );
__( 'The following error(s) occurred while processing the request:', 'elementor' );
__( 'Please try again.', 'elementor' );
__( 'Undo', 'elementor' );
__( 'You\'ve saved %1$d%% of the templates in your plan. To get more space ', 'elementor' );
__( 'Upgrade now', 'elementor' );
__( 'You\'ve saved %1$d%% of the templates in your plan. To get more space ', 'elementor' );
__( 'Upgrade now', 'elementor' );
__( 'Blocks', 'elementor' );
__( 'Pages', 'elementor' );
__( 'Templates', 'elementor' );
__( 'Connect to Template Library', 'elementor' );
__( 'Access this template and our entire library by creating a free personal account', 'elementor' );
__( 'Get Started', 'elementor' );
__( 'Apply the settings of this %s too?', 'elementor' );
__( 'This will override the design, layout, and other settings of the %s you’re working on.', 'elementor' );
__( 'Apply', 'elementor' );
__( 'Don’t apply', 'elementor' );
__( 'Some styles were added as static values because the style limits were reached.', 'elementor' );
__( 'Some styles were added as static values because the class limit was reached.', 'elementor' );
__( 'Some styles were added as static values because the variable limit was reached.', 'elementor' );
__( 'Icon Library', 'elementor' );
__( 'Insert', 'elementor' );
__( 'Keyboard Shortcuts', 'elementor' );
__( 'Dynamic Content', 'elementor' );
__(
					'Create more personalized and dynamic sites by populating data from various sources with dozens of dynamic tags to choose from.',
					'elementor',
				),
				targetElement: this.ui.dynamicSwitcher,
				position: {
					blockStart: '-10',
				},
				actionButton: {
					url: hasProAndNotConnected
						? elementorProEditorConfig.urls.connect
						: elementor.config.dynamicPromotionURL.replace( '%s', this.view.model.get( 'name' ) ),
					text: hasProAndNotConnected
						? __( 'Connect & Activate', 'elementor' );
__( 'Upgrade', 'elementor' );
__( 'Cannot load editor', 'elementor' );
__( 'Server Error', 'elementor' );
__( 'Type Here', 'elementor' );
__( 'Structure', 'elementor' );
__( 'Link copied!', 'elementor' );
__( 'Copy and share Link', 'elementor' );
__( 'Publish', 'elementor' );
__( 'Update', 'elementor' );
__( 'Submit', 'elementor' );
__( 'Item #%d', 'elementor' );
__( 'Item', 'elementor' );
__( 'Item', 'elementor' );
__( 'Item', 'elementor' );
__( 'Item', 'elementor' );
__( 'Elements', 'elementor' );
__( 'To paste the element from your other site.', 'elementor' );
__( 'Make sure that both sites are updated to last version of Elementor and have enabled the features relevant to the copied element before trying again.', 'elementor' );
__( 'Template', 'elementor' );
__( 'All Content', 'elementor' );
__( 'That didn’t work. Try duplicating one kind of element at a time.', 'elementor' );
__( 'Got it', 'elementor' );
__( 'That didn’t work. Try copying one kind of element at a time.', 'elementor' );
__( 'Got it', 'elementor' );
__( 'Library', 'elementor' );
__( 'template', 'elementor' );
__( 'templates', 'elementor' );
__( 'selected. Bulk actions available.', 'elementor' );
__( 'Settings', 'elementor' );
__( 'Style', 'elementor' );
__( 'Advanced', 'elementor' );
__( 'Become a Pro user to upload unlimited font icon folders to your website.', 'elementor' );
__( 'Upgrade Now', 'elementor' );
__( 'My Libraries', 'elementor' );
__( 'Upload', 'elementor' );
__( 'You are leaving to a separate site part.', 'elementor' );
__( 'Save your changes before moving on because the current document and the one you’re moving to are separate site parts.', 'elementor' );
__( 'Save & leave', 'elementor' );
__( 'Don\'t leave', 'elementor' );
__( 'More', 'elementor' );
__( 'Navigate From Page', 'elementor' );
__( 'View Page', 'elementor' );
__( 'Settings', 'elementor' );
__( 'User Preferences', 'elementor' );
__( 'Finder', 'elementor' );
__( 'Add-ons', 'elementor' );
__( 'Exit', 'elementor' );
__( 'New options for "Exit to..."', 'elementor' );
__( 'Apply', 'elementor' );
__( 'Decide Later', 'elementor' );
__( 'Elements', 'elementor' );
__( 'Global', 'elementor' );
__( 'Content', 'elementor' );
__( 'Style', 'elementor' );
__( 'Advanced', 'elementor' );
__( 'Layout', 'elementor' );
__( 'Edit %s', 'elementor' );
__( 'Saving has been disabled until you’re reconnected.', 'elementor' );
__( 'Server Error', 'elementor' );
__( 'Elements', 'elementor' );
__( 'Select template', 'elementor' );
__( '%1$s of %2$s templates used', 'elementor' );
__( 'Name', 'elementor' );
__( 'Type', 'elementor' );
__( 'Created By', 'elementor' );
__( 'Creation Date', 'elementor' );
__( 'descending', 'elementor' );
__( 'ascending', 'elementor' );
__( 'Sorted by', 'elementor' );
__( 'more templates loaded', 'elementor' );
__( 'Category', 'elementor' );
__( 'connected', 'elementor' );
__( 'Only %s Elementor account can access Cloud Templates from any connected site.', 'elementor' );
__( 'Authorized users on this site can access Site Templates.', 'elementor' );
__( 'Haven’t Saved Templates Yet?', 'elementor' );
__( 'This is where your templates should be. Design it. Save it. Reuse it.', 'elementor' );
__( 'No Results Found', 'elementor' );
__( 'Please make sure your search is spelled correctly or try a different words.', 'elementor' );
__( 'No Favorite Templates', 'elementor' );
__( 'You can mark any pre-designed template as a favorite.', 'elementor' );
__( 'No templates saved just yet', 'elementor' );
__( 'Once you save a template, it’ll show up here, ready for reuse across all of your Elementor sites—no extra work needed.', 'elementor' );
__( 'Back to editor', 'elementor' );
__( 'No templates to show here, yet', 'elementor' );
__( 'Once you save some templates to this folder, you can use them on any website you’re working on.', 'elementor' );
__( 'Back to editor', 'elementor' );
__( 'An error occurred.', 'elementor' );
__( 'Please select at least one location.', 'elementor' );
__( 'Template saved to your Site and Cloud Templates.', 'elementor' );
__( '%1$d Template(s) %2$s.', 'elementor' );
__( '%1$s %2$s.', 'elementor' );
__( 'Template', 'elementor' );
__( 'View', 'elementor' );
__( 'Load More', 'elementor' );
__( 'Upgrade your subscription to get more space and reuse saved assets across all your sites.', 'elementor' );
__( 'Upgrade your subscription to access Cloud Templates and reuse saved assets across all your sites.', 'elementor' );
__(
					'Upgrade Now',
					'elementor',
				),
				classes: '',
				callback: () => {
					open( goLink, '_blank' );
__(
					'To access the Cloud Templates Library you must have an active Elementor Pro subscription',
					'elementor',
				) +
				' <i>' +
				__(
					'and',
					'elementor',
				) +
				'</i> ' +
				__(
					'connect your site.',
					'elementor',
				),
			);

		this.connectInfoTipDialog.getElements( 'header' ).remove();
		this.connectInfoTipDialog.getElements( 'buttonsWrapper' ).remove();

		this.addVariantClass( this.connectInfoTipDialog.getElements( 'widget' ) );
		this.connectInfoTipDialog.show();
	},

	addVariantClass() {
		return '';
	},

	hideConnectInfoTip() {
		if ( this.connectInfoTipDialog ) {
			this.connectInfoTipDialog.hide();
		}
	},

	handleElementorConnect() {
		elementor.templates.eventManager.sendPageViewEvent( {
			location: elementorCommon.eventsManager.config.secondaryLocations.templateLibrary.saveModalSelectConnect,
		} );

		this.ui.connect.elementorConnect( {
			success: () => {
				elementor.config.library_connect.is_connected = true;

				$e.run( 'library/close' );
				elementor.notifications.showToast( {
					message: __( 'Connected successfully.', 'elementor' );
__( 'Upgrade your subscription to get more space and reuse saved assets across all your sites.', 'elementor' );
__( 'Upgrade your subscription to access Cloud Templates and reuse saved assets across all your sites.', 'elementor' );
__( 'connected', 'elementor' );
__( 'Only %s Elementor account can access Cloud Templates from any connected site.', 'elementor' );
__( 'Authorized users on this site can access Site Templates.', 'elementor' );
__( 'You successfully imported %1$d template(s).', 'elementor' );
__( 'Connected successfully.', 'elementor' );
__( 'Connect to your Elementor account', 'elementor' );
__( 'Then you can find all your templates in one convenient library.', 'elementor' );
__( 'Connect', 'elementor' );
__( 'It’s time to level up', 'elementor' );
__( 'Elementor Pro plans come with Cloud Templates.', 'elementor' );
__( 'Upgrade now to re-use your templates on all the websites you’re working on.', 'elementor' );
__( 'Upgrade now', 'elememntor' );
__( 'Upgrade now', 'elementor' );
__( 'Your library has been deactivated', 'elementor' );
__( 'This is because you don’t have an active subscription.', 'elementor' );
__( 'Your templates are saved for 90 days from the day your subscription expires,', 'elementor' );
__( 'then they’ll be gone forever.', 'elementor' );
__( 'Renew my subscription', 'elememntor' );
__( 'Renew my subscription', 'elementor' );
__( 'Empty folder', 'elememntor' );
__( 'Connected successfully.', 'elementor' );
__( 'Have a look', 'elementor' );
__( 'Library sections', 'elementor' );
__( 'Folders you create will appear here.', 'elementor' );
__( 'To create a new one, go to Cloud Templates.', 'elementor' );