.elementor-animation-rotate {
	transition-duration: 0.3s;
	transition-property: transform;
}
.elementor-animation-rotate:active,
.elementor-animation-rotate:focus,
.elementor-animation-rotate:hover {
	transform: rotate(4deg);
}
