__( 'class', 'elementor' );
__( 'classes', 'elementor' );
__( 'Convert to global class', 'elementor' );
__( 'Sync class to Global Fonts', 'elementor' );
__(
							'Only typography settings supported in Global Fonts will be applied, including: font family, responsive font sizes, weight, text transform, decoration, line height, letter spacing, and word spacing. Changes made in the class will automatically apply to Global Fonts.',
							'elementor'
						);
__( "Don't show again", 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Sync to Global Fonts', 'elementor' );
__( 'Sorry, nothing matched.', 'elementor' );
__( 'Try something else.', 'elementor' );
__( 'Sorry, nothing matched', 'elementor' );
__( 'Clear your input and try something else.', 'elementor' );
__( 'Sorry, nothing matched that search.', 'elementor' );
__( 'Clear the filters and try something else.', 'elementor' );
__( 'Clear & try again', 'elementor' );
__( 'There are no global classes yet.', 'elementor' );
__(
				'CSS classes created in the editor panel will appear here. Once they are available, you can arrange their hierarchy, rename them, or delete them as needed.',
				'elementor'
			);
__( "We've published your page and updated class names.", 'elementor' );
__(
							'Some new classes used the same names as existing ones. To prevent conflicts, we added the prefix',
							'elementor'
						);
__( 'Before', 'elementor' );
__( 'After', 'elementor' );
__( 'Your designs and classes are safe.', 'elementor' );
__(
									'Only the prefixes were added. Find them in Class Manager by searching',
									'elementor'
								);
__( 'Go to Class Manager', 'elementor' );
__( 'Done', 'elementor' );
// translators: %1: total usage count, %2: number of pages
__(
					'Will permanently remove it from your project and may affect the design across all elements using it. Used %1 times across %2 pages. This action cannot be undone.',
					'elementor'
			  );
__(
					'Will permanently remove it from your project and may affect the design across all elements using it. This action cannot be undone.',
					'elementor'
			  );
__( 'Delete this class?', 'elementor' );
__( 'Deleting', 'elementor' );
__( 'Save changes', 'elementor' );
__( 'You have unsaved changes', 'elementor' );
__( 'You have unsaved changes in the Class Manager.', 'elementor' );
__( 'To avoid losing your updates, save your changes before leaving.', 'elementor' );
__( 'Discard', 'elementor' );
__( 'Save & Continue', 'elementor' );
__( 'Class Manager', 'elementor' );
__( 'Something went wrong', 'elementor' );
__( 'Un-sync typography class', 'elementor' );
__( "You're about to stop syncing a typography class to Global Fonts.", 'elementor' );
__(
						"Note that if it's being used anywhere, the affected elements will inherit the default typography.",
						'elementor'
					);
__( 'Cancel', 'elementor' );
__( 'Got it', 'elementor' );
__( "Don't show again", 'elementor' );
__( 'Class Manager', 'elementor' );
__(
					"The Class Manager lets you see all the classes you've created, plus adjust their priority, rename them, and delete unused classes to keep your CSS structured.",
					'elementor'
				);
__(
					'Remember, when editing an item within a specific class, any changes you make will apply across all elements in that class.',
					'elementor'
				);
__( 'Class Manager', 'elementor' );
__( 'You have unsaved changes', 'elementor' );
__(
								"To open the Class Manager, save your page first. You can't continue without saving.",
								'elementor'
							);
__( 'Stay here', 'elementor' );
__( 'Save & Continue', 'elementor' );
__( 'More actions', 'elementor' );
__( 'Rename', 'elementor' );
__( 'Stop syncing to Global Fonts', 'elementor' );
__( 'Sync to Global Fonts', 'elementor' );
__( 'Delete', 'elementor' );
__( 'Show {{number}} {{locations}}', 'elementor' );
__( 'location', 'elementor' );
__( 'locations', 'elementor' );
__( 'This class isn’t being used yet.', 'elementor' );
__( 'Post', 'elementor' );
__( 'Page', 'elementor' );
__( 'Popup', 'elementor' );
__( 'Header', 'elementor' );
__( 'Footer', 'elementor' );
__( 'Locator', 'elementor' );
__( 'Search', 'elementor' );
__( 'Unused', 'elementor' );
__( 'Empty', 'elementor' );
__( 'On this page', 'elementor' );
__( 'Filters', 'elementor' );
__( 'Clear all', 'elementor' );
__( 'Filters', 'elementor' );
__( 'Clear Filters', 'elementor' );