"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["1832"],{7051(e){e.exports=JSON.parse('{"header":"URL no coincide","title":"\xbfC\xf3mo desea continuar?","description":"Su clave de licencia no coincide con su dominio actual, lo que provoca una falta de coincidencia.{br}Esto se debe muy probablemente a un cambio en la URL del dominio de su sitio.","actions":{"updateCurrentSite":{"title":"Actualizar la URL conectada","description":"Para cambios de URL en el mismo sitio, como de staging a producci\xf3n o de HTTP a HTTPS.","action":"Actualizar URL conectada"},"connectNewSite":{"title":"Conectar la URL como un nuevo sitio","description":"Para conectar un sitio completamente diferente. El historial anterior se eliminar\xe1.","action":"Conectar como un nuevo sitio"}}}')}}]);