<?php


namespace Nextend\Framework\Form\Element\Text;


use Nextend\Framework\Asset\Js\Js;
use Nextend\Framework\Image\ImageManager;
use Nextend\Framework\View\Html;

class FieldImageResponsive extends FieldImage {

    protected function fetchElement() {

        $html = parent::fetchElement();

        return $html;
    }
}