.elementor-62 .elementor-element.elementor-element-0fa78b6 > .elementor-background-overlay{opacity:0.58;transition:background 0.3s, border-radius 0.3s, opacity 0.3s;}.elementor-62 .elementor-element.elementor-element-0fa78b6{transition:background 0.3s, border 0.3s, border-radius 0.3s, box-shadow 0.3s;margin-top:37px;margin-bottom:0px;padding:0px 0px 0px 0px;}.elementor-widget-text-editor{font-family:var( --e-global-typography-text-font-family ), Sans-serif;font-weight:var( --e-global-typography-text-font-weight );color:var( --e-global-color-text );}.elementor-widget-text-editor.elementor-drop-cap-view-stacked .elementor-drop-cap{background-color:var( --e-global-color-primary );}.elementor-widget-text-editor.elementor-drop-cap-view-framed .elementor-drop-cap, .elementor-widget-text-editor.elementor-drop-cap-view-default .elementor-drop-cap{color:var( --e-global-color-primary );border-color:var( --e-global-color-primary );}.elementor-62 .elementor-element.elementor-element-171388c{color:#000000;}.elementor-62 .elementor-element.elementor-element-e1e4075{margin-top:0px;margin-bottom:0px;}.elementor-widget-image .widget-image-caption{color:var( --e-global-color-text );font-family:var( --e-global-typography-text-font-family ), Sans-serif;font-weight:var( --e-global-typography-text-font-weight );}.elementor-62 .elementor-element.elementor-element-448df92{color:#000000;}.elementor-62 .elementor-element.elementor-element-0c78b59{color:#000000;}