"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_pt-PT_assets-whatsnew_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/pt-PT/assets-whatsnew.json":
/*!******************************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/pt-PT/assets-whatsnew.json ***!
  \******************************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"4.0-default":{"title":"O novo predefinido","description":"Os novos sites começam na versão 4.0 com funcionalidades atómicas ativadas por predefinição. Os sites existentes podem ativar manualmente. Os seus layouts e sites atuais não mudam.","topic":"Versão 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"4.0-atomic-forms":{"title":"Formulários atómicos","description":"Crie formulários como parte do layout, não como widgets separados. Layouts flexíveis em várias colunas, aninhamento livre e controlo total com o mesmo sistema atómico.","topic":"Versão 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"4.0-interactions":{"title":"Interações Pro","description":"Crie movimento avançado e leve no Editor. Defina o comportamento de forma visual, tudo com base no sistema, sem scripts pesados ou ferramentas externas.","topic":"Versão 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"4.0-sync-design-system":{"title":"Sincronize e partilhe design systems","description":"Exporte e importe variáveis e classes entre sites e sincronize com Global Styles v3. Design consistente em projetos e versões.","topic":"Versão 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"angie-launch":{"title":"Apresentamos o Angie Code.","description":"Crie widgets Elementor e excertos a partir de uma descrição. Nativo para WordPress e Elementor. Pré-visualize com segurança, refine na conversa e publique quando estiver pronto.","topic":"Angie Code","chipTags":["Novo lançamento"],"readMoreText":"Saiba mais","cta":""},"partner-program":{"title":"Seja parceiro da Elementor. Desenvolva o seu negócio.","description":"Aceda a benefícios exclusivos, visibilidade, oportunidades de marketing e receitas adicionais com o trabalho que já fez. Adira gratuitamente e comece já.","chipTags":["Programa de parceiros"],"readMoreText":"","cta":"Candidatar-se"},"manage-launch":{"title":"Apresentamos o Manage","description":"Monitorize, otimize e mantenha todos os sites a partir de um painel central. Acompanhe o desempenho, atualizações em massa e riscos de segurança.","chipTags":["Novo lançamento"],"readMoreText":"","cta":"Começar grátis"},"components-3.35":{"title":"Componentes","description":"Secções modulares reutilizáveis que se atualizam em todo o lado e decide quanto controlo cede à equipa ou clientes.","topic":"Versão 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"one-launch":{"title":"Apresentamos o Elementor One","description":"A experiência completa para criar sites. Ferramentas para criar, otimizar e gerir, unificadas num único sítio.","chipTags":["Novo lançamento"],"readMoreText":"","cta":"Explorar o Elementor One"},"atomic-tabs-3.34":{"title":"Separadores atómicos","description":"Coloque qualquer conteúdo nos separadores, com um design verdadeiramente atómico.","topic":"Versão 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"variables-manager-3.33":{"title":"Gestor de variáveis","description":"Centralize cores, tipografia e tokens de tamanho para design systems coerentes e escaláveis.","topic":"Versão 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"ally-assistant":{"title":"Novo: acessibilidade com Ally Assistant","description":"Analise qualquer página e corrija com um clique: contraste, texto alternativo e mais. Passos orientados ou correção com IA para um sítio mais inclusivo.","topic":"Ally by Elementor","chipTags":["Nova funcionalidade"],"readMoreText":"","cta":"Analisar grátis"},"image-optimizer-3.19":{"title":"Otimize imagens com facilidade para um sítio rápido e impactante com o plugin Image Optimizer.","description":"O Image Optimizer equilibra qualidade e desempenho. Redimensione, comprima, converta para WebP: carregamento mais rápido, melhor experiência.","topic":"Image Optimizer Plugin by Elementor","chipTags":["Novo plugin"],"readMoreText":"","cta":"Obter o Image Optimizer"},"5-star-rating-prompt":{"title":"Gosta das novidades? Dê-nos 5 estrelas","description":"Conte ao mundo o que gosta no Elementor.","chipTags":[],"readMoreText":"","cta":"Deixar avaliação"},"site-mailer-introducing":{"title":"Apresentamos o Site Mailer","description":"Mantenha o e-mail do WordPress fora do spam: melhor entrega e configuração simples, sem plugin SMTP complicado.","topic":"Site Mailer Plugin by Elementor","chipTags":["Novo plugin"],"readMoreText":"","cta":"Iniciar teste grátis"}}');

/***/ })

}]);