"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["7275"],{67414(e){e.exports=JSON.parse('{"dialog":{"title":"Comparta sus comentarios","fieldTitlePlaceholder":"T\xedtulo","fieldDescriptionPlaceholder":"D\xedganos qu\xe9 ten\xeda en mente","fieldSubjectPlaceholder":"Seleccione el asunto de sus comentarios","fieldProductPlaceholder":"Seleccionar el producto","note":"\xa1Agradecemos sus comentarios! Aunque revisamos todas las sugerencias, no podemos garantizar que cada una de ellas resulte en un cambio o actualizaci\xf3n.","subjects":{"leaveFeedback":"Enviar comentarios","reportBug":"Informar de un error","requestFeature":"Solicitar una funci\xf3n","shareThoughts":"Compartir cualquier otra idea"},"products":{"general":"General","editor":"Editor","accessibility":"Accesibilidad","imageOptimization":"Optimizaci\xf3n de im\xe1genes","emailDeliverability":"Capacidad de entrega de correo electr\xf3nico","siteManagement":"Site Management"},"cancel":"Cancelar","submit":"Enviar","titleLengthError":"El t\xedtulo debe tener menos de 90 caracteres","descriptionLengthError":"La descripci\xf3n debe tener menos de 1024 caracteres","alert":{"title":"\xbfNecesita ayuda o ha tenido alg\xfan problema?","button":"Enviar un ticket de soporte"}},"tooltipSuccess":"Comentarios enviados. Gracias por su ayuda.","tooltipError":"Algo sali\xf3 mal. Intente enviar sus comentarios de nuevo."}')}}]);