"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_fr_common_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/fr/common.json":
/*!******************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/fr/common.json ***!
  \******************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"example":{"component":"Composant exemple"},"header":{"title":"constructeur de site Web","userInfo":"Mon compte","userProfileMenu":{"connectPreText":"Vous avez un forfait Elementor One ?","connect":"Connecter","goToMyAccount":"Allez sur Mon compte","disconnect":"Déconnecter","elementorOneActive":"Élémentor Un","active":"Actif","urlMismatch":"Incohérence d\'URL détectée","fixUrlMismatch":"Réparer maintenant"},"whatsNew":"Quoi de neuf","whatsNewError":"Une erreur s\'est produite lors de la récupération des notifications. Veuillez réessayer plus tard."}}');

/***/ })

}]);