"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_en_common_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/en/common.json":
/*!******************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/en/common.json ***!
  \******************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"header":{"title":"website builder","userInfo":"My account","userProfileMenu":{"connectPreText":"Have an Elementor One plan?","connect":"Connect","goToMyAccount":"Go to My account","disconnect":"Disconnect","elementorOneActive":"Elementor One","active":"Active","urlMismatch":"URL mismatch detected","fixUrlMismatch":"Fix now"},"whatsNew":"What\'s new","whatsNewError":"Something went wrong while fetching the notifications. Please try again later."}}');

/***/ })

}]);