"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["5768"],{73419(e){e.exports=JSON.parse('{"downloadInvoice404":{"title":"Twoja faktura jest przetwarzana","message":"Wy\u015Blemy j\u0105 do Ciebie e-mailem, gdy b\u0119dzie gotowa."},"supportedLanguages":{"en":"Angielski","de":"Niemiecki","es":"Hiszpa\u0144ski","it":"W\u0142oski","nl":"Niderlandzki","pt-PT":"Portugalski","pt-BR":"Portugalski (Brazylia)","fr":"Francuski","he-IL":"\u05E2\u05D1\u05E8\u05D9\u05EA"}}')}}]);