"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["5359"],{58658(a){a.exports=JSON.parse('{"header":"URL uyu\u015Fmazl\u0131\u011F\u0131","title":"Nas\u0131l devam etmek istersiniz?","description":"Lisans anahtar\u0131n\u0131z mevcut alan ad\u0131n\u0131zla e\u015Fle\u015Fmiyor ve bu da bir uyu\u015Fmazl\u0131\u011Fa neden oluyor.{br}Bu durum b\xfcy\xfck olas\u0131l\u0131kla sitenizin alan ad\u0131 URL\'sindeki bir de\u011Fi\u015Fiklikten kaynaklanmaktad\u0131r.","actions":{"updateCurrentSite":{"title":"Ba\u011Fl\u0131 URL\'yi g\xfcncelle","description":"Ayn\u0131 sitedeki URL de\u011Fi\u015Fiklikleri i\xe7in (\xf6r. haz\u0131rl\u0131k ortam\u0131ndan \xfcretim ortam\u0131na veya HTTP\'den HTTPS\'ye ge\xe7i\u015F).","action":"Ba\u011Fl\u0131 URL\'yi g\xfcncelle"},"connectNewSite":{"title":"URL\'yi yeni bir site olarak ba\u011Fla","description":"Tamamen farkl\u0131 bir siteyi ba\u011Flamak i\xe7in. \xd6nceki ge\xe7mi\u015F kald\u0131r\u0131lacakt\u0131r.","action":"Yeni bir site olarak ba\u011Fla"}}}')}}]);