"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9902"],{82157(e){e.exports=JSON.parse('{"wPLoginAttempts":"WP giri\u015F denemeleri.","wPLoginAttemptsResetSuccess":"WP giri\u015F denemeleri ba\u015Far\u0131yla s\u0131f\u0131rland\u0131.","errorTryAgain":"Bir \u015Feyler yanl\u0131\u015F gitti, l\xfctfen tekrar deneyin.","backupCreation":"Yedekleme olu\u015Fturma.","backupCreated":"Site yedeklemesi ba\u015Far\u0131yla olu\u015Fturuldu.","backupUpdate":"Site yedeklemesi ba\u015Far\u0131yla g\xfcncellendi.","backupUpdated":"Site yedeklemesi ba\u015Far\u0131yla g\xfcncellendi.","backupRestore":"Yedekleme geri y\xfckleme.","backupDelete":"Yedekleme silme.","backupDeleted":"Yedekleme silindi.","backupExport":"Yedekleme d\u0131\u015Fa aktarma.","backupExportSuccessToast":"K\u0131sa s\xfcre i\xe7inde indirme ba\u011Flant\u0131s\u0131 i\xe7eren bir e-posta alacaks\u0131n\u0131z.","debugMode":"Hata ay\u0131klama modu.","debugModeSwithFailed":"Hata ay\u0131klama modunu {value, select, true {devre d\u0131\u015F\u0131 b\u0131rakma} other {etkinle\u015Ftirme}} ba\u015Far\u0131s\u0131z oldu, l\xfctfen tekrar deneyin.","siteDeletion":"Site kald\u0131rma.","siteDeleted":"Site kald\u0131r\u0131ld\u0131.","setFavoriteSuccess":"{domain} favori sitelerinize eklendi.","removeFavoriteSuccess":"{domain} favori sitelerinizden kald\u0131r\u0131ld\u0131.","maxReachedFavorites":"Maksimum favori say\u0131s\u0131na ula\u015Ft\u0131n.","generalErrorToast":"Hata! \u0130\u015Flem ba\u015Far\u0131s\u0131z oldu. L\xfctfen daha sonra tekrar dene.","websiteDeactivation":"Website devre d\u0131\u015F\u0131 b\u0131rakma.","setDefaultPaymentFailed":"Varsay\u0131lan \xf6deme y\xf6ntemi ayarlanamad\u0131.","actionFailedMessage":"\xdczg\xfcn\xfcz, bu i\u015Flem ba\u015Far\u0131s\u0131z oldu.","retryErrorMessage":"\xdczg\xfcn\xfcz, bu i\u015Flem ba\u015Far\u0131s\u0131z oldu. Tekrar deneyin.","addingDomainFailed":"Alan ad\u0131 ekleme ba\u015Far\u0131s\u0131z oldu, l\xfctfen tekrar deneyin.","removingDomainFailed":"Alan ad\u0131 kald\u0131rma ba\u015Far\u0131s\u0131z oldu, l\xfctfen tekrar deneyin.","settingDomainPrimaryFailed":"Alan ad\u0131n\u0131 birincil olarak ayarlama ba\u015Far\u0131s\u0131z oldu, l\xfctfen tekrar deneyin.","emailVerification":"E-posta do\u011Frulama.","emailAlreadyVerified":"E-posta zaten do\u011Frulanm\u0131\u015F.","emailVerificationSent":"G\xf6nderildi! Do\u011Frulama e-postas\u0131 i\xe7in gelen kutunuzu kontrol edin.","emailVerificationResendDelay":"Gelen kutunuza zaten bir do\u011Frulama e-postas\u0131 g\xf6nderdik. E-postay\u0131 hala bulam\u0131yorsan\u0131z, 5 dakika sonra yeniden g\xf6nderilmesini isteyebilirsiniz.","teamMemberRemoved":"{email} ekibinizden \xe7\u0131kar\u0131ld\u0131.","inviteSentTo":"{email} Adresine bir davetiye g\xf6nderildi.","billingInfoUpdated":"Fatura bilgileriniz g\xfcncellendi.","subCanceledConfirmation":"Aboneli\u011Finiz iptal edildi ve iadeniz i\u015Fleme al\u0131nd\u0131. Ayr\u0131nt\u0131lar i\xe7in e-postan\u0131z\u0131 kontrol edin.","siteDomainRemoved":"{domain} Websitesi kald\u0131r\u0131ld\u0131.","siteLockPassReset":"Site kilidi \u015Fifre s\u0131f\u0131rlama.","updatedSiteLockCode":"Yeni Site-Kilidi kodunuz: {pass}.","contactSupport":"Destek ekibiyle ileti\u015Fime ge\xe7in.","srySomethingWrong":"\xdczg\xfcn\xfcz, bir \u015Feyler yanl\u0131\u015F gitti.","subRefundFailed":"\u0130ade i\u015Flemi ger\xe7ekle\u015Ftirilemedi\u011Fi i\xe7in aboneli\u011Finiz hala aktif. Yard\u0131mc\u0131 olmak i\xe7in buraday\u0131z.","partialRefundMessage":"\u0130adeniz tam olarak i\u015Fleme al\u0131namad\u0131, ancak aboneli\u011Finiz art\u0131k aktif de\u011Fil. Yard\u0131mc\u0131 olmak i\xe7in buraday\u0131z.","exitMaintenanceModeToastTitle":"Bak\u0131m modundan \xe7\u0131k.","exitMaintenanceModeToastText":"{slug} Sitesi ba\u015Far\u0131yla bak\u0131m modundan \xe7\u0131kar\u0131ld\u0131."}')}}]);