"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["1720"],{1659(e){e.exports=JSON.parse('{"downloadInvoice404":{"title":"Ihre Rechnung wird bearbeitet","message":"Wir senden sie Ihnen per E-Mail zu, sobald sie fertig ist."},"supportedLanguages":{"en":"Englisch","de":"Deutsch","es":"Spanisch","it":"Italienisch","nl":"Niederl\xe4ndisch","pt-PT":"Portugu\xeas","pt-BR":"Portugiesisch (Brasilien)","fr":"Franz\xf6sisch","he-IL":"\u05E2\u05D1\u05E8\u05D9\u05EA"}}')}}]);