"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["3437"],{43964(a){a.exports=JSON.parse('{"header":"URL tidak cocok","title":"Bagaimana Anda ingin melanjutkan?","description":"Kunci lisensi Anda tidak cocok dengan domain Anda saat ini, menyebabkan ketidakcocokan.{br}Ini kemungkinan besar disebabkan oleh perubahan URL domain situs Anda.","actions":{"updateCurrentSite":{"title":"Perbarui URL yang terhubung","description":"Untuk perubahan URL pada situs yang sama, seperti dari staging ke produksi atau HTTP ke HTTPS.","action":"Perbarui URL yang terhubung"},"connectNewSite":{"title":"Hubungkan URL sebagai situs baru","description":"Untuk menghubungkan situs yang sama sekali berbeda. Riwayat sebelumnya akan dihapus.","action":"Hubungkan sebagai situs baru"}}}')}}]);