"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["3906"],{95129(e){e.exports=JSON.parse('{"onBoardingInstall":{"title":"Elementor One\'a ho\u015F geldiniz!","description":"T\xfcm Elementor \xf6zelliklerini y\xfckleyece\u011Fiz.\\nY\xfcklemek istemiyorsan\u0131z \u015Fimdi se\xe7imlerini kald\u0131r\u0131n.","skip":"Atla","continue":"Devam Et","installAndContinue":"Y\xfckle ve devam et","duringInstallation":"Y\xfckleme s\u0131ras\u0131nda, gerekli t\xfcm ara\xe7lar\u0131 g\xfcncelleyece\u011Fiz.","tools":{"additionalBetaTools":"Ek beta ara\xe7lar\u0131","editorCore":{"title":"Edit\xf6r \xe7ekirde\u011Fi","description":"S\xfcr\xfckle ve b\u0131rak aray\xfcz\xfcyle piksel m\xfckemmelli\u011Finde web siteleri olu\u015Fturun"},"editorPro":{"title":"Edit\xf6r pro","description":"Profesyonel ara\xe7larla t\xfcm sitenizi olu\u015Fturun"},"imageOptimizer":{"title":"G\xf6rsel optimizasyonu","description":"Performans\u0131 art\u0131rmak i\xe7in g\xf6rselleri s\u0131k\u0131\u015Ft\u0131r\u0131n ve optimize edin"},"accessibility":{"title":"Eri\u015Filebilirlik","description":"Sitenizdeki eri\u015Filebilirlik sorunlar\u0131n\u0131 bulun ve d\xfczeltin"},"siteMailer":{"title":"Site Mailer","description":"Site e-postalar\u0131n\u0131z\u0131n spam\'e de\u011Fil, gelen kutusuna ula\u015Ft\u0131\u011F\u0131ndan emin olun"},"ai":{"title":"WordPress i\xe7in yerel yapay zeka","description":"Yerel yapay zeka ile fikirleri sayfalara, bloklara ve \xf6zelliklere d\xf6n\xfc\u015Ft\xfcr\xfcn "},"installed":"Zaten y\xfckl\xfc","singleSub":"Tek abonelik","updateRequired":"G\xfcncelleme gerekli","updateRequiredTooltip":"Otomatik olarak en son s\xfcr\xfcme g\xfcncellenecektir","beta":"Beta"}},"siteIdentity":{"activeTheme":"Aktif tema:","getHelloElementor":"Hello Elementor\'u edinin","goToDashboard":"Kontrol paneline git","editSite":"Siteyi d\xfczenle","editSiteMenu":{"addPage":"Sayfa ekle","addBlogPost":"Blog yaz\u0131s\u0131 ekle","createHeader":"Ba\u015Fl\u0131k olu\u015Ftur","createFooter":"Alt bilgi olu\u015Ftur"},"helloThemeInstalled":"Hello Elementor temas\u0131 ba\u015Far\u0131yla y\xfcklendi","helloThemeInstallationFailed":"Hello Elementor temas\u0131 y\xfcklenemedi","helloThemeActivationFailed":"Hello Elementor tema etkinle\u015Ftirilemedi","helloThemeActivated":"Hello Elementor tema ba\u015Far\u0131yla etkinle\u015Ftirildi"},"capabilities":{"greeting":"Olu\u015Fturmaya ba\u015Flayal\u0131m.","filters":{"all":"T\xfcm\xfc","discover":"Ke\u015Ffet","build":"Olu\u015Ftur","optimize":"Optimize et","manage":"Y\xf6net"},"toolManager":"Ara\xe7 y\xf6neticisi","addForFreeButton":"\xdccretsiz ekle","openButton":"A\xe7","goProButton":"Pro\'ya ge\xe7","inProgressButton":"Devam ediyor","learnMore":{"upgrade":"Y\xfckselt","install":"Y\xfckle"}},"toolManager":{"title":"T\xfcm ara\xe7lar\u0131n\u0131z\u0131 TEK bir yerden kontrol edin."}}')}}]);