"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9428"],{33519(i){i.exports=JSON.parse('{"onBoardingInstall":{"title":"Benvenuto in\\nElementor One!","description":"Installeremo tutte le funzionalit\xe0 di Elementor.\\nSe non desideri installarle, deselezionale ora.","skip":"Salta","continue":"Continua","installAndContinue":"Installa e continua","duringInstallation":"Durante l\'installazione, aggiorneremo tutti gli strumenti che lo richiedono.","tools":{"additionalBetaTools":"Strumenti beta aggiuntivi","editorCore":{"title":"Editor core","description":"Crea siti web pixel-perfect con un\'interfaccia drag & drop"},"editorPro":{"title":"Editor pro","description":"Crea il tuo intero sito con strumenti professionali"},"imageOptimizer":{"title":"Ottimizzazione immagini","description":"Comprimi e ottimizza le immagini per migliorare le prestazioni"},"accessibility":{"title":"Accessibilit\xe0","description":"Trova e risolvi i problemi di accessibilit\xe0 sul tuo sito"},"siteMailer":{"title":"Site Mailer","description":"Assicurati che le email del tuo sito raggiungano la posta in arrivo, non lo spam"},"ai":{"title":"AI nativa per WordPress","description":"Trasforma le idee in pagine, blocchi e funzionalit\xe0 con l\'AI nativa "},"installed":"Gi\xe0 installato","singleSub":"Abbonamento singolo","updateRequired":"Aggiornamento richiesto","updateRequiredTooltip":"Verr\xe0 aggiornato automaticamente all\'ultima versione","beta":"Beta","manage":{"title":"Gestione del sito","description":"Monitora, ottimizza e gestisci tutti i tuoi siti in un unico posto"},"installedTooltip":"Puoi disinstallare gli strumenti installati dal gestore strumenti."},"installedToolTip":"Puoi disinstallare gli strumenti installati dal gestore strumenti.","conflictsDialog":{"update":{"title":"Aggiornamenti disponibili","description":"Questi strumenti usano versioni precedenti. Aggiornali per prestazioni e sicurezza ottimali.","selectTools":"Seleziona gli strumenti da aggiornare","action":"{nothingIsSelected, select, true {Continua} other {Aggiorna e continua}}"},"migrate":{"title":"Migrazione richiesta","description":"Questi strumenti non sono migrati a Elementor One. Migra per prestazioni e sicurezza ottimali.","selectTools":"Seleziona gli strumenti da migrare","action":"{nothingIsSelected, select, true {Continua} other {Sposta e continua}}"},"manageLater":"Puoi gestire questi aggiornamenti pi\xf9 tardi nel gestore strumenti","step":"Passaggio {step} di {total}"}},"siteIdentity":{"activeTheme":"Tema attivo:","getHelloElementor":"Ottieni Hello Elementor","goToDashboard":"Vai alla dashboard","editSite":"Modifica sito","editSiteMenu":{"addPage":"Aggiungi una pagina","addBlogPost":"Aggiungi un post del blog","createHeader":"Crea un\'intestazione","createFooter":"Crea un pi\xe8 di pagina"},"helloThemeInstalled":"Tema Hello Elementor installato correttamente","helloThemeInstallationFailed":"Installazione del tema Hello Elementor non riuscita","helloThemeActivationFailed":"Attivazione del tema Hello Elementor non riuscita","helloThemeActivated":"Tema Hello Elementor attivato con successo","goToSiteSetup":"Vai alla configurazione del sito"},"capabilities":{"greeting":"Iniziamo a costruire.","filters":{"all":"Tutto","discover":"Scopri","build":"Costruisci","optimize":"Ottimizza","manage":"Gestisci","featured":"In evidenza","create":"Crea"},"toolManager":"Gestore strumenti","addForFreeButton":"Aggiungi gratuitamente","openButton":"Apri","goProButton":"Passa a Pro","inProgressButton":"In corso","learnMore":{"upgrade":"Aggiorna","install":"Installa","open":"Apri"},"isNew":"Novit\xe0"},"toolManager":{"title":"Controlla tutti i tuoi strumenti in UN UNICO posto."},"welcomeModal":{"letsStart":{"title":"Benvenuto nel <br />nuovo Elementor!","description":"Crea, ottimizza e gestisci il tuo sito web <br />da un\u2019unica potente area di lavoro.","button":"Iniziamo"}}}')}}]);