"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["573"],{1532(e){e.exports=JSON.parse('{"example":{"component":"Beispielkomponente"},"header":{"title":"Website-Builder","userInfo":"Mein Konto","userProfileMenu":{"connectPreText":"Haben Sie einen Elementor-One-Tarif?","connect":"Verbinden","goToMyAccount":"Zu meinem Konto","disconnect":"Trennen","elementorOneActive":"Elementor One","active":"Aktiv","urlMismatch":"URL stimmt nicht \xfcberein","fixUrlMismatch":"Jetzt beheben"},"whatsNew":"Neuigkeiten","whatsNewError":"Beim Abruf der Benachrichtigungen ist etwas schiefgelaufen. Bitte versuchen Sie es sp\xe4ter erneut."}}')}}]);