"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9216"],{89731(a){a.exports=JSON.parse('{"onBoardingInstall":{"title":"Selamat datang di\\nElementor One!","description":"Kami akan menginstal semua kemampuan Elementor.\\nJika Anda tidak ingin menginstal, harap batalkan pilihan sekarang.","skip":"Lewati","continue":"Lanjutkan","installAndContinue":"Instal dan lanjutkan","duringInstallation":"Selama instalasi, kami akan memperbarui alat apa pun yang memerlukannya.","tools":{"additionalBetaTools":"Alat beta tambahan","editorCore":{"title":"Inti editor","description":"Buat situs web yang sempurna piksel dengan antarmuka seret & lepas"},"editorPro":{"title":"Editor pro","description":"Bangun seluruh situs Anda dengan alat profesional"},"imageOptimizer":{"title":"Optimasi gambar","description":"Kompres dan optimalkan gambar untuk meningkatkan kinerja"},"accessibility":{"title":"Aksesibilitas","description":"Temukan dan perbaiki masalah aksesibilitas di seluruh situs Anda"},"siteMailer":{"title":"Site Mailer","description":"Pastikan email situs Anda mencapai kotak masuk - bukan spam"},"ai":{"title":"AI Native untuk WordPress","description":"Ubah ide menjadi halaman, blok, dan fitur dengan AI native "},"installed":"Sudah terinstal","singleSub":"Satu langganan","updateRequired":"Pembaruan diperlukan","updateRequiredTooltip":"Akan diperbarui secara otomatis ke versi terbaru","beta":"Beta"}},"siteIdentity":{"activeTheme":"Tema aktif:","getHelloElementor":"Dapatkan Hello Elementor","goToDashboard":"Pergi ke dasbor","editSite":"Edit situs","editSiteMenu":{"addPage":"Tambahkan halaman","addBlogPost":"Tambahkan postingan blog","createHeader":"Buat header","createFooter":"Buat footer"},"helloThemeInstalled":"Tema Hello Elementor berhasil diinstal","helloThemeInstallationFailed":"Penginstalan tema Hello Elementor gagal","helloThemeActivationFailed":"Aktivasi tema Hello Elementor gagal","helloThemeActivated":"Tema Hello Elementor berhasil diaktifkan"},"capabilities":{"greeting":"Mari mulai membangun.","filters":{"all":"Semua","discover":"Temukan","build":"Bangun","optimize":"Optimalkan","manage":"Kelola"},"toolManager":"Manajer alat","addForFreeButton":"Tambahkan secara gratis","openButton":"Buka","goProButton":"Jadikan pro","inProgressButton":"Sedang berlangsung","learnMore":{"upgrade":"Tingkatkan","install":"Instal"}},"toolManager":{"title":"Kontrol semua alat Anda di SATU tempat."}}')}}]);