"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["1440"],{98227(e){e.exports=JSON.parse('{"title":"Gestionnaire d\u2019outils","subtitle":"Contr\xf4lez tous vos outils en UN seul endroit.","filters":{"all":"Tous","active":"Actif","disabled":"D\xe9sactiv\xe9","notInstalled":"Non install\xe9"},"back":"Retour \xe0 l\u2019aper\xe7u des outils","breadcrumb":{"home":"Accueil","toolManager":"Gestionnaire d\u2019outils"},"tools":{"build":{"title":"Construire","items":{"core":{"title":"Noyau de l\u2019\xe9diteur"},"pro":{"title":"\xc9diteur pro","features":{"themeBuilder":"Constructeur de th\xe8me","popups":"Popups","commerce":"Commerce","savedTemplates":"Mod\xe8les enregistr\xe9s","templateCategories":"Cat\xe9gories de mod\xe8les","starterTemplates":"Mod\xe8les de d\xe9marrage (mod\xe8les de site web)","customFonts":"Polices personnalis\xe9es","customIcons":"Ic\xf4nes personnalis\xe9es","customCode":"Code personnalis\xe9","customCss":"CSS personnalis\xe9"}},"ai":{"title":"IA agentique"}}},"optimize":{"title":"Optimiser","items":{"accessibility":{"title":"Accessibilit\xe9"},"io":{"title":"Optimisation d\u2019image"}}},"manage":{"title":"G\xe9rer","items":{"email":{"title":"D\xe9livrabilit\xe9 des e-mails"},"manage":{"title":"Gestion des sites"}}},"create":{"title":"Cr\xe9er","items":{"core":{"title":"Noyau de l\'\xe9diteur","withAI":"avec des capacit\xe9s d\'IA"},"pro":{"title":"\xc9diteur Pro","features":{"themeBuilder":"G\xe9n\xe9rateur de th\xe8me","popups":"Fen\xeatres contextuelles","commerce":"Commerce","savedTemplates":"Mod\xe8les enregistr\xe9s","templateCategories":"Cat\xe9gories de mod\xe8les","starterTemplates":"Mod\xe8les de d\xe9marrage (mod\xe8les de sites Web)","customFonts":"Polices personnalis\xe9es","customIcons":"Ic\xf4nes personnalis\xe9es","customCode":"Code personnalis\xe9","customCss":"CSS personnalis\xe9"}},"ai":{"title":"Angie - IA native pour WordPress"}}}},"actions":{"add":"Ajouter","update":"Mettre \xe0 jour","activate":"Activer","deactivate":"D\xe9sactiver","migrateToOne":"Migrer vers One","updateRequired":"Mise \xe0 jour requise","confirmAdd":{"title":"Ajouter un outil","msg":"Voulez-vous vraiment ajouter cet outil ? Cela ajoutera l\u2019outil \xe0 votre compte et vous pourrez l\u2019utiliser dans vos projets.","ok":"Ajouter","cancel":"Annuler"},"confirmActivate":{"title":"Voulez-vous vraiment activer {name}? ","msg":"En activant...","ok":"Activer","cancel":"Annuler"},"confirmDeactivate":{"title":"Voulez-vous vraiment d\xe9sactiver {name}? ","msg":"En d\xe9sactivant...","ok":"D\xe9sactiver","cancel":"Pas maintenant"},"detachAi":"D\xe9tacher l\'IA de l\'\xe9diteur d\'Elementor One","activateCore":"Activez Editor Core pour activer Editor Pro","confirmDetach":{"title":"Detach {name} ","msg":"{isEditorCore, select, true {Remove Elementor One from Editor AI. This lets you use it with another plan.} other {Remove the One plan from this plugin. This lets you use it with another plan.}}","ok":"D\xe9tacher","cancel":"Pas maintenant"},"confirmDeactivateOrDetach":{"title":"Qu\'aimeriez-vous faire ?","deactivateMsg":"D\xe9sactivez cette fonctionnalit\xe9 et son plugin WordPress. Vous pouvez le r\xe9activer \xe0 tout moment et continuer \xe0 l\u2019utiliser avec votre forfait One.","deactivate":"D\xe9sactiver","msg":"{isEditorCore, select, true {Remove Elementor One from Editor AI. This lets you use it with another plan.} other {Remove the One plan from this plugin. This lets you use it with another plan.}}","detach":"D\xe9tacher","cancel":"Pas maintenant"},"confirmMigration":{"title":"Move {name} to Elementor One? ","msg":"{name} is currently active with its own subscription. You also have an Elementor One subscription for this site.<br/><br/>If you switch to Elementor One:<ul><li>Your current {name} subscription will be deactivated</li><li>{name} will use your shared Elementor One credits</li></ul>","ok":"Se d\xe9placer","cancel":"Pas maintenant"},"failedAction":{"install":"L\'installation a \xe9chou\xe9. Veuillez r\xe9essayer plus tard.","activate":"L\'activation a \xe9chou\xe9. Veuillez r\xe9essayer plus tard.","deactivate":"La d\xe9sactivation a \xe9chou\xe9. Veuillez r\xe9essayer plus tard.","migrate":"La migration a \xe9chou\xe9. Veuillez r\xe9essayer plus tard.","detach":"Le d\xe9tachement a \xe9chou\xe9. Veuillez r\xe9essayer plus tard."}},"showMoreFeatures":"Afficher plus de fonctionnalit\xe9s","hideMoreFeatures":"Masquer plus de fonctionnalit\xe9s","noToolsFound":"Aucun outil ne correspond \xe0 cette recherche","noToolsFoundDescription":"Essayez d\u2019ajuster vos filtres.","updateRequiredTooltip":"Les extensions \xe0 jour offrent de nouvelles fonctionnalit\xe9s et des correctifs pour que votre site fonctionne en toute s\xe9curit\xe9 et sans probl\xe8me."}')}}]);