"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["6226"],{66025(e){e.exports=JSON.parse('{"header":"URL-mismatch","title":"Hoe wilt u verdergaan?","description":"Uw licentiesleutel komt niet overeen met uw huidige domein, wat een mismatch veroorzaakt.{br}Dit komt waarschijnlijk door een wijziging in de domein-URL van uw site.","actions":{"updateCurrentSite":{"title":"Gekoppelde URL bijwerken","description":"Voor URL-wijzigingen op dezelfde site, zoals van staging naar productie of van HTTP naar HTTPS.","action":"Gekoppelde URL bijwerken"},"connectNewSite":{"title":"De URL als een nieuwe site koppelen","description":"Voor het koppelen van een compleet andere site. Eerdere geschiedenis wordt verwijderd.","action":"Koppelen als een nieuwe site"}}}')}}]);