"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_pt-BR_send-feedback_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/pt-BR/send-feedback.json":
/*!****************************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/pt-BR/send-feedback.json ***!
  \****************************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"dialog":{"title":"Compartilhe seu feedback","fieldTitlePlaceholder":"Título","fieldDescriptionPlaceholder":"Diga-nos o que você tem em mente","fieldSubjectPlaceholder":"Selecione o assunto do seu feedback","fieldProductPlaceholder":"Selecionar o produto","note":"Agradecemos seu feedback! Embora revisemos todas as sugestões, não podemos garantir que cada sugestão resultará em uma alteração ou atualização.","subjects":{"leaveFeedback":"Deixar um feedback","reportBug":"Reportar um erro","requestFeature":"Solicitar um recurso","shareThoughts":"Partilhar outras ideias"},"products":{"general":"Geral","editor":"Editor","accessibility":"Acessibilidade","imageOptimization":"Otimização de imagem","emailDeliverability":"Capacidade de entrega de email","siteManagement":"Site Management"},"cancel":"Cancelar","submit":"Enviar","titleLengthError":"O título deve ter menos de 90 caracteres","descriptionLengthError":"A descrição deve ter menos de 1024 caracteres","alert":{"title":"Precisa de ajuda ou encontrou um problema?","button":"Enviar um ticket de suporte"}},"tooltipSuccess":"Feedback enviado. Obrigado por nos ajudar.","tooltipError":"Algo deu errado. Tente enviar seu feedback novamente."}');

/***/ })

}]);