"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_pt-BR_common_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/pt-BR/common.json":
/*!*********************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/pt-BR/common.json ***!
  \*********************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"header":{"title":"construtor de sites","userInfo":"Minha conta","userProfileMenu":{"connectPreText":"Tem um plano Elementor One?","connect":"Conectar","goToMyAccount":"Ir para Minha conta","disconnect":"Desconectar","elementorOneActive":"Elementor One","active":"Ativo","urlMismatch":"Incompatibilidade de URL detectada","fixUrlMismatch":"Corrigir agora"},"whatsNew":"O que há de novo","whatsNewError":"Algo deu errado ao buscar as notificações. Tente novamente mais tarde."}}');

/***/ })

}]);