/*
 * UnderConstructionPage
 * Common frontend CSS
 * (c) WebFactory Ltd, 2015 - 2025
 */


.content img {
  max-width: 100%;
  height: auto;
}

#linkback {
  font-size: small;
  text-align: center;
  opacity: 0.55;
  margin: 10px;
}

#login-button {
  position: relative;
  right: 0;
  bottom: 50px;
  text-align: right;
  float: right;
  margin-bottom: 20px;
}

#login-button a {
  background-color: rgba(70, 70, 70, 1);
  border-radius: 5px 0 0 5px;
  opacity: 0.3;
  padding: 10px;
  color: #ffffff;
  display: inline-block;
}

#login-button a:hover {
  box-shadow: 0 4px 5px 0 rgba(0,0,0,0.14), 0 1px 10px 0 rgba(0,0,0,0.12), 0 2px 4px -1px rgba(0,0,0,0.3);
  opacity: 1;
}

@media(max-width:767px){
  #login-button {
    bottom: 5px;
  }
  #login-button a {
    padding: 5px;
  }
  #social a i {
    margin: 5px;
  }
}
