/*! For license information please see editor-elements-panel-notice.js.LICENSE.txt */
!function(){"use strict";var e={"./packages/packages/core/editor-elements-panel-notice/src/components/notice-portal.tsx":function(e,t,r){r.r(t),r.d(t,{NoticePortal:function(){return NoticePortal}});var n=r("react"),o=r("@elementor/editor-v1-adapters"),i=r("@elementor/ui");const c="elementor-panel-elements-notice-area",a="panel/elements/";function NoticePortal({component:e}){const t=(0,o.__privateUseListenTo)([(0,o.v1ReadyEvent)(),(0,o.routeOpenEvent)(a)],()=>document.getElementById(c));return t?n.createElement(i.Portal,{container:t},n.createElement(e,null)):null}},"./packages/packages/core/editor-elements-panel-notice/src/init.tsx":function(e,t,r){r.r(t),r.d(t,{register:function(){return register}});var n=r("react"),o=r("@elementor/editor"),i=r("@elementor/editor-v1-adapters"),c=r("./packages/packages/core/editor-elements-panel-notice/src/components/notice-portal.tsx"),a=r("./packages/packages/core/editor-elements-panel-notice/src/utils/create-notice-view.ts");function register(e){(0,o.injectIntoTop)({id:"editor-elements-panel-notice",component:()=>n.createElement(c.NoticePortal,{component:e})}),(0,i.__privateListenTo)((0,i.v1ReadyEvent)(),()=>{window.elementor?.hooks?.addFilter("panel/elements/regionViews",(e,{notice:t})=>(e.notice={region:t,view:(0,a.createNoticeView)()},e))})}},"./packages/packages/core/editor-elements-panel-notice/src/utils/create-notice-view.ts":function(e,t,r){function createNoticeView(){return window.Marionette?.CompositeView.extend({template:"<div></div>"})}r.r(t),r.d(t,{createNoticeView:function(){return createNoticeView}})},"@elementor/editor":function(e){e.exports=window.elementorV2.editor},"@elementor/editor-v1-adapters":function(e){e.exports=window.elementorV2.editorV1Adapters},"@elementor/ui":function(e){e.exports=window.elementorV2.ui},react:function(e){e.exports=window.React}},t={};function __webpack_require__(r){var n=t[r];if(void 0!==n)return n.exports;var o=t[r]={exports:{}};return e[r](o,o.exports,__webpack_require__),o.exports}__webpack_require__.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return __webpack_require__.d(t,{a:t}),t},__webpack_require__.d=function(e,t){for(var r in t)__webpack_require__.o(t,r)&&!__webpack_require__.o(e,r)&&Object.defineProperty(e,r,{enumerable:!0,get:t[r]})},__webpack_require__.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},__webpack_require__.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})};var r={};!function(){__webpack_require__.r(r),__webpack_require__.d(r,{register:function(){return e.register}});var e=__webpack_require__("./packages/packages/core/editor-elements-panel-notice/src/init.tsx")}(),(window.elementorV2=window.elementorV2||{}).editorElementsPanelNotice=r}(),window.elementorV2.editorElementsPanelNotice?.init?.();
//# sourceMappingURL=editor-elements-panel-notice.js.map