/*
 * UnderConstructionPage
 * Clock CSS
 * (c) WebFactory Ltd, 2015 - 2025
 */


html {
   height: 100%;
   padding: 0;
   margin: 0;
}

body {
  font-weight: 400;
  font-size: 14px;
  line-height: 120%;
  color:  #fefefe;
  background: #01c9fd;
  background: -webkit-linear-gradient(to right, #90fe9d, #01c9fd);
  background: linear-gradient(to right, #90fe9d, #01c9fd);
  padding: 0;
  margin: 0;
  height: 100%;
}

a, a:hover {
  color: #000000;
}

.top-container {
  padding: 50px 0;
}

#hero-image {
  text-align: left;
  position: relative;
  display: inline-block;
}

#hero-image img {
  max-width: 80%;
}

.clock-hand {
  position: absolute;
  top: 0;
  left: 0;
  transform: rotate(0deg);
  transform-origin: 50.1% 59.9%;
  -webkit-animation: spin 30s linear infinite;
  -moz-animation: spin 30s linear infinite;
  animation: spin 30s linear infinite;
}

.display-table {
  display: table;
  table-layout: fixed;

}

.display-cell {
  display: table-cell;
  vertical-align: middle;
  float: none;
  text-align: center;
}

h1 {
  font-size: 34px;
  color: #fefefe;
  font-family: "Nunito", sans-serif;
  font-weight: 900;
  margin: 20px 0 30px 0;
  text-align: left;
}

.content {
  text-align: left;
  font-family: "Helvetica", "Arial", sans-serif;
}

#social {
  text-align: center;
  margin-top: 30px;
}

#social a i {
  color: #fefefe;
  margin: 10px;
  box-sizing: content-box;
}

#social a:hover i {
  color: #2e2e2e;
}

@media(max-width:767px) {
  h1 {
     font-size: 28px;
     margin: 10px 0 30px 0;
  }
  #hero-image img {
    max-width: 95%;
  }
}

@media (max-width: 1200px) {
  h1 {
    text-align: center;
    padding: 0 20px;
  }
  .display-table {
    display: initial;
    table-layout: auto;
  }
  .display-cell {
    display: block;
    float: none;
  }
  #hero-image img {
    max-height: 250px
  }
  .top-container {
    padding: 25px 0;
  }
}

@-moz-keyframes spin { 100% { -moz-transform: rotate(360deg); } }
@-webkit-keyframes spin { 100% { -webkit-transform: rotate(360deg); } }
@keyframes spin { 100% { -webkit-transform: rotate(360deg); transform:rotate(360deg); } }
