"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_es_common_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/es/common.json":
/*!******************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/es/common.json ***!
  \******************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"example":{"component":"Componente de ejemplo"},"header":{"title":"creador de sitios web","userInfo":"mi cuenta","userProfileMenu":{"connectPreText":"¿Tienes un plan Elementor One?","connect":"Conectar","goToMyAccount":"Ir a mi cuenta","disconnect":"Desconectar","elementorOneActive":"Elementor Uno","active":"Activo","urlMismatch":"Se detectó una URL que no coincide","fixUrlMismatch":"Arreglar ahora"},"whatsNew":"Qué hay de nuevo","whatsNewError":"Algo salió mal al recuperar las notificaciones. Inténtelo de nuevo más tarde."}}');

/***/ })

}]);