"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["6031"],{21234(e){e.exports=JSON.parse('{"4.0-default":{"title":"O novo predefinido","description":"Os novos sites come\xe7am na vers\xe3o 4.0 com funcionalidades at\xf3micas ativadas por predefini\xe7\xe3o. Os sites existentes podem ativar manualmente. Os seus layouts e sites atuais n\xe3o mudam.","topic":"Vers\xe3o 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"4.0-atomic-forms":{"title":"Formul\xe1rios at\xf3micos","description":"Crie formul\xe1rios como parte do layout, n\xe3o como widgets separados. Layouts flex\xedveis em v\xe1rias colunas, aninhamento livre e controlo total com o mesmo sistema at\xf3mico.","topic":"Vers\xe3o 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"4.0-interactions":{"title":"Intera\xe7\xf5es Pro","description":"Crie movimento avan\xe7ado e leve no Editor. Defina o comportamento de forma visual, tudo com base no sistema, sem scripts pesados ou ferramentas externas.","topic":"Vers\xe3o 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"4.0-sync-design-system":{"title":"Sincronize e partilhe design systems","description":"Exporte e importe vari\xe1veis e classes entre sites e sincronize com Global Styles v3. Design consistente em projetos e vers\xf5es.","topic":"Vers\xe3o 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"angie-launch":{"title":"Apresentamos o Angie Code.","description":"Crie widgets Elementor e excertos a partir de uma descri\xe7\xe3o. Nativo para WordPress e Elementor. Pr\xe9-visualize com seguran\xe7a, refine na conversa e publique quando estiver pronto.","topic":"Angie Code","chipTags":["Novo lan\xe7amento"],"readMoreText":"Saiba mais","cta":""},"partner-program":{"title":"Seja parceiro da Elementor. Desenvolva o seu neg\xf3cio.","description":"Aceda a benef\xedcios exclusivos, visibilidade, oportunidades de marketing e receitas adicionais com o trabalho que j\xe1 fez. Adira gratuitamente e comece j\xe1.","chipTags":["Programa de parceiros"],"readMoreText":"","cta":"Candidatar-se"},"manage-launch":{"title":"Apresentamos o Manage","description":"Monitorize, otimize e mantenha todos os sites a partir de um painel central. Acompanhe o desempenho, atualiza\xe7\xf5es em massa e riscos de seguran\xe7a.","chipTags":["Novo lan\xe7amento"],"readMoreText":"","cta":"Come\xe7ar gr\xe1tis"},"components-3.35":{"title":"Componentes","description":"Sec\xe7\xf5es modulares reutiliz\xe1veis que se atualizam em todo o lado e decide quanto controlo cede \xe0 equipa ou clientes.","topic":"Vers\xe3o 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"one-launch":{"title":"Apresentamos o Elementor One","description":"A experi\xeancia completa para criar sites. Ferramentas para criar, otimizar e gerir, unificadas num \xfanico s\xedtio.","chipTags":["Novo lan\xe7amento"],"readMoreText":"","cta":"Explorar o Elementor One"},"atomic-tabs-3.34":{"title":"Separadores at\xf3micos","description":"Coloque qualquer conte\xfado nos separadores, com um design verdadeiramente at\xf3mico.","topic":"Vers\xe3o 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"variables-manager-3.33":{"title":"Gestor de vari\xe1veis","description":"Centralize cores, tipografia e tokens de tamanho para design systems coerentes e escal\xe1veis.","topic":"Vers\xe3o 4.0","chipTags":["Atomic Editor"],"readMoreText":"Saiba mais","cta":""},"ally-assistant":{"title":"Novo: acessibilidade com Ally Assistant","description":"Analise qualquer p\xe1gina e corrija com um clique: contraste, texto alternativo e mais. Passos orientados ou corre\xe7\xe3o com IA para um s\xedtio mais inclusivo.","topic":"Ally by Elementor","chipTags":["Nova funcionalidade"],"readMoreText":"","cta":"Analisar gr\xe1tis"},"image-optimizer-3.19":{"title":"Otimize imagens com facilidade para um s\xedtio r\xe1pido e impactante com o plugin Image Optimizer.","description":"O Image Optimizer equilibra qualidade e desempenho. Redimensione, comprima, converta para WebP: carregamento mais r\xe1pido, melhor experi\xeancia.","topic":"Image Optimizer Plugin by Elementor","chipTags":["Novo plugin"],"readMoreText":"","cta":"Obter o Image Optimizer"},"5-star-rating-prompt":{"title":"Gosta das novidades? D\xea-nos 5 estrelas","description":"Conte ao mundo o que gosta no Elementor.","chipTags":[],"readMoreText":"","cta":"Deixar avalia\xe7\xe3o"},"site-mailer-introducing":{"title":"Apresentamos o Site Mailer","description":"Mantenha o e-mail do WordPress fora do spam: melhor entrega e configura\xe7\xe3o simples, sem plugin SMTP complicado.","topic":"Site Mailer Plugin by Elementor","chipTags":["Novo plugin"],"readMoreText":"","cta":"Iniciar teste gr\xe1tis"}}')}}]);