"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["1506"],{83577(e){e.exports=JSON.parse('{"apps":{"HOSTING":"Hosting","APP_AI":"Elementor AI","APP_IO":"Image Optimizer","APP_MAILER":"Site Mailer","PLUGIN":"Elementor Pro","APP_ACCESS":"Ally","APP_EMPMA":"Send","APP_MANAGE":"Elementor Manage"}}')}}]);