"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["2455"],{96794(e){e.exports=JSON.parse('{"dialog":{"title":"Partagez vos commentaires","fieldTitlePlaceholder":"Titre","fieldDescriptionPlaceholder":"Dites-nous ce que vous aviez en t\xeate","fieldSubjectPlaceholder":"S\xe9lectionnez le sujet de vos commentaires","fieldProductPlaceholder":"S\xe9lectionner le produit","note":"Nous appr\xe9cions vos commentaires ! Bien que nous examinions toutes les soumissions, nous ne pouvons pas garantir que chaque suggestion entra\xeenera un changement ou une mise \xe0 jour.","subjects":{"leaveFeedback":"Laisser un commentaire","reportBug":"Signaler un bug","requestFeature":"Demander une fonctionnalit\xe9","shareThoughts":"Partager d\u2019autres r\xe9flexions"},"products":{"general":"G\xe9n\xe9ral","editor":"\xc9diteur","accessibility":"Accessibilit\xe9","imageOptimization":"Optimisation des images","emailDeliverability":"D\xe9livrabilit\xe9 des e-mails","siteManagement":"Site Management"},"cancel":"Annuler","submit":"Envoyer","titleLengthError":"Le titre doit contenir moins de 90 caract\xe8res","descriptionLengthError":"La description doit contenir moins de 1024 caract\xe8res","alert":{"title":"Besoin d\'aide ou rencontr\xe9 un probl\xe8me ?","button":"Envoyer un ticket d\'assistance"}},"tooltipSuccess":"Commentaires envoy\xe9s. Merci de nous avoir aid\xe9s.","tooltipError":"Une erreur s\'est produite. Veuillez r\xe9essayer d\'envoyer vos commentaires."}')}}]);