"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["5819"],{18934(e){e.exports=JSON.parse('{"title":"Ara\xe7 y\xf6neticisi","subtitle":"T\xfcm ara\xe7lar\u0131n\u0131z\u0131 TEK bir yerden kontrol edin.","filters":{"all":"T\xfcm\xfc","active":"Aktif","disabled":"Devre d\u0131\u015F\u0131","notInstalled":"Y\xfckl\xfc de\u011Fil"},"back":"Ara\xe7lara genel bak\u0131\u015Fa geri d\xf6n","breadcrumb":{"home":"Ana Sayfa","toolManager":"Ara\xe7 y\xf6neticisi"},"tools":{"build":{"title":"Olu\u015Ftur","items":{"core":{"title":"D\xfczenleyici \xe7ekirde\u011Fi"},"pro":{"title":"D\xfczenleyici pro","features":{"themeBuilder":"Tema olu\u015Fturucu","popups":"Pop-up\'lar","commerce":"Ticaret","savedTemplates":"Kaydedilen \u015Fablonlar","templateCategories":"\u015Eablon kategorileri","starterTemplates":"Ba\u015Flang\u0131\xe7 \u015Fablonlar\u0131 (web sitesi \u015Fablonlar\u0131)","customFonts":"\xd6zel yaz\u0131 tipleri","customIcons":"\xd6zel simgeler","customCode":"\xd6zel kod","customCss":"\xd6zel CSS"}},"ai":{"title":"Agentic AI"}}},"optimize":{"title":"Optimize Et","items":{"accessibility":{"title":"Eri\u015Filebilirlik"},"io":{"title":"G\xf6rsel optimizasyonu"}}},"manage":{"title":"Y\xf6net","items":{"email":{"title":"E-posta teslim edilebilirli\u011Fi"}}}},"actions":{"add":"Ekle","update":"G\xfcncelle","activate":"Etkinle\u015Ftir","deactivate":"Devre d\u0131\u015F\u0131 b\u0131rak","migrateToOne":"One\u2019a ge\xe7","updateRequired":"G\xfcncelleme gerekli","confirmAdd":{"title":"Ara\xe7 ekle","msg":"Bu arac\u0131 eklemek istedi\u011Finizden emin misiniz? Bu i\u015Flem arac\u0131 hesab\u0131n\u0131za ekleyecek ve projelerinizde kullanabileceksiniz.","ok":"Ekle","cancel":"\u0130ptal"},"confirmActivate":{"title":"{name}\'y\u0131 etkinle\u015Ftirmek istedi\u011Finizden emin misiniz? ","msg":"Etkinle\u015Ftirerek...","ok":"Etkinle\u015Ftir","cancel":"\u0130ptal"},"confirmDeactivate":{"title":"{name}\'y\u0131 devre d\u0131\u015F\u0131 b\u0131rakmak istedi\u011Finizden emin misiniz? ","msg":"Devre d\u0131\u015F\u0131 b\u0131rakarak...","ok":"Devre d\u0131\u015F\u0131 b\u0131rak","cancel":"\u015Eimdi de\u011Fil"}},"showMoreFeatures":"Daha fazla \xf6zellik g\xf6ster","hideMoreFeatures":"Daha fazla \xf6zelli\u011Fi gizle","noToolsFound":"Bu aramaya uyan ara\xe7 bulunamad\u0131","noToolsFoundDescription":"Filtrelerinizi ayarlamay\u0131 deneyin.","updateRequiredTooltip":"G\xfcncel eklentiler yeni \xf6zelliklere ve d\xfczeltmelere sahiptir, b\xf6ylece siteniz g\xfcvenli ve sorunsuz \xe7al\u0131\u015F\u0131r."}')}}]);