"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["2757"],{66580(e){e.exports=JSON.parse('{"wPLoginAttempts":"WP-inlogpogingen.","wPLoginAttemptsResetSuccess":"WP-inlogpogingen zijn succesvol gereset.","errorTryAgain":"Er is iets misgegaan, probeer het opnieuw.","backupCreation":"Back-up maken.","backupCreated":"Site back-up is succesvol gemaakt.","backupUpdate":"Site back-up is succesvol bijgewerkt.","backupUpdated":"Site back-up is succesvol bijgewerkt.","backupRestore":"Back-up herstellen.","backupDelete":"Back-up verwijderen.","backupDeleted":"Back-up is verwijderd.","backupExport":"Back-up exporteren.","backupExportSuccessToast":"U ontvangt binnenkort een e-mail met de downloadlink.","debugMode":"Debugmodus.","debugModeSwithFailed":"{value, select, true {Uitschakelen} other {Inschakelen}} van debugmodus is mislukt, probeer het opnieuw.","siteDeletion":"Site verwijdering.","siteDeleted":"Site is verwijderd.","setFavoriteSuccess":"{domain} is toegevoegd aan uw favoriete sites.","removeFavoriteSuccess":"{domain} is verwijderd uit uw favoriete sites.","maxReachedFavorites":"Je hebt het maximale aantal favorieten bereikt.","generalErrorToast":"Oeps, dat werkte niet. Probeer het later opnieuw.","websiteDeactivation":"Website deactiveren.","setDefaultPaymentFailed":"Standaard betaalmethode instellen is mislukt.","actionFailedMessage":"Sorry, dat werkte niet.","retryErrorMessage":"Sorry, dat werkte niet. Probeer het opnieuw.","addingDomainFailed":"Domein toevoegen is mislukt, probeer het opnieuw.","removingDomainFailed":"Domein verwijderen is mislukt, probeer het opnieuw.","settingDomainPrimaryFailed":"Domein als primair instellen is mislukt, probeer het opnieuw.","emailVerification":"E-mailverificatie.","emailAlreadyVerified":"Het e-mailadres is al geverifieerd.","emailVerificationSent":"Verzonden! Controleer uw inbox voor een verificatie-e-mail.","emailVerificationResendDelay":"We hebben al een verificatie-e-mail naar uw inbox gestuurd. Als u de e-mail nog steeds niet kunt vinden, kunt u over 5 minuten vragen om deze opnieuw te verzenden.","teamMemberRemoved":"{email} is verwijderd uit uw team.","inviteSentTo":"Er is een uitnodiging verzonden naar {email}.","inviteResendDelay":"Wacht {cooldown} seconden voordat u de uitnodiging opnieuw verzendt.","billingInfoUpdated":"Uw factureringsgegevens zijn bijgewerkt.","subCanceledConfirmation":"Uw abonnement is geannuleerd en uw terugbetaling wordt verwerkt. Controleer uw e-mail voor details.","siteDomainRemoved":"Website {domain} is verwijderd.","siteLockPassReset":"Site-lock wachtwoord opnieuw ingesteld.","updatedSiteLockCode":"Uw nieuwe Site-Lock code is: {pass}.","contactSupport":"Neem contact op met de klantenservice.","srySomethingWrong":"Sorry, er is iets misgegaan.","subRefundFailed":"Uw abonnement is nog actief omdat de terugbetaling niet kon worden verwerkt. We staan klaar om u te helpen.","partialRefundMessage":"Uw terugbetaling kon niet volledig worden verwerkt, maar uw abonnement is niet langer actief. We staan klaar om u te helpen.","exitMaintenanceModeToastTitle":"Verlaat onderhoudsmodus.","exitMaintenanceModeToastText":"Site {slug} is succesvol uit de onderhoudsmodus gehaald."}')}}]);