.elementor-78 .elementor-element.elementor-element-8eee883{margin-top:32px;margin-bottom:0px;}.elementor-widget-text-editor{font-family:var( --e-global-typography-text-font-family ), Sans-serif;font-weight:var( --e-global-typography-text-font-weight );color:var( --e-global-color-text );}.elementor-widget-text-editor.elementor-drop-cap-view-stacked .elementor-drop-cap{background-color:var( --e-global-color-primary );}.elementor-widget-text-editor.elementor-drop-cap-view-framed .elementor-drop-cap, .elementor-widget-text-editor.elementor-drop-cap-view-default .elementor-drop-cap{color:var( --e-global-color-primary );border-color:var( --e-global-color-primary );}.elementor-78 .elementor-element.elementor-element-abe8c31{color:#000000;}.elementor-78 .elementor-element.elementor-element-dae94ae{color:#000000;}.elementor-78 .elementor-element.elementor-element-aefd444:not(.elementor-motion-effects-element-type-background), .elementor-78 .elementor-element.elementor-element-aefd444 > .elementor-motion-effects-container > .elementor-motion-effects-layer{background-color:#F6E81D;}.elementor-78 .elementor-element.elementor-element-aefd444{transition:background 0.3s, border 0.3s, border-radius 0.3s, box-shadow 0.3s;}.elementor-78 .elementor-element.elementor-element-aefd444 > .elementor-background-overlay{transition:background 0.3s, border-radius 0.3s, opacity 0.3s;}.elementor-widget-heading .elementor-heading-title{font-family:var( --e-global-typography-primary-font-family ), Sans-serif;font-weight:var( --e-global-typography-primary-font-weight );color:var( --e-global-color-primary );}.elementor-78 .elementor-element.elementor-element-2b88fe1{text-align:center;}.elementor-78 .elementor-element.elementor-element-2b88fe1 .elementor-heading-title{font-family:"Times New Roman", Sans-serif;font-weight:600;color:#000000;}.elementor-78 .elementor-element.elementor-element-ce20708{--e-image-carousel-slides-to-show:3;}@media(min-width:768px){.elementor-78 .elementor-element.elementor-element-aefb53c{width:57.193%;}.elementor-78 .elementor-element.elementor-element-bbb11fb{width:42.763%;}}