"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["3259"],{99174(e){e.exports=JSON.parse('{"downloadInvoice404":{"title":"Votre facture est en cours de traitement","message":"Nous vous l\'enverrons par courriel d\xe8s qu\'elle sera pr\xeate."},"supportedLanguages":{"en":"Anglais","de":"Allemand","es":"Espagnol","it":"Italien","nl":"N\xe9erlandais","pt-PT":"Portugais","pt-BR":"Portugais (Br\xe9sil)","fr":"Fran\xe7ais","he-IL":"H\xe9breu"}}')}}]);