"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_it_send-feedback_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/it/send-feedback.json":
/*!*************************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/it/send-feedback.json ***!
  \*************************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"dialog":{"title":"Condividi il tuo feedback","fieldTitlePlaceholder":"Titolo","fieldDescriptionPlaceholder":"Dicci cosa avevi in mente","fieldSubjectPlaceholder":"Seleziona l\'oggetto del tuo feedback","fieldProductPlaceholder":"Seleziona il prodotto","note":"Apprezziamo il tuo feedback! Anche se esaminiamo tutti i suggerimenti, non possiamo garantire che ogni suggerimento si tradurrà in una modifica o un aggiornamento.","subjects":{"leaveFeedback":"Lascia un feedback","reportBug":"Segnala un bug","requestFeature":"Richiedi una funzionalità","shareThoughts":"Condividi altri pensieri"},"products":{"general":"Generale","editor":"Editor","accessibility":"Accessibilità","imageOptimization":"Ottimizzazione delle immagini","emailDeliverability":"Deliverability delle email","siteManagement":"Site Management"},"cancel":"Annulla","submit":"Invia","titleLengthError":"Il titolo deve contenere meno di 90 caratteri","descriptionLengthError":"La descrizione deve contenere meno di 1024 caratteri","alert":{"title":"Hai bisogno di aiuto o hai riscontrato un problema?","button":"Invia un ticket di supporto"}},"tooltipSuccess":"Feedback inviato. Grazie per il tuo aiuto.","tooltipError":"Qualcosa è andato storto. Prova a inviare di nuovo il tuo feedback."}');

/***/ })

}]);