__( 'Not Found', 'elementor' );
__( 'Not Found', 'elementor' );
__( 'Something went wrong.', 'elementor' );
__( 'Continue', 'elementor' );
__( 'Go Back', 'elementor' );
__( 'First, enable unfiltered file uploads.', 'elementor' );
__( 'Enable', 'elementor' );
__( 'Skip', 'elementor' );
__( 'App could not be loaded', 'elementor' );
__( 'We’re sorry, but something went wrong. Click on ‘Learn more’ and follow each of the steps to quickly solve it.', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Go Back', 'elementor' );
__( 'This file type is not allowed', 'elementor' );
__( 'This file type is not allowed', 'elementor' );
__( 'Select File', 'elementor' );
__( 'Upgrade Now', 'elementor' );
__( 'Loading', 'elementor' );
__( 'Back to dashboard', 'elementor' );
__( 'Close', 'elementor' );
__( 'Elementor', 'elementor' );
__( 'Header', 'elementor' );
__( 'What is a Header Template?', 'elementor' );
__( 'The header template allows you to easily design and edit custom WordPress headers so you are no longer constrained by your theme’s header design limitations.', 'elementor' );
__( 'You can create multiple headers, and assign each to different areas of your site.', 'elementor' );
__( 'Footer', 'elementor' );
__( 'What is a Footer Template?', 'elementor' );
__( 'The footer template allows you to easily design and edit custom WordPress footers without the limits of your theme’s footer design constraints', 'elementor' );
__( 'You can create multiple footers, and assign each to different areas of your site.', 'elementor' );
__( 'Single Page', 'elementor' );
__( 'What is a Single Page Template?', 'elementor' );
__( 'A single page template allows you to easily create the layout and style of pages, ensuring design consistency across all the pages of your site.', 'elementor' );
__( 'You can create multiple single page templates, and assign each to different areas of your site.', 'elementor' );
__( 'Single Post', 'elementor' );
__( 'What is a Single Post Template?', 'elementor' );
__( 'A single post template allows you to easily design the layout and style of posts, ensuring a design consistency throughout all your blog posts, for example.', 'elementor' );
__( 'You can create multiple single post templates, and assign each to a different category.', 'elementor' );
__( 'Archive', 'elementor' );
__( 'What is an Archive Template?', 'elementor' );
__( 'An archive template allows you to easily design the layout and style of archive pages - those pages that show a list of posts (e.g. a blog’s list of recent posts), which may be filtered by terms such as authors, categories, tags, search results, etc.', 'elementor' );
__( 'If you’d like a different style for a specific category, it’s easy to create a separate archive template whose condition is to only display when users are viewing that category’s list of posts.', 'elementor' );
__( 'search results page', 'elementor' );
__( 'What is a Search Results Template?', 'elementor' );
__( 'You can easily control the layout and design of the Search Results page with the Search Results template, which is simply a special archive template just for displaying search results.', 'elementor' );
__( 'You can customize the message if there are no results for the search term.', 'elementor' );
__( 'Product', 'elementor' );
__( 'What is a Single Product Template?', 'elementor' );
__( 'A single product template allows you to easily design the layout and style of WooCommerce single product pages, and apply that template to various conditions that you assign.', 'elementor' );
__( 'You can create multiple single product templates, and assign each to different types of products, enabling a custom design for each group of similar products.', 'elementor' );
__( 'Products Archive', 'elementor' );
__( 'What is a Products Archive Template?', 'elementor' );
__( 'A products archive template allows you to easily design the layout and style of your WooCommerce shop page or other product archive pages - those pages that show a list of products, which may be filtered by terms such as categories, tags, etc.', 'elementor' );
__( 'You can create multiple archive product templates, and assign each to different categories of products. This gives you the freedom to customize the appearance for each type of product being shown.', 'elementor' );
__( '404 page', 'elementor' );
__( 'What is a 404 Page Template?', 'elementor' );
__( 'A 404 page template allows you to easily design the layout and style of the page that is displayed when a visitor arrives at a page that does not exist.', 'elementor' );
__( 'Keep your site\'s visitors happy when they get lost by displaying your recent posts, a search bar, or any information that might help the user find what they were looking for.', 'elementor' );
__( 'Are you sure?', 'elementor' );
__( 'Removing %s will permanently delete changes made to the Websites Template\'s content and site settings', 'elementor' );
__( 'Delete', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Try a different Website Template or build your site from scratch.', 'elementor' );
__( 'OK', 'elementor' );
__( 'Library', 'elementor' );
__( 'You\'re ready to apply a new Kit!', 'elementor' );
__( 'Continue to new Kit', 'elementor' );
__( 'Close', 'elementor' );
__( '%s was successfully deleted', 'elementor' );
__( 'Your Kit', 'elementor' );
__( 'Close', 'elementor' );
__( 'Tip', 'elementor' );
__( 'Add New', 'elementor' );
__( 'Close', 'elementor' );
__( 'Theme Builder', 'elementor' );
__( 'Upgrade', 'elementor' );
__( 'Customize every part of your site', 'elementor' );
__( 'Get total control, consistency and a faster workflow by designing the recurring parts that make up a complete website like the Header & Footer, Archive, 404, WooCommerce pages and more.', 'elementor' );
__( 'Upgrade Now', 'elementor' );
__( 'Theme Builder could not be loaded', 'elementor' );
__( 'We’re sorry, but something went wrong. Click on ‘Learn more’ and follow each of the steps to quickly solve it.', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Go Back', 'elementor' );
__( 'Info', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Tip', 'elementor' );
__( 'Watch Video', 'elementor' );
__( 'Upgrade Now', 'elementor' );
__( 'Site Parts', 'elementor' );
__( 'All Parts', 'elementor' );
__( 'Error:', 'elementor' );
__( 'Loading', 'elementor' );
__( 'Categories', 'elementor' );
__( 'Tags', 'elementor' );
__( 'Features', 'elementor' );
__( 'Plan', 'elementor' );
__( 'Free', 'elementor' );
__( 'Pro', 'elementor' );
__( 'Advanced', 'elementor' );
__( 'Expert', 'elementor' );
__( 'Agency', 'elementor' );
__( 'Free', 'elementor' );
__( 'Essential', 'elementor' );
__( 'Advanced & Higher', 'elementor' );
__( 'Free', 'elementor' );
__( 'Essential', 'elementor' );
__( 'Advanced', 'elementor' );
__( 'My Website Templates', 'elementor' );
__( 'My Website Templates', 'elementor' );
__( 'Connect', 'elementor' );
__( 'My Website Templates', 'elementor' );
__( 'Upgrade', 'elementor' );
__( 'All Website Templates', 'elementor' );
__( 'Favorites', 'elementor' );
__( 'Pages', 'elementor' );
__( 'Site Parts', 'elementor' );
__( 'Popups', 'elementor' );
__( 'Search %s...', 'elementor' );
__( 'No Results Found', 'elementor' );
__( 'Sort Descending', 'elementor' );
__( 'Sort Ascending', 'elementor' );
__( 'Clear', 'elementor' );
__( 'Website template storage is full.', 'elementor' );
__( 'Get more space ', 'elementor' );
__( 'Upgrade now', 'elementor' );
__( 'Website template storage is %1$s%% full.', 'elementor' );
__( 'Get more space ', 'elementor' );
__( 'Upgrade now', 'elementor' );
__( 'or', 'elementor' );
__( 'Dismiss notification', 'elementor' );
__( 'of', 'elementor' );
__( 'To get more space', 'elementor' );
__( 'Upgrade now', 'elementor' );
__( 'Blank Canvas', 'elementor' );
__( 'Blank Canvas', 'elementor' );
__( 'Blank Canvas', 'elementor' );
__( 'Create New Elementor Page', 'elementor' );
__( 'Upgrade', 'elementor' );
__( 'View Demo', 'elementor' );
__( 'Delete', 'elementor' );
__( 'Your library is currently over the new quota. Upgrade your plan within 90 days to keep all website templates', 'elementor' );
__( 'Actions', 'elementor' );
__( 'Your library is currently over the new quota. Upgrade your plan within 90 days to keep all website templates', 'elementor' );
__( 'Apply', 'elementor' );
__( 'Delete this Website Template?', 'elementor' );
__( 'Removing "%s" will permanently delete this website template from your library.', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Delete', 'elementor' );
__( 'You\'ve already applied a Website Templates.', 'elementor' );
__( 'Applying two Website Templates on the same website will mix global styles and colors and hurt your site\'s performance.', 'elementor' );
__( 'Remove the existing Website Template before applying a new one.', 'elementor' );
__( 'Remove existing', 'elementor' );
__( 'Apply anyway', 'elementor' );
__( 'Apply', 'elementor' );
__( 'Apply', 'elementor' );
__( 'Something went wrong.', 'elementor' );
__( 'Something went wrong.', 'elementor' );
__( 'Download Website', 'elementor' );
__( 'Download Website ZIP', 'elementor' );
__(
						'Go to the pages screen to make sure your kit pages have been imported successfully. If not, try again.',
						'elementor',
					) }
					approveButtonText={ __( 'Go to pages', 'elementor' );
__( 'Got it', 'elementor' );
_n( 'Showing %s result for', 'Showing %s results for', props.resultCount, 'elementor' );
__( 'no', 'elementor' );
__( 'Remove', 'elementor' );
__( 'Clear all', 'elementor' );
__( 'Remove from Favorites', 'elementor' );
__( 'Add to Favorites', 'elementor' );
__( 'Looking for more Website Templates?', 'elementor' );
__( 'Check out Elementor Website Templates on ThemeForest', 'elementor' );
__( 'Unable to connect', 'elementor' );
__( 'Connect to Template Library', 'elementor' );
__( 'Access this template and our entire library by creating a free personal account', 'elementor' );
__( 'Get Started', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Apply %s?', 'elementor' );
__( 'You can use everything in this kit, or Customize to only include some items.', 'elementor' );
__( 'By applying the entire kit, you\'ll override any styles, settings or content already on your site.', 'elementor' );
__( 'Apply All', 'elementor' );
__( 'Customize', 'elementor' );
__( 'Import', 'elementor' );
__( 'Export', 'elementor' );
__( 'No import sessions available to revert.', 'elementor' );
__( 'Are you sure?', 'elementor' );
__(
						"Removing %s will permanently delete changes made to the Website Template's content and site settings",
						'elementor',
					).replace( '%s', activeKitName ),
					strings: {
						confirm: __( 'Delete', 'elementor' );
__( 'Cancel', 'elementor' );
__( '%s was successfully deleted', 'elementor' );
__(
					'Try a different Website Template or build your site from scratch.',
					'elementor',
				),
				strings: {
					confirm: __( 'OK', 'elementor' );
__( 'Library', 'elementor' );
__( "You're ready to apply a new Kit!", 'elementor' );
__( 'Continue to new Kit', 'elementor' );
__( 'Close', 'elementor' );
__( 'Your Kit', 'elementor' );
__( 'Your Kit', 'elementor' );
__( 'Content', 'elementor' );
__( 'Elementor Pages', 'elementor' );
__( 'Elementor Posts', 'elementor' );
__( 'WP Pages', 'elementor' );
__( 'WP Posts', 'elementor' );
__( 'WP Menus', 'elementor' );
__( 'Custom Post Types', 'elementor' );
__( 'Templates', 'elementor' );
__( 'Saved Templates', 'elementor' );
__( 'Headers', 'elementor' );
__( 'Footers', 'elementor' );
__( 'Archives', 'elementor' );
__( 'Single Posts', 'elementor' );
__( 'Single Pages', 'elementor' );
__( 'Search Results', 'elementor' );
__( '404 Error Page', 'elementor' );
__( 'Popups', 'elementor' );
__( 'Global widgets', 'elementor' );
__( 'To import or export these components, you’ll need Elementor Pro.', 'elementor' );
__( 'Settings & configurations', 'elementor' );
__( 'Classes', 'elementor' );
__( 'Variables', 'elementor' );
__( 'Global Colors', 'elementor' );
__( 'Global Fonts', 'elementor' );
__( 'Theme Style Settings', 'elementor' );
__( 'Layout Settings', 'elementor' );
__( 'Lightbox Settings', 'elementor' );
__( 'Background Settings', 'elementor' );
__( 'Custom Fonts', 'elementor' );
__( 'Icons', 'elementor' );
__( 'Code', 'elementor' );
__( 'Plugins', 'elementor' );
__( 'All plugins are required for this website templates to work', 'elementor' );
__( 'Desktop', 'elementor' );
__( 'Tablet', 'elementor' );
__( 'Mobile', 'elementor' );
__( 'Overview', 'elementor' );
__( 'Kit Library', 'elementor' );
__( 'Loading...', 'elementor' );
__( 'View Demo', 'elementor' );
__( 'Kit Library', 'elementor' );
__( 'Loading...', 'elementor' );
__( 'WHAT\'S INSIDE', 'elementor' );
__( 'View Demo', 'elementor' );
__( 'Website Templates', 'elementor' );
__( 'Featured', 'elementor' );
__( 'New', 'elementor' );
__( 'Popular', 'elementor' );
__( 'Trending', 'elementor' );
__( 'Search all Website Templates...', 'elementor' );
__( 'Something went wrong.', 'elementor' );
__( 'Nothing to worry about, use 🔄 on the top corner to try again. If the problem continues, head over to the Help Center.', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'No results matched your search.', 'elementor' );
__( 'Try different keywords or ', 'elementor' );
__( 'Continue browsing.', 'elementor' );
__( 'Info', 'elementor' );
__( 'Refetch', 'elementor' );
__( 'Import', 'elementor' );
__( 'Import Website Template', 'elementor' );
__( 'Welcome to the Library', 'elementor' );
__( 'What\'s a Website Template?', 'elementor' );
__( 'A Website Template is full, ready-made design that you can apply to your site. It includes all the pages, parts, settings and content that you\'d expect in a fully functional website.', 'elementor' );
__( 'What\'s going on in the Website Templates Library?', 'elementor' );
__( 'Search & filter for website templates by category and tags, or browse through individual website templates to see what\'s inside.', 'elementor' );
__( 'Once you\'ve picked a winner, apply it to your site!', 'elementor' );
__( 'Happy browsing!', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'about using templates', 'elementor' );
__( 'No favorites here yet...', 'elementor' );
__( 'Use the heart icon to save Website Templates that inspire you. You\'ll be able to find them here.', 'elementor' );
__( 'Continue browsing.', 'elementor' );
__( 'Access Website Templates with a plan upgrade', 'elementor' );
__( 'Your current plan doesn\'t include saving and importing Website Templates. Upgrade to the Advanced plan or higher to use this feature.', 'elementor' );
__( 'Compare plans', 'elementor' );
__( 'It\'s time to level up', 'elementor' );
__( 'Upgrade to Elementor Pro to import your own website template and save templates that you can reuse on any of your connected websites.', 'elementor' );
__( 'Upgrade now', 'elementor' );
__( 'Your library has been deactivated', 'elementor' );
__( 'Your subscription is currently deactivated, but you still have a 90 day window to keep all your templates safe. Upgrade within this time to continue enjoying them without interruption.', 'elementor' );
__( 'Upgrade now', 'elementor' );
__( 'Website Templates', 'elementor' );
__( 'Search my Website Templates...', 'elementor' );
__( 'Something went wrong.', 'elementor' );
__( 'Nothing to worry about, use 🔄 on the top corner to try again. If the problem continues, head over to the Help Center.', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'No Website Templates found for your search', 'elementor' );
__( 'Try different keywords or ', 'elementor' );
__( 'Continue browsing.', 'elementor' );
__( 'No Website Templates to show here yet', 'elementor' );
__( "Once you export a Website to the cloud, you'll find it here and be able to use it on all your sites.", 'elementor' );
__( 'Export this site', 'elementor' );
__( 'Website Templates', 'elementor' );
__( 'Back to Library', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'We couldn’t download the Website Template due to technical difficulties on our part. Try again and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Couldn’t handle the Website Template', 'elementor' );
__( 'Seems like your server is missing the PHP zip module. Install it on your server or contact your site host for further instructions.', 'elementor' );
__( 'Couldn’t use the .zip file', 'elementor' );
__( 'Seems like there is a problem with the zip’s files. Try installing again and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'It took too much time to download your Website Template and we were unable to complete the process. If all the Website Template’s parts don’t appear in ', 'elementor' );
__( 'Pages', 'elementor' );
__( ', try again and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'We couldn’t download the Website Template due to technical difficulty on our part. Try again in a few minutes and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Couldn’t access the file', 'elementor' );
__( 'Seems like Elementor isn’t authorized to access relevant files for installing this Website Template. Contact your site host to get permission.', 'elementor' );
__( 'Couldn’t install the Website Template', 'elementor' );
__( 'The Website Template includes plugins you don’t have permission to install. Contact your site admin to change your permissions.', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'This is due to a conflict with one or more third-party plugins already active on your site. Try disabling them, and then give the download another go.', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'This download requires the \'DOMDocument\' PHP extension, which we couldn’t detect on your server. Enable this extension, or get in touch with your hosting service for support, and then give the download another go.', 'elementor' );
__( 'Couldn’t Export the Website Template', 'elementor' );
__( 'The export failed because it will pass the maximum Website Templates you can export.', 'elementor' );
__( 'Couldn’t fetch quota', 'elementor' );
__( 'Failed to fetch quota.', 'elementor' );
__( 'Couldn’t Export the Website Template', 'elementor' );
__( 'The export failed because it will pass the maximum Website Templates storage you have available.', 'elementor' );
__( 'Try Again', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Close', 'elementor' );
__( 'Site Area', 'elementor' );
__( 'Included', 'elementor' );
__( 'Elementor Templates', 'elementor' );
__( 'Site Settings', 'elementor' );
__( 'Content', 'elementor' );
__( 'Plugins', 'elementor' );
__( 'Templates', 'elementor' );
__( 'Saved Templates', 'elementor' );
__( 'Headers', 'elementor' );
__( 'Footers', 'elementor' );
__( 'Archives', 'elementor' );
__( 'Single Posts', 'elementor' );
__( 'Single Pages', 'elementor' );
__( 'Search Results', 'elementor' );
__( '404 Error Page', 'elementor' );
__( 'Popups', 'elementor' );
__( 'Global widgets', 'elementor' );
__( 'To import or export these components, you’ll need Elementor Pro.', 'elementor' );
__( 'Content', 'elementor' );
__( 'Elementor Pages', 'elementor' );
__( 'Landing Pages', 'elementor' );
__( 'Elementor Posts', 'elementor' );
__( 'WP Pages', 'elementor' );
__( 'WP Posts', 'elementor' );
__( 'WP Menus', 'elementor' );
__( 'Custom Post Types', 'elementor' );
__( 'Site Settings', 'elementor' );
__( 'Global Colors', 'elementor' );
__( 'Global Fonts', 'elementor' );
__( 'Theme Style settings', 'elementor' );
__( 'Layout Settings', 'elementor' );
__( 'Lightbox Settings', 'elementor' );
__( 'Background Settings', 'elementor' );
__( 'Kit Info', 'elementor' );
__( 'Import a Website Template', 'elementor' );
__( 'What’s a Website Template?', 'elementor' );
__( 'A Website Template is a .zip file that contains all the parts of a complete site. It’s an easy way to get a site up and running quickly.', 'elementor' );
__( ' Learn more about Website Templates', 'elementor' );
__( 'How does importing work?', 'elementor' );
__( 'Start by uploading the file and selecting the parts and plugins you want to apply. If there are any overlaps between the kit and your current design, you’ll be able to choose which imported parts you want to apply or ignore. Once the file is ready, the kit will be applied to your site and you’ll be able to see it live.', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Export a Website Kit', 'elementor' );
__( 'What’s a Website Kit?', 'elementor' );
__( 'A Website Kit is a .zip file that contains all the parts of a complete site. It’s an easy way to get a site up and running quickly.', 'elementor' );
__( ' Learn more about Website Kits', 'elementor' );
__( 'How does exporting work?', 'elementor' );
__( 'To turn your site into a Website Kit, select the templates, content, settings and plugins you want to include. Once it’s ready, you’ll get a .zip file that you can import to other sites.', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Setting up your website template...', 'elementor' );
__( 'This usually takes a few moments.', 'elementor' );
__( "Don't close this window until the process is finished.", 'elementor' );
__( 'Custom Post Type', 'elementor' );
__( 'Click to select custom post types', 'elementor' );
__( 'No custom post types in your site...', 'elementor' );
__( 'Add the custom posts types to export. The latest 20 items from each type will be included.', 'elementor' );
__( 'You’re using an older Elementor version. Update for full customization.', 'elementor' );
__( 'Update version', 'elementor' );
__( 'This website template was exported from an older version of Elementor. If possible, re-export it with the latest version for better capabilities.', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Override all classes and variables?', 'elementor' );
__( 'This will delete all existing classes and variables and replace them with the imported ones. This action cannot be undone.', 'elementor' );
__( 'Override all variables?', 'elementor' );
__( 'This will delete all existing variables and replace them with the imported ones. This action cannot be undone.', 'elementor' );
__( 'Override all classes?', 'elementor' );
__( 'This will delete all existing classes and replace them with the imported ones. This action cannot be undone.', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Save and override', 'elementor' );
__( 'Edit settings & configurations', 'elementor' );
__( 'Theme', 'elementor' );
__( 'Theme', 'elementor' );
__( 'Only public WordPress themes are supported', 'elementor' );
__( 'Version', 'elementor' );
__( 'Version', 'elementor' );
__( 'Edit plugins', 'elementor' );
__( 'Plugin name and version', 'elementor' );
__( 'All plugins', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Save changes', 'elementor' );
__( 'This feature requires Elementor Pro', 'elementor' );
__( 'Upgrade', 'elementor' );
__( 'Edit', 'elementor' );
__( 'Edit', 'elementor' );
__( 'Not exported', 'elementor' );
__( 'Limit exceeded. Click \'Edit\' to review conflicts or override existing items', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Save changes', 'elementor' );
__( 'Link to media', 'elementor' );
__( 'Stores only the URLs. The export stays light, but files load only while the original site is online.', 'elementor' );
__( 'Save media to the cloud', 'elementor' );
__( 'All images and files are stored with the template. Keeps everything intact, but the file is larger.', 'elementor' );
__( 'Media format', 'elementor' );
__( 'Note:', 'elementor' );
__( 'The media will be uploaded automatically, just as it was saved during export', 'elementor' );
__( 'Select how do you want to save & export the media files.', 'elementor' );
__( 'Media format', 'elementor' );
__( 'Note:', 'elementor' );
__( 'To export a ZIP, go to Edit Content, choose \'Link to Media\', then Export as ZIP.', 'elementor' );
__( 'Or, save this template to the cloud instead.', 'elementor' );
__( 'Edit content', 'elementor' );
__( 'Custom post types', 'elementor' );
__( 'Custom post types', 'elementor' );
__( 'Not exported', 'elementor' );
__( 'All', 'elementor-pro' );
__( 'Show less', 'elementor' );
__( 'Show more', 'elementor' );
__( 'What\'s included:', 'elementor' );
__( 'Not exported', 'elementor' );
__( 'over limit', 'elementor' );
__( 'Review', 'elementor' );
__( 'Override all', 'elementor' );
__( 'This will delete all existing items and replace them with the imported ones', 'elementor' );
__( 'Classes & variables', 'elementor' );
__( 'Import limit reached.', 'elementor' );
__( 'To resolve this, review existing items or choose to override', 'elementor' );
__( 'Classes', 'elementor' );
__( 'Variables', 'elementor' );
__( 'Import', 'elementor' );
__( 'Setting up your website template...', 'elementor' );
__( 'This usually takes a few moments.', 'elementor' );
__( 'Don\'t close this window until the process is finished.', 'elementor' );
__( 'Import', 'elementor' );
__( 'Import a website template', 'elementor' );
__( 'Upload a file with templates, site settings, content, etc., and apply them to your site ', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Import', 'elementor' );
__( 'Back', 'elementor' );
__( 'Import and apply', 'elementor' );
__( 'Select which parts you want to apply', 'elementor' );
__( 'These are the templates, content and site settings that come with your website templates.', 'elementor' );
__( 'All items are already selected by default. Uncheck the ones you don\'t want.', 'elementor' );
__( 'No templates imported', 'elementor' );
__( 'No templates imported', 'elementor' );
__( 'No content imported', 'elementor' );
__( 'Taxonomies', 'elementor' );
__( 'Taxonomy', 'elementor' );
__( 'Menus', 'elementor' );
__( 'Menu', 'elementor' );
__( 'No content imported', 'elementor' );
__( 'No plugins imported', 'elementor' );
__( 'No settings imported', 'elementor' );
__( 'No settings imported', 'elementor' );
__( 'Content', 'elementor' );
__( 'Templates', 'elementor' );
__( 'Site settings', 'elementor' );
__( 'Plugins', 'elementor' );
__( 'See it Live', 'elementor' );
__( 'Close', 'elementor' );
__( 'Import', 'elementor' );
__( 'Kit is live illustration', 'elementor' );
__( 'Your website template is now live on your site!', 'elementor' );
__( 'You\'ve imported and applied the following to your site:', 'elementor' );
__( 'Build sites faster with Website Templates.', 'elementor' );
__( 'Show me how', 'elementor' );
__( 'This file type is not allowed', 'elementor' );
__( 'This file type is not allowed', 'elementor' );
__( 'Activating plugins:', 'elementor' );
__( 'Try Again', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Upload a .zip file', 'elementor' );
__( 'Click to upload', 'elementor' );
__( 'or drag and drop', 'elementor' );
__( 'Setting up your website template...', 'elementor' );
__( 'Processing media files...', 'elementor' );
__( 'Export failed', 'elementor' );
__( 'Export', 'elementor' );
__( 'Export', 'elementor' );
__( 'View in Library', 'elementor' );
__( 'Done', 'elementor' );
__( 'Export', 'elementor' );
__( 'No templates exported', 'elementor' );
__( 'No templates exported', 'elementor' );
__( 'No content exported', 'elementor' );
__( 'Taxonomies', 'elementor' );
__( 'No content exported', 'elementor' );
__( 'No plugins exported', 'elementor' );
__( 'No settings exported', 'elementor' );
__( 'No settings exported', 'elementor' );
__( 'Content', 'elementor' );
__( 'Templates', 'elementor' );
__( 'Site settings', 'elementor' );
__( 'Plugins', 'elementor' );
__( 'Your website template is now saved to the library!', 'elementor' );
__( 'Your .zip file is ready', 'elementor' );
__( 'You can find it in the My Website Templates tab.', 'elementor' );
__( 'Once the download is complete, you can upload it to be used for other sites.', 'elementor' );
__( 'Take me there', 'elementor' );
__( 'Is the automatic download not starting?', 'elementor' );
__( 'Download manually', 'elementor' );
__( 'Must add a website template name', 'elementor' );
__( 'Use characters only', 'elementor' );
__( 'Description exceeds 300 characters', 'elementor' );
__( 'Website template name', 'elementor' );
__( 'Type name here...', 'elementor' );
__( 'Description (Optional)', 'elementor' );
__( 'Type description here...', 'elementor' );
__( 'characters', 'elementor' );
__( 'This usually takes a few moments.', 'elementor' );
__( 'Don\'t close this window until the process is finished.', 'elementor' );
__( 'Save to library', 'elementor' );
__( 'Save to library', 'elementor' );
__( 'Save to library', 'elementor' );
__( 'Save to library', 'elementor' );
__( 'Export as .zip', 'elementor' );
__( 'Export a Website template?', 'elementor' );
__( 'Choose which Elementor components - templates, content and site settings - to include in your website templates file. By default, all of your components will be exported.', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Version' ) } ${ cellLinkProps.text }` } <Icon className="eicon-editor-external-link" />
		</InlineLink>
	);

	const getHeaders = () => {
		if ( ! withHeader ) {
			return [];
		}

		const headers = [ 'Plugin Name', 'Version' ];

		if ( withStatus ) {
			headers.splice( 1, 0, 'Status' );
__( 'Previous', 'elementor' );
__( 'Next', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Import a Website Kit to your site', 'elementor' );
__( 'Parts of this kit overlap with your site’s templates, design and settings. The items you leave checked on this list will replace your current design.', 'elementor' );
__( 'Note:', 'elementor' );
__( "Your site's homepage will be determined by the kit. You can change this later.", 'elementor' );
__( 'Select the items you want to keep and apply:', 'elementor' );
__( 'Importing your content, templates and site settings', 'elementor' );
__( 'This allows Elementor to scan your SVGs for malicious content. Otherwise, you can skip any SVGs in this import.', 'elementor' );
__( 'Nothing to worry about, just continue without importing SVGs or go back and start the import again.', 'elementor' );
__( 'Activating plugins:', 'elementor' );
__( 'Select which plugins to include', 'elementor' );
__( 'All items are already selected by default. Uncheck the ones you don\'t want.', 'elementor' );
__( ' Recommended:', 'elementor' );
__( 'Head over to Updates and make sure that your plugins are updated to the latest version.', 'elementor' );
__( 'Take me there', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Back to Website Templates', 'elementor' );
__( 'Import a Website Template', 'elementor' );
__( 'Upload a .zip file with style, site settings, content, etc. Then, we’ll apply them to your site.', 'elementor' );
__( 'Heads up!', 'elementor' );
__( 'Before applying a new template, we recommend backing up your site so you can roll back any undesired changes.', 'elementor' );
__( 'Choose a file to import', 'elementor' );
__( 'Drag & drop the .zip file with your website template', 'elementor' );
__( 'Or', 'elementor' );
__( 'Import from files', 'elementor' );
__( 'Warning: JSON or ZIP files may be unsafe', 'elementor' );
__( 'Uploading JSON or ZIP files from unknown sources can be harmful and put your site at risk. For maximum safety, upload only JSON or ZIP files from trusted sources.', 'elementor' );
__( 'Continue', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Do not show this message again', 'elementor' );
__( 'Select which parts you want to apply', 'elementor' );
__( "All items are already selected by default. Uncheck the ones you don't want.", 'elementor' );
__( 'We applied your template and your site is online!', 'elementor' );
__( 'You\'ve imported and applied the following to your site:', 'elementor' );
__( 'Click here', 'elementor' );
__( 'to learn more about building your site with Elementor Website Templates', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Select which plugins to export', 'elementor' );
__( 'Your Website Template may not work as expected if key plugins are missing.', 'elementor' );
__( 'By default, we’ll include everything in your file. Uncheck the items you don\'t want.', 'elementor' );
__( 'Next', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Select which items to export', 'elementor' );
__( 'You can export the content, site settings, and templates as a Website Template to be reused in the future.', 'elementor' );
__( 'Uncheck the items you don\'t want to include.', 'elementor' );
__( 'Open library', 'elementor' );
__( 'Done', 'elementor' );
__( 'Download manually', 'elementor' );
__( 'Show me how', 'elementor' );
__( 'Take me there', 'elementor' );
__( 'Your website template is now saved to the library!', 'elementor' );
__( 'Your .zip file is ready', 'elementor' );
__( 'You can find it in the My Website Templates tab.', 'elementor' );
__( 'Once the download is complete, you can upload it to be used for other sites.', 'elementor' );
__( 'Build sites faster with Website Templates.', 'elementor' );
__( 'Is the automatic download not starting?', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'We couldn’t download the Website Template due to technical difficulties on our part. Try again and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Couldn’t handle the Website Template', 'elementor' );
__( 'Seems like your server is missing the PHP zip module. Install it on your server or contact your site host for further instructions.', 'elementor' );
__( 'Couldn’t use the .zip file', 'elementor' );
__( 'Seems like there is a problem with the zip’s files. Try installing again and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'It took too much time to download your Website Template and we were unable to complete the process. If all the Website Template’s parts don’t appear in ', 'elementor' );
__( 'Pages', 'elementor' );
__( ', try again and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'We couldn’t download the Website Template due to technical difficulty on our part. Try again in a few minutes and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Couldn’t access the file', 'elementor' );
__( 'Seems like Elementor isn’t authorized to access relevant files for installing this Website Template. Contact your site host to get permission.', 'elementor' );
__( 'Couldn’t install the Website Template', 'elementor' );
__( 'The Website Template includes plugins you don’t have permission to install. Contact your site admin to change your permissions.', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'This is due to a conflict with one or more third-party plugins already active on your site. Try disabling them, and then give the download another go.', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'This download requires the \'DOMDocument\' PHP extension, which we couldn’t detect on your server. Enable this extension, or get in touch with your hosting service for support, and then give the download another go.', 'elementor' );
__( 'Couldn’t Export the Website Template', 'elementor' );
__( 'The export failed because it will pass the maximum Website Templates you can export. ', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Couldn’t fetch quota', 'elementor' );
__( 'Failed to fetch quota, please try again. If the problem continues, contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Couldn’t Upload to Library', 'elementor' );
__( 'We couldn’t add your export to the library. Try again. ', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'We couldn’t download the Website Template due to technical difficulties on our part. Try again and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Couldn’t save media files to the cloud', 'elementor' );
__( 'We ran into a problem while saving your media files to the cloud. Please try again. If the issue persists, edit the Content section and choose "Link to media" to save it as a reference. ', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Your library is full', 'elementor' );
__( 'This file', 'elementor' );
__( '%s exceeds the library size limit', 'elementor' );
__( 'The maximum website template library size is %s GB. To save this file, you can either export it locally as a .zip file or get more storage by ', 'elementor' );
__( 'Upgrade now', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Export as .zip', 'elementor' );
__( 'Try Again', 'elementor' );
__( 'Export', 'elementor' );
__( 'Close', 'elementor' );
__( 'Edit Template', 'elementor' );
__( 'Imported', 'elementor' );
__( 'Existing', 'elementor' );
__( 'Install Elementor Pro', 'elementor' );
__( "Without Elementor Pro, importing components like templates, widgets and popups won't work.", 'elementor' );
__( 'Is your Elementor Pro ready?', 'elementor' );
__( 'If you’ve purchased, installed & activated Elementor Pro, we can continue importing all the parts of this site.', 'elementor' );
__( 'Yes', 'elementor' );
__( 'Not yet', 'elementor' );
__( 'Previous', 'elementor' );
__( 'Next', 'elementor' );
__( 'Plugins you already have:', 'elementor' );
__( 'Plugins to add:', 'elementor' );
__( 'Missing Required Plugins:', 'elementor' );
__( 'Previous', 'elementor' );
__( 'Import', 'elementor' );
__( 'Note:', 'elementor' );
__( 'The Website Kit you’re using contains plugins for functionality, but no content or pages, etc.', 'elementor' );
__( 'You can’t use this Website Kit because it doesn’t contain any content, pages, etc. Try again with a different file.', 'elementor' );
__( 'Go Back', 'elementor' );
__( 'Required plugins are still missing.', 'elementor' );
__( "If you don't include them, this kit may not work properly.", 'elementor' );
__( 'Go Back', 'elementor' );
__( 'See It Live', 'elementor' );
__( 'Got It', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Important:', 'elementor' );
__( "There are few plugins that we couldn't install:", 'elementor' );
__( 'Let’s do it', 'elementor' );
__( 'Tip:', 'elementor' );
__( 'Make sure your Elementor Pro account is connected', 'elementor' );
__( 'Save to library', 'elementor' );
__( 'Save to library', 'elementor' );
__( 'Save to library', 'elementor' );
__( 'Back', 'elementor' );
__( 'Export as .zip', 'elementor' );
__( 'Must add a name', 'elementor' );
__( 'Name', 'elementor' );
__( 'Type name here...', 'elementor' );
__( 'Description (Optional)', 'elementor' );
__( 'Type description here...', 'elementor' );