"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["1358"],{59453(e){e.exports=JSON.parse('{"onBoardingInstall":{"title":"Willkommen bei\\nElementor One!","description":"Wir werden alle Elementor-Funktionen installieren.\\nWenn Sie diese nicht installieren m\xf6chten, deaktivieren Sie sie jetzt.","skip":"\xdcberspringen","continue":"Weiter","installAndContinue":"Installieren und fortfahren","duringInstallation":"W\xe4hrend der Installation werden alle erforderlichen Tools aktualisiert.","tools":{"additionalBetaTools":"Zus\xe4tzliche Beta-Tools","editorCore":{"title":"Editor-Kern","description":"Erstellen Sie pixelgenaue Websites mit einer Drag & Drop-Oberfl\xe4che"},"editorPro":{"title":"Editor Pro","description":"Erstellen Sie Ihre gesamte Website mit professionellen Tools"},"imageOptimizer":{"title":"Bildoptimierung","description":"Bilder komprimieren und optimieren, um die Leistung zu steigern"},"accessibility":{"title":"Barrierefreiheit","description":"Barrierefreiheitsprobleme auf Ihrer Website finden und beheben"},"siteMailer":{"title":"Site Mailer","description":"Stellen Sie sicher, dass Ihre Website-E-Mails im Posteingang landen \u2013 nicht im Spam"},"ai":{"title":"Native KI f\xfcr WordPress","description":"Verwandeln Sie Ideen in Seiten, Bl\xf6cke und Funktionen mit nativer KI "},"installed":"Bereits installiert","singleSub":"Einzelabonnement","updateRequired":"Update erforderlich","updateRequiredTooltip":"Wird automatisch auf die neueste Version aktualisiert","beta":"Beta","manage":{"title":"Website-Verwaltung","description":"\xdcberwachen, optimieren und verwalten Sie alle Ihre Websites an einem Ort"},"installedTooltip":"Installierte Tools k\xf6nnen Sie im Tool-Manager deinstallieren."},"installedToolTip":"Installierte Tools k\xf6nnen Sie im Tool-Manager deinstallieren.","conflictsDialog":{"update":{"title":"Updates verf\xfcgbar","description":"Diese Tools laufen in \xe4lteren Versionen. Aktualisieren Sie sie f\xfcr beste Leistung und Sicherheit.","selectTools":"Tools zum Aktualisieren ausw\xe4hlen","action":"{nothingIsSelected, select, true {Weiter} other {Aktualisieren & fortfahren}}"},"migrate":{"title":"Migration erforderlich","description":"Diese Tools sind nicht auf Elementor One migriert. Migrieren Sie sie f\xfcr beste Leistung und Sicherheit.","selectTools":"Tools zum Migrieren ausw\xe4hlen","action":"{nothingIsSelected, select, true {Weiter} other {Verschieben & fortfahren}}"},"manageLater":"Sie k\xf6nnen diese Updates sp\xe4ter im Tool-Manager verwalten","step":"Schritt {step} von {total}"}},"siteIdentity":{"activeTheme":"Aktives Theme:","getHelloElementor":"Hello Elementor herunterladen","goToDashboard":"Zum Dashboard gehen","editSite":"Website bearbeiten","editSiteMenu":{"addPage":"Seite hinzuf\xfcgen","addBlogPost":"Blogbeitrag hinzuf\xfcgen","createHeader":"Header erstellen","createFooter":"Footer erstellen"},"helloThemeInstalled":"Hello Elementor Theme erfolgreich installiert","helloThemeInstallationFailed":"Installation des Hello Elementor Themes fehlgeschlagen","helloThemeActivationFailed":"Aktivierung des Hello Elementor Themes fehlgeschlagen","helloThemeActivated":"Hello Elementor Theme erfolgreich aktiviert","goToSiteSetup":"Zur Website-Einrichtung"},"capabilities":{"greeting":"Fangen wir an zu bauen.","filters":{"all":"Alle","discover":"Entdecken","build":"Erstellen","optimize":"Optimieren","manage":"Verwalten","featured":"Empfohlen","create":"Erstellen"},"toolManager":"Tool-Manager","addForFreeButton":"Kostenlos hinzuf\xfcgen","openButton":"\xd6ffnen","goProButton":"Pro werden","inProgressButton":"In Bearbeitung","learnMore":{"upgrade":"Upgrade","install":"Installieren","open":"\xd6ffnen"},"isNew":"Neu"},"toolManager":{"title":"Alle Ihre Tools an EINEM Ort steuern."},"welcomeModal":{"letsStart":{"title":"Willkommen beim <br />neuen Elementor!","description":"Erstellen, optimieren und verwalten Sie Ihre Website <br />aus einem leistungsstarken Arbeitsbereich.","button":"Los geht\'s"}}}')}}]);