@keyframes elementor-animation-pop {
	50% {
		transform: scale(1.2);
	}
}
.elementor-animation-pop:active,
.elementor-animation-pop:focus,
.elementor-animation-pop:hover {
	animation-name: elementor-animation-pop;
	animation-duration: 0.3s;
	animation-timing-function: linear;
	animation-iteration-count: 1;
}
