"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["897"],{55048(a){a.exports=JSON.parse('{"title":"Manajer alat","subtitle":"Kontrol semua alat Anda di SATU tempat.","filters":{"all":"Semua","active":"Aktif","disabled":"Dinonaktifkan","notInstalled":"Tidak terinstal"},"back":"Kembali ke ikhtisar alat","breadcrumb":{"home":"Beranda","toolManager":"Manajer alat"},"tools":{"build":{"title":"Bangun","items":{"core":{"title":"Inti editor"},"pro":{"title":"Editor pro","features":{"themeBuilder":"Pembuat tema","popups":"Pop-up","commerce":"Perdagangan","savedTemplates":"Templat tersimpan","templateCategories":"Kategori templat","starterTemplates":"Templat pemula (templat situs web)","customFonts":"Font kustom","customIcons":"Ikon kustom","customCode":"Kode kustom","customCss":"CSS kustom"}},"ai":{"title":"AI Agen"}}},"optimize":{"title":"Optimalkan","items":{"accessibility":{"title":"Aksesibilitas"},"io":{"title":"Optimasi gambar"}}},"manage":{"title":"Kelola","items":{"email":{"title":"Keterkiriman email"}}}},"actions":{"add":"Tambah","update":"Perbarui","activate":"Aktifkan","deactivate":"Nonaktifkan","migrateToOne":"Migrasi ke One","updateRequired":"Pembaruan diperlukan","confirmAdd":{"title":"Tambah alat","msg":"Apakah Anda yakin ingin menambahkan alat ini? Ini akan menambahkan alat ke akun Anda dan Anda akan dapat menggunakannya di proyek Anda.","ok":"Tambah","cancel":"Batal"},"confirmActivate":{"title":"Yakin ingin mengaktifkan {name}? ","msg":"Dengan mengaktifkan ...","ok":"Aktifkan","cancel":"Batal"},"confirmDeactivate":{"title":"Yakin ingin menonaktifkan {name}? ","msg":"Dengan menonaktifkan ...","ok":"Nonaktifkan","cancel":"Nanti saja"}},"showMoreFeatures":"Tampilkan lebih banyak fitur","hideMoreFeatures":"Sembunyikan lebih banyak fitur","noToolsFound":"Tidak ada alat yang cocok dengan pencarian tersebut","noToolsFoundDescription":"Coba sesuaikan filter Anda.","updateRequiredTooltip":"Plugin terbaru memiliki fitur dan perbaikan baru agar situs Anda berjalan aman dan lancar."}')}}]);