/*
 * UnderConstructionPage
 * Hard Worker theme CSS
 * (c) WebFactory Ltd, 2015 - 2025
 */


html {
   height: 100%;
   padding: 0;
   margin: 0;
}

body {
  font-weight: 400;
  font-size: 14px;
  line-height: 120%;
  color: #bebfc1;
  background: linear-gradient(to bottom, #0e6f8d 0%, #084C61 100%);
  padding: 0;
  margin: 0;
  background-repeat: repeat;
  background-attachment: fixed;
}

#hero-image {
  text-align: center;
  margin: 20px auto 40px auto;
  border-bottom: 2px solid rgba(0, 0, 0, 0.9);
}

#hero-image img {
  max-width: 80%;
}

h1 {
  font-size: 34px;
  color: #d2d4d5;
  font-family: "Roboto", sans-serif;
  font-weight: 900;
  margin: 60px 0 30px 0;
  text-align: center;
}

.content {
  text-align: center;
  font-family: "Helvetica", "Arial", sans-serif;
}

#social {
  text-align: center;
  margin-top: 30px;
}

#social a i {
  color: #bebfc1;
  margin: 10px;
  box-sizing: content-box;
}

#social a:hover i {
  color: #FFBB33;
}

@media(max-width:767px){
  #hero-image {
    border-bottom: 1px solid rgba(0, 0, 0, 0.7);
  }
  h1 {
     font-size: 30px;
     margin: 10px 0 30px 0;
  }
  #hero-image img {
    max-width: 95%;
  }
}
