"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["8664"],{70571(e){e.exports=JSON.parse('{"example":{"component":"Voorbeeldcomponent"},"header":{"title":"website bouwer","userInfo":"Mijn rekening","userProfileMenu":{"connectPreText":"Heb je een Elementor One-abonnement?","connect":"Verbinden","goToMyAccount":"Ga naar Mijn account","disconnect":"Verbreek de verbinding","elementorOneActive":"Elementor E\xe9n","active":"Actief","urlMismatch":"URL-mismatch gedetecteerd","fixUrlMismatch":"Nu repareren"},"whatsNew":"Wat is er nieuw","whatsNewError":"Er is iets misgegaan bij het ophalen van de meldingen. Probeer het later opnieuw."}}')}}]);