.elementor-animation-bounce-in {
	transition-duration: 0.5s;
}
.elementor-animation-bounce-in:active,
.elementor-animation-bounce-in:focus,
.elementor-animation-bounce-in:hover {
	transform: scale(1.2);
	transition-timing-function: cubic-bezier(0.47, 2.02, 0.31, -0.36);
}
