__( 'No import sessions available to revert.', 'elementor' );
__( 'Are you sure?', 'elementor' );
__(
						"Removing %s will permanently delete changes made to the Website Template's content and site settings",
						'elementor',
					).replace( '%s', activeKitName ),
					strings: {
						confirm: __( 'Delete', 'elementor' );
__( 'Cancel', 'elementor' );
__( '%s was successfully deleted', 'elementor' );
__(
					'Try a different Website Template or build your site from scratch.',
					'elementor',
				),
				strings: {
					confirm: __( 'OK', 'elementor' );
__( 'Library', 'elementor' );
__( "You're ready to apply a new Kit!", 'elementor' );
__( 'Continue to new Kit', 'elementor' );
__( 'Close', 'elementor' );
__( 'Your Kit', 'elementor' );
__( 'Your Kit', 'elementor' );
__( 'Content', 'elementor' );
__( 'Elementor Pages', 'elementor' );
__( 'Elementor Posts', 'elementor' );
__( 'WP Pages', 'elementor' );
__( 'WP Posts', 'elementor' );
__( 'WP Menus', 'elementor' );
__( 'Custom Post Types', 'elementor' );
__( 'Templates', 'elementor' );
__( 'Saved Templates', 'elementor' );
__( 'Headers', 'elementor' );
__( 'Footers', 'elementor' );
__( 'Archives', 'elementor' );
__( 'Single Posts', 'elementor' );
__( 'Single Pages', 'elementor' );
__( 'Search Results', 'elementor' );
__( '404 Error Page', 'elementor' );
__( 'Popups', 'elementor' );
__( 'Global widgets', 'elementor' );
__( 'To import or export these components, you’ll need Elementor Pro.', 'elementor' );
__( 'Settings & configurations', 'elementor' );
__( 'Classes', 'elementor' );
__( 'Variables', 'elementor' );
__( 'Global Colors', 'elementor' );
__( 'Global Fonts', 'elementor' );
__( 'Theme Style Settings', 'elementor' );
__( 'Layout Settings', 'elementor' );
__( 'Lightbox Settings', 'elementor' );
__( 'Background Settings', 'elementor' );
__( 'Custom Fonts', 'elementor' );
__( 'Icons', 'elementor' );
__( 'Code', 'elementor' );
__( 'Plugins', 'elementor' );
__( 'All plugins are required for this website templates to work', 'elementor' );
__( 'You’re using an older Elementor version. Update for full customization.', 'elementor' );
__( 'Update version', 'elementor' );
__( 'This website template was exported from an older version of Elementor. If possible, re-export it with the latest version for better capabilities.', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Override all classes and variables?', 'elementor' );
__( 'This will delete all existing classes and variables and replace them with the imported ones. This action cannot be undone.', 'elementor' );
__( 'Override all variables?', 'elementor' );
__( 'This will delete all existing variables and replace them with the imported ones. This action cannot be undone.', 'elementor' );
__( 'Override all classes?', 'elementor' );
__( 'This will delete all existing classes and replace them with the imported ones. This action cannot be undone.', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Save and override', 'elementor' );
__( 'Edit settings & configurations', 'elementor' );
__( 'Theme', 'elementor' );
__( 'Theme', 'elementor' );
__( 'Only public WordPress themes are supported', 'elementor' );
__( 'Version', 'elementor' );
__( 'Version', 'elementor' );
__( 'Edit plugins', 'elementor' );
__( 'Plugin name and version', 'elementor' );
__( 'All plugins', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Save changes', 'elementor' );
__( 'This feature requires Elementor Pro', 'elementor' );
__( 'Upgrade', 'elementor' );
__( 'Edit', 'elementor' );
__( 'Edit', 'elementor' );
__( 'Not exported', 'elementor' );
__( 'Limit exceeded. Click \'Edit\' to review conflicts or override existing items', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Save changes', 'elementor' );
__( 'Link to media', 'elementor' );
__( 'Stores only the URLs. The export stays light, but files load only while the original site is online.', 'elementor' );
__( 'Save media to the cloud', 'elementor' );
__( 'All images and files are stored with the template. Keeps everything intact, but the file is larger.', 'elementor' );
__( 'Media format', 'elementor' );
__( 'Note:', 'elementor' );
__( 'The media will be uploaded automatically, just as it was saved during export', 'elementor' );
__( 'Select how do you want to save & export the media files.', 'elementor' );
__( 'Media format', 'elementor' );
__( 'Note:', 'elementor' );
__( 'To export a ZIP, go to Edit Content, choose \'Link to Media\', then Export as ZIP.', 'elementor' );
__( 'Or, save this template to the cloud instead.', 'elementor' );
__( 'Edit content', 'elementor' );
__( 'Custom post types', 'elementor' );
__( 'Custom post types', 'elementor' );
__( 'Not exported', 'elementor' );
__( 'All', 'elementor-pro' );
__( 'Show less', 'elementor' );
__( 'Show more', 'elementor' );
__( 'What\'s included:', 'elementor' );
__( 'Not exported', 'elementor' );
__( 'over limit', 'elementor' );
__( 'Review', 'elementor' );
__( 'Override all', 'elementor' );
__( 'This will delete all existing items and replace them with the imported ones', 'elementor' );
__( 'Classes & variables', 'elementor' );
__( 'Import limit reached.', 'elementor' );
__( 'To resolve this, review existing items or choose to override', 'elementor' );
__( 'Classes', 'elementor' );
__( 'Variables', 'elementor' );
__( 'Import', 'elementor' );
__( 'Setting up your website template...', 'elementor' );
__( 'This usually takes a few moments.', 'elementor' );
__( 'Don\'t close this window until the process is finished.', 'elementor' );
__( 'Import', 'elementor' );
__( 'Import a website template', 'elementor' );
__( 'Upload a file with templates, site settings, content, etc., and apply them to your site ', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Import', 'elementor' );
__( 'Back', 'elementor' );
__( 'Import and apply', 'elementor' );
__( 'Select which parts you want to apply', 'elementor' );
__( 'These are the templates, content and site settings that come with your website templates.', 'elementor' );
__( 'All items are already selected by default. Uncheck the ones you don\'t want.', 'elementor' );
__( 'No templates imported', 'elementor' );
__( 'No templates imported', 'elementor' );
__( 'No content imported', 'elementor' );
__( 'Taxonomies', 'elementor' );
__( 'Taxonomy', 'elementor' );
__( 'Menus', 'elementor' );
__( 'Menu', 'elementor' );
__( 'No content imported', 'elementor' );
__( 'No plugins imported', 'elementor' );
__( 'No settings imported', 'elementor' );
__( 'No settings imported', 'elementor' );
__( 'Content', 'elementor' );
__( 'Templates', 'elementor' );
__( 'Site settings', 'elementor' );
__( 'Plugins', 'elementor' );
__( 'See it Live', 'elementor' );
__( 'Close', 'elementor' );
__( 'Import', 'elementor' );
__( 'Kit is live illustration', 'elementor' );
__( 'Your website template is now live on your site!', 'elementor' );
__( 'You\'ve imported and applied the following to your site:', 'elementor' );
__( 'Build sites faster with Website Templates.', 'elementor' );
__( 'Show me how', 'elementor' );
__( 'This file type is not allowed', 'elementor' );
__( 'This file type is not allowed', 'elementor' );
__( 'Activating plugins:', 'elementor' );
__( 'Try Again', 'elementor' );
__( 'Learn More', 'elementor' );
__( 'Upload a .zip file', 'elementor' );
__( 'Click to upload', 'elementor' );
__( 'or drag and drop', 'elementor' );
__( 'Setting up your website template...', 'elementor' );
__( 'Processing media files...', 'elementor' );
__( 'Export failed', 'elementor' );
__( 'Export', 'elementor' );
__( 'Export', 'elementor' );
__( 'View in Library', 'elementor' );
__( 'Done', 'elementor' );
__( 'Export', 'elementor' );
__( 'No templates exported', 'elementor' );
__( 'No templates exported', 'elementor' );
__( 'No content exported', 'elementor' );
__( 'Taxonomies', 'elementor' );
__( 'No content exported', 'elementor' );
__( 'No plugins exported', 'elementor' );
__( 'No settings exported', 'elementor' );
__( 'No settings exported', 'elementor' );
__( 'Content', 'elementor' );
__( 'Templates', 'elementor' );
__( 'Site settings', 'elementor' );
__( 'Plugins', 'elementor' );
__( 'Your website template is now saved to the library!', 'elementor' );
__( 'Your .zip file is ready', 'elementor' );
__( 'You can find it in the My Website Templates tab.', 'elementor' );
__( 'Once the download is complete, you can upload it to be used for other sites.', 'elementor' );
__( 'Take me there', 'elementor' );
__( 'Is the automatic download not starting?', 'elementor' );
__( 'Download manually', 'elementor' );
__( 'Must add a website template name', 'elementor' );
__( 'Use characters only', 'elementor' );
__( 'Description exceeds 300 characters', 'elementor' );
__( 'Website template name', 'elementor' );
__( 'Type name here...', 'elementor' );
__( 'Description (Optional)', 'elementor' );
__( 'Type description here...', 'elementor' );
__( 'characters', 'elementor' );
__( 'This usually takes a few moments.', 'elementor' );
__( 'Don\'t close this window until the process is finished.', 'elementor' );
__( 'Save to library', 'elementor' );
__( 'Save to library', 'elementor' );
__( 'Save to library', 'elementor' );
__( 'Save to library', 'elementor' );
__( 'Export as .zip', 'elementor' );
__( 'Export a Website template?', 'elementor' );
__( 'Choose which Elementor components - templates, content and site settings - to include in your website templates file. By default, all of your components will be exported.', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Export', 'elementor' );
__( 'Close', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'We couldn’t download the Website Template due to technical difficulties on our part. Try again and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Couldn’t handle the Website Template', 'elementor' );
__( 'Seems like your server is missing the PHP zip module. Install it on your server or contact your site host for further instructions.', 'elementor' );
__( 'Couldn’t use the .zip file', 'elementor' );
__( 'Seems like there is a problem with the zip’s files. Try installing again and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'It took too much time to download your Website Template and we were unable to complete the process. If all the Website Template’s parts don’t appear in ', 'elementor' );
__( 'Pages', 'elementor' );
__( ', try again and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'We couldn’t download the Website Template due to technical difficulty on our part. Try again in a few minutes and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Couldn’t access the file', 'elementor' );
__( 'Seems like Elementor isn’t authorized to access relevant files for installing this Website Template. Contact your site host to get permission.', 'elementor' );
__( 'Couldn’t install the Website Template', 'elementor' );
__( 'The Website Template includes plugins you don’t have permission to install. Contact your site admin to change your permissions.', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'This is due to a conflict with one or more third-party plugins already active on your site. Try disabling them, and then give the download another go.', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'This download requires the \'DOMDocument\' PHP extension, which we couldn’t detect on your server. Enable this extension, or get in touch with your hosting service for support, and then give the download another go.', 'elementor' );
__( 'Couldn’t Export the Website Template', 'elementor' );
__( 'The export failed because it will pass the maximum Website Templates you can export. ', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Couldn’t fetch quota', 'elementor' );
__( 'Failed to fetch quota, please try again. If the problem continues, contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Couldn’t Upload to Library', 'elementor' );
__( 'We couldn’t add your export to the library. Try again. ', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Unable to download the Website Template', 'elementor' );
__( 'We couldn’t download the Website Template due to technical difficulties on our part. Try again and if the problem persists contact ', 'elementor' );
__( 'Support', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Couldn’t save media files to the cloud', 'elementor' );
__( 'We ran into a problem while saving your media files to the cloud. Please try again. If the issue persists, edit the Content section and choose "Link to media" to save it as a reference. ', 'elementor' );
__( 'Learn more', 'elementor' );
__( 'Your library is full', 'elementor' );
__( 'This file', 'elementor' );
__( '%s exceeds the library size limit', 'elementor' );
__( 'The maximum website template library size is %s GB. To save this file, you can either export it locally as a .zip file or get more storage by ', 'elementor' );
__( 'Upgrade now', 'elementor' );
__( 'Cancel', 'elementor' );
__( 'Export as .zip', 'elementor' );
__( 'Try Again', 'elementor' );