:root {
  --e-one-palette-text-primary: #ffffff;
  --e-one-palette-text-secondary: #babfc5;
  --e-one-palette-text-tertiary: #9da5ae;
  --e-one-palette-text-disabled: #515962;
  --e-one-palette-primary-light: #f3bafd;
  --e-one-palette-primary-main: #f0abfc;
  --e-one-palette-primary-dark: #eb8efb;
  --e-one-palette-primary-contrast-text: #0c0d0e;
  --e-one-palette-primary-contrastText: var(--e-one-palette-primary-contrast-text);
  --e-one-palette-secondary-light: #babfc5;
  --e-one-palette-secondary-main: #9da5ae;
  --e-one-palette-secondary-dark: #818a96;
  --e-one-palette-secondary-contrast-text: #0c0d0e;
  --e-one-palette-secondary-contrastText: var(--e-one-palette-secondary-contrast-text);
  --e-one-palette-error-light: #ef4444;
  --e-one-palette-error-main: #dc2626;
  --e-one-palette-error-dark: #b91c1c;
  --e-one-palette-error-contrast-text: #ffffff;
  --e-one-palette-error-contrastText: var(--e-one-palette-error-contrast-text);
  --e-one-palette-warning-light: #fbbf24;
  --e-one-palette-warning-main: #f59e0b;
  --e-one-palette-warning-dark: #b15211;
  --e-one-palette-warning-contrast-text: #000000;
  --e-one-palette-warning-contrastText: var(--e-one-palette-warning-contrast-text);
  --e-one-palette-info-light: #3b82f6;
  --e-one-palette-info-main: #2563eb;
  --e-one-palette-info-dark: #1d4ed8;
  --e-one-palette-info-contrast-text: #ffffff;
  --e-one-palette-info-contrastText: var(--e-one-palette-info-contrast-text);
  --e-one-palette-success-light: #10b981;
  --e-one-palette-success-main: #0a875a;
  --e-one-palette-success-dark: #047857;
  --e-one-palette-success-contrast-text: #ffffff;
  --e-one-palette-success-contrastText: var(--e-one-palette-success-contrast-text);
  --e-one-palette-global-light: #99f6e4;
  --e-one-palette-global-main: #5eead4;
  --e-one-palette-global-dark: #2adfcd;
  --e-one-palette-global-contrast-text: #0c0d0e;
  --e-one-palette-global-contrastText: var(--e-one-palette-global-contrast-text);
  --e-one-palette-promotion-light: #b51243;
  --e-one-palette-promotion-main: #93003f;
  --e-one-palette-promotion-dark: #7e013b;
  --e-one-palette-promotion-contrast-text: #ffffff;
  --e-one-palette-promotion-contrastText: var(--e-one-palette-promotion-contrast-text);
  --e-one-palette-decorative-light: #99f6e4;
  --e-one-palette-decorative-main: #5eead4;
  --e-one-palette-decorative-dark: #2adfcd;
  --e-one-palette-decorative-contrast-text: #0c0d0e;
  --e-one-palette-decorative-contrastText: var(--e-one-palette-decorative-contrast-text);
  --e-one-palette-neutral-light: #ffffff;
  --e-one-palette-neutral-main: #ffffff;
  --e-one-palette-neutral-dark: #ffffff;
  --e-one-palette-neutral-contrast-text: #ffffff;
  --e-one-palette-neutral-contrastText: var(--e-one-palette-neutral-contrast-text);
  --e-one-palette-action-active: #fff;
  --e-one-palette-action-hover: rgba(255, 255, 255, 0.08);
  --e-one-palette-action-selected: rgba(255, 255, 255, 0.16);
  --e-one-palette-action-focus: rgba(255, 255, 255, 0.12);
  --e-one-palette-action-disabled: rgba(255, 255, 255, 0.3);
  --e-one-palette-action-disabled-background: rgba(255, 255, 255, 0.12);
  --e-one-palette-action-disabledBackground: var(--e-one-palette-action-disabled-background);
  --e-one-palette-divider: rgba(255, 255, 255, 0.12);
  --e-one-palette-common-black: #000;
  --e-one-palette-common-white: #fff;
  --e-one-palette-background-default: #1f2124;
  --e-one-palette-background-paper: #0c0d0e;
}

/*# sourceMappingURL=theme-dark.css.map */