<?php
/**
 * WP_Exception class
 *
 * @package WordPress
 * @since 6.7.0
 */

/**
 * Core base Exception class.
 *
 * Future, more specific, Exceptions should always extend this base class.
 *
 * @since 6.7.0
 */
class WP_Exception extends Exception {}
