"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9341"],{6092(e){e.exports=JSON.parse('{"copyClipboard":"Panoya kopyala","copyClipboardSuccess":"Kopyaland\u0131!","noDataToDisplay":"G\xf6r\xfcnt\xfclenecek veri yok","search":"Ara","sort":"S\u0131rala","pagination":{"rowsPerPage":"Sayfa ba\u015F\u0131na sat\u0131r:","displayedRows":"{from}-{to} / {count}"},"phoneInput":{"countryCode":"\xdclke kodu","phoneNumber":"Telefon numaras\u0131","countryCodeRequired":"\xdclke kodu gerekli","phoneNumberRequired":"Telefon numaras\u0131 gerekli"}}')}}]);