"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["568"],{5179(e){e.exports=JSON.parse('{"dialog":{"title":"Prze\u015Blij swoj\u0105 opini\u0119","fieldTitlePlaceholder":"Tytu\u0142","fieldDescriptionPlaceholder":"Opowiedz nam, co masz na my\u015Bli","fieldSubjectPlaceholder":"Wybierz temat swojej opinii","fieldProductPlaceholder":"Wybierz produkt","note":"Dzi\u0119kujemy za Twoj\u0105 opini\u0119! Chocia\u017C przegl\u0105damy wszystkie zg\u0142oszenia, nie mo\u017Cemy zagwarantowa\u0107, \u017Ce ka\u017Cda sugestia zaowocuje zmian\u0105 lub aktualizacj\u0105.","subjects":{"leaveFeedback":"Zostaw opini\u0119","reportBug":"Zg\u0142o\u015B b\u0142\u0105d","requestFeature":"Zaproponuj funkcj\u0119","shareThoughts":"Podziel si\u0119 innymi przemy\u015Bleniami"},"products":{"general":"Og\xf3lne","editor":"Edytor","accessibility":"Dost\u0119pno\u015B\u0107","imageOptimization":"Optymalizacja obrazu","emailDeliverability":"Dostarczalno\u015B\u0107 wiadomo\u015Bci e-mail","siteManagement":"Site Management"},"cancel":"Anuluj","submit":"Wy\u015Blij","titleLengthError":"Tytu\u0142 musi zawiera\u0107 mniej ni\u017C 90 znak\xf3w","descriptionLengthError":"Opis musi zawiera\u0107 mniej ni\u017C 1024 znaki","alert":{"title":"Potrzebujesz pomocy lub napotka\u0142e\u015B problem?","button":"Wy\u015Blij zg\u0142oszenie do pomocy technicznej"}},"tooltipSuccess":"Opinia wys\u0142ana. Dzi\u0119kujemy za pomoc.","tooltipError":"Co\u015B posz\u0142o nie tak. Spr\xf3buj ponownie wys\u0142a\u0107 swoj\u0105 opini\u0119."}')}}]);