"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_he-IL_common_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/he-IL/common.json":
/*!*********************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/he-IL/common.json ***!
  \*********************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"example":{"component":"רכיב לדוגמה"},"header":{"title":"בונה אתרים","userInfo":"החשבון שלי","userProfileMenu":{"connectPreText":"יש לך תוכנית של Elementor One?","connect":"לְחַבֵּר","goToMyAccount":"עבור אל החשבון שלי","disconnect":"לְנַתֵק","elementorOneActive":"אלמנטור אחת","active":"פָּעִיל","urlMismatch":"זוהתה אי התאמה של כתובת האתר","fixUrlMismatch":"תקן עכשיו"},"whatsNew":"מה חדש","whatsNewError":"משהו השתבש בעת שליפת ההתראות. אנא נסה שוב מאוחר יותר."}}');

/***/ })

}]);