"use strict";
(self["webpackChunkelementor"] = self["webpackChunkelementor"] || []).push([["node_modules_elementor_elementor-one-assets_locales_de_send-feedback_json"],{

/***/ "../node_modules/@elementor/elementor-one-assets/locales/de/send-feedback.json":
/*!*************************************************************************************!*\
  !*** ../node_modules/@elementor/elementor-one-assets/locales/de/send-feedback.json ***!
  \*************************************************************************************/
/***/ ((module) => {

module.exports = /*#__PURE__*/JSON.parse('{"dialog":{"title":"Teilen Sie Ihr Feedback mit uns","fieldTitlePlaceholder":"Titel","fieldDescriptionPlaceholder":"Sagen Sie uns, was Sie sich vorgestellt haben","fieldSubjectPlaceholder":"Wählen Sie das Thema Ihres Feedbacks aus","fieldProductPlaceholder":"Produkt auswählen","note":"Wir freuen uns über Ihr Feedback! Wir prüfen zwar alle Einsendungen, können aber nicht garantieren, dass jeder Vorschlag zu einer Änderung oder Aktualisierung führt.","subjects":{"leaveFeedback":"Feedback geben","reportBug":"Fehler melden","requestFeature":"Funktion anfragen","shareThoughts":"Sonstige Gedanken teilen"},"products":{"general":"Allgemein","editor":"Editor","accessibility":"Barrierefreiheit","imageOptimization":"Bildoptimierung","emailDeliverability":"E-Mail-Zustellbarkeit","siteManagement":"Site Management"},"cancel":"Abbrechen","submit":"Senden","titleLengthError":"Der Titel muss weniger als 90 Zeichen lang sein","descriptionLengthError":"Die Beschreibung muss weniger als 1024 Zeichen lang sein","alert":{"title":"Benötigen Sie Hilfe oder sind Sie auf ein Problem gestoßen?","button":"Ein Support-Ticket einreichen"}},"tooltipSuccess":"Feedback gesendet. Vielen Dank für Ihre Hilfe.","tooltipError":"Es ist ein Fehler aufgetreten. Bitte versuchen Sie, Ihr Feedback erneut zu senden."}');

/***/ })

}]);