"use strict";(self.webpackChunk=self.webpackChunk||[]).push([["9556"],{5887(e){e.exports=JSON.parse('{"alertError":{"defaultTitle":"Un probl\xe8me est survenu !","defaultMessage":"Veuillez actualiser cette page.","refreshBtn":"Actualiser","okBtn":"D\'accord"},"errorBoundary":{"default":{"title":"Un probl\xe8me est survenu !","message":"Veuillez actualiser cette page.","btn":"Actualiser"},"newVersion":{"title":"Nouvelle version disponible !","message":"Veuillez actualiser cette page.","btn":"Actualiser"}}}')}}]);